@@ -20,6 +20,7 @@ private Q_SLOTS:
     void testCopyFiles();
     void testMoveFiles();
     void testCopyDirectory();
+    void testCopyEmptyDirectory();
     void testMoveDirectory();
     void testRenameFile();
     void testRenameDir();
@@ -33,7 +34,7 @@ private Q_SLOTS:
     void testBatchRename();
     void testUndoCopyOfDeletedFile();
 
-    // TODO find tests that would lead to kio job errors
+    void testErrorDuringMoveUndo();
 
     // TODO test renaming during a CopyJob.
     // Doesn't seem possible though, requires user interaction...
