@@ -1,29 +1,17 @@
-/* This file is part of the KDE libraries
-    Copyright (c) 2008 Andreas Hartmetz <ahartmetz@gmail.com>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2008 Andreas Hartmetz <ahartmetz@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "httpheadertokenizetest.h"
 
-#include <qtest.h>
+#include <QTest>
 
 #include <QByteArray>
-#include <QHash>
 #include <QDebug>
+#include <QHash>
 
 #include <parsinghelpers.h>
 
@@ -53,9 +41,9 @@ QTEST_MAIN(HeaderTokenizeTest)
         {"location", false},
 */
 
-//no use testing many different headers, just a couple each of the multi-valued
-//and the single-valued group to make sure that corner cases work both if there
-//are already entries for the header and if there are no entries.
+// no use testing many different headers, just a couple each of the multi-valued
+// and the single-valued group to make sure that corner cases work both if there
+// are already entries for the header and if there are no entries.
 static const char messyHeader[] =
     "\n"
     "accept-ranges:foo\r\n"
@@ -70,16 +58,16 @@ static const char messyHeader[] =
     " :fi:ve\r\n"
     ":invalid stuff\r\n"
     "\tinvalid: connection:close\t\r"
-    "connection: Six, seven ,, , eight\r"   //one malformed newline...
-    "\n\r ";   //two malformed newlines; end of header. also observe the trailing space.
+    "connection: Six, seven ,, , eight\r" // one malformed newline...
+    "\n\r "; // two malformed newlines; end of header. also observe the trailing space.
 
-//tab separates values, newline separates header lines. the first word is the key.
+// tab separates values, newline separates header lines. the first word is the key.
 static const char messyResult[] =
     "accept-ranges\tfoo\t42\tmaybe   or not\n"
     "connection\tone   t_   wo\tthree\tfour\t:fi:ve\tSix\tseven\teight";
 
 static const char redirectHeader[] =
-//"HTTP/1.1 302 Moved Temporarily\r\n"
+    //"HTTP/1.1 302 Moved Temporarily\r\n"
     "Location: http://www.hertz.de/rentacar/index.jsp?bsc=t&targetPage=reservationOnHomepage.jsp\r\n"
     "Connection:close\r\n"
     "Cache-Control: no-cache\r\n"
@@ -97,7 +85,7 @@ char buffer[bufSize];
 
 void HeaderTokenizeTest::testMessyHeader()
 {
-    //Copy the header into a writable buffer
+    // Copy the header into a writable buffer
     for (int i = 0; i < bufSize; i++) {
         buffer[i] = 0;
     }
@@ -139,7 +127,7 @@ void HeaderTokenizeTest::testMessyHeader()
     }
     QCOMPARE(nValues2, nValues);
 
-    return; //comment out for parsed header dump to stdout
+    return; // comment out for parsed header dump to stdout
 
     it = tokenizer.constBegin();
     for (; it != tokenizer.constEnd(); ++it) {
@@ -154,7 +142,7 @@ void HeaderTokenizeTest::testMessyHeader()
 
 void HeaderTokenizeTest::testRedirectHeader()
 {
-    //Copy the header into a writable buffer
+    // Copy the header into a writable buffer
     for (int i = 0; i < bufSize; i++) {
         buffer[i] = 0;
     }
