@@ -1,27 +1,15 @@
-/* This file is part of the KDE project
-   Copyright (C) 2004 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef JOBTEST_H
 #define JOBTEST_H
 
-#include <QString>
 #include <QObject>
+#include <QString>
 #include <kio/job.h>
 
 class JobTest : public QObject
@@ -29,7 +17,9 @@ class JobTest : public QObject
     Q_OBJECT
 
 public:
-    JobTest() {}
+    JobTest()
+    {
+    }
 
 private Q_SLOTS:
     void initTestCase();
@@ -47,8 +37,10 @@ private Q_SLOTS:
     void storedPutIODeviceSlowDeviceBigChunk();
     void asyncStoredPutReadyReadAfterFinish();
     void copyFileToSamePartition();
+    void testCopyFilePermissionsToSamePartition();
     void copyDirectoryToSamePartition();
     void copyDirectoryToExistingDirectory();
+    void copyDirectoryToExistingSymlinkedDirectory();
     void copyFileToOtherPartition();
     void copyDirectoryToOtherPartition();
     void copyRelativeSymlinkToSamePartition();
@@ -83,10 +75,15 @@ private Q_SLOTS:
     void rmdirEmpty();
     void rmdirNotEmpty();
     void stat();
+    void statDetailsBasic();
+    void statDetailsBasicSetDetails();
+    void statWithInode();
 #ifndef Q_OS_WIN
     void statSymlink();
+    void statTimeResolution();
 #endif
     void mostLocalUrl();
+    void mostLocalUrlHttp();
     void chmodFile();
 #ifdef Q_OS_UNIX
     void chmodSticky();
@@ -95,14 +92,20 @@ private Q_SLOTS:
     void mimeType();
     void mimeTypeError();
     void calculateRemainingSeconds();
+    void moveFileDestAlreadyExists_data();
     void moveFileDestAlreadyExists();
+    void copyFileDestAlreadyExists_data();
+    void copyFileDestAlreadyExists();
     void moveDestAlreadyExistsAutoRename_data();
     void moveDestAlreadyExistsAutoRename();
 
     void copyDirectoryAlreadyExistsSkip();
+    void copyFileAlreadyExistsRename();
 
     void safeOverwrite();
     void safeOverwrite_data();
+    void overwriteOlderFiles();
+    void overwriteOlderFiles_data();
     void moveAndOverwrite();
     void moveOverSymlinkToSelf();
     void createSymlink();
@@ -117,10 +120,12 @@ private Q_SLOTS:
     void cancelCopyAndCleanDest_data();
 
     // Remote tests
-    //void copyFileToSystem();
+    // void copyFileToSystem();
 
     void getInvalidUrl();
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 84)
     void multiGet();
+#endif
 
 Q_SIGNALS:
     void exitLoop();
@@ -136,10 +141,14 @@ private:
     void enterLoop();
     enum { AlreadyExists = 1 };
     void copyLocalFile(const QString &src, const QString &dest);
+    bool checkXattrFsSupport(const QString &writeTest);
+    bool setXattr(const QString &src);
+    QList<QByteArray> readXattr(const QString &src);
+    void compareXattr(const QString &src, const QString &dest);
     void copyLocalDirectory(const QString &src, const QString &dest, int flags = 0);
     void moveLocalFile(const QString &src, const QString &dest);
     void moveLocalDirectory(const QString &src, const QString &dest);
-    //void copyFileToSystem( bool resolve_local_urls );
+    // void copyFileToSystem( bool resolve_local_urls );
     void deleteSymlink(bool using_fast_path);
     void deleteManyDirs(bool using_fast_path);
     void deleteManyFilesTogether(bool using_fast_path);
@@ -150,6 +159,9 @@ private:
     QStringList m_names;
     int m_dataReqCount;
     QString m_mimetype;
+    QString m_setXattrCmd;
+    QString m_getXattrCmd;
+    std::function<QStringList(const QString &, const QString &, const QString &)> m_setXattrFormatArgs;
 };
 
 #endif
