@@ -1569,6 +1569,24 @@ void KDirListerTest::testDeleteCurrentDir()
     QVERIFY(deletedUrls.contains(currentDirUrl));
 }
 
+void KDirListerTest::testForgetDir()
+{
+    QTemporaryDir tempDir(homeTmpDir());
+    QString path = tempDir.path() + QLatin1Char('/');
+    createTestFile(path + "/file_1");
+
+    QSignalSpy spyCompleted(&m_dirLister, qOverload<>(&KCoreDirLister::completed));
+
+    m_dirLister.openUrl(QUrl::fromLocalFile(path), KDirLister::Keep);
+    QVERIFY(spyCompleted.wait());
+
+    m_dirLister.forgetDirs(QUrl::fromLocalFile(path));
+
+    QSignalSpy addedSpy(&m_dirLister, &MyDirLister::itemsAdded);
+    createTestFile(path + "/file_2");
+    QVERIFY(!addedSpy.wait(1000)); // to allow for KDirWatch's internal 500ms timer
+}
+
 int KDirListerTest::fileCount() const
 {
     return QDir(tempPath()).entryList(QDir::AllEntries | QDir::NoDotAndDotDot).count();
