@@ -5,6 +5,8 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include <array>
+
 #include "kdirmodeltest.h"
 #include "jobuidelegatefactory.h"
 #include <KDirWatch>
@@ -19,7 +21,6 @@
 #include <QDebug>
 #include <QMimeData>
 #include <QSignalSpy>
-#include <QTest>
 #include <QUrl>
 
 #ifdef Q_OS_UNIX
@@ -34,11 +35,14 @@ QTEST_MAIN(KDirModelTest)
 #define exitLoop quit
 #endif
 
+static QString specialChars()
+{
 #ifndef Q_OS_WIN
-#define SPECIALCHARS " special chars%:.pdf"
+    return QStringLiteral(" special chars%:.pdf");
 #else
-#define SPECIALCHARS " special chars%.pdf"
+    return QStringLiteral(" special chars%.pdf");
 #endif
+}
 
 Q_DECLARE_METATYPE(KFileItemList)
 
@@ -48,13 +52,14 @@ void KDirModelTest::initTestCase()
     // To avoid a runtime dependency on klauncher
     qputenv("KDE_FORK_SLAVES", "yes");
 
+    QStandardPaths::setTestModeEnabled(true);
+
     qRegisterMetaType<KFileItemList>("KFileItemList");
 
     m_dirModelForExpand = nullptr;
     m_dirModel = nullptr;
     s_referenceTimeStamp = QDateTime::currentDateTime().addSecs(-30); // 30 seconds ago
-    m_tempDir = nullptr;
-    m_topLevelFileNames << QStringLiteral("toplevelfile_1") << QStringLiteral("toplevelfile_2") << QStringLiteral("toplevelfile_3") << SPECIALCHARS;
+    m_topLevelFileNames << QStringLiteral("toplevelfile_1") << QStringLiteral("toplevelfile_2") << QStringLiteral("toplevelfile_3") << specialChars();
     recreateTestData();
 
     fillModel(false);
@@ -64,11 +69,11 @@ void KDirModelTest::recreateTestData()
 {
     if (m_tempDir) {
         qDebug() << "Deleting old tempdir" << m_tempDir->path();
-        delete m_tempDir;
+        m_tempDir.reset();
         qApp->processEvents(); // process inotify events so they don't pollute us later on
     }
 
-    m_tempDir = new QTemporaryDir;
+    m_tempDir = std::make_unique<QTemporaryDir>(homeTmpDir());
     qDebug() << "new tmp dir:" << m_tempDir->path();
     // Create test data:
     /*
@@ -95,7 +100,7 @@ void KDirModelTest::recreateTestData()
      * PATH/subdir/hasChildren/pipeDir/pipe
      */
     const QString path = m_tempDir->path() + '/';
-    for (const QString &f : qAsConst(m_topLevelFileNames)) {
+    for (const QString &f : std::as_const(m_topLevelFileNames)) {
         createTestFile(path + f);
     }
     createTestFile(path + ".hiddenfile");
@@ -120,10 +125,11 @@ void KDirModelTest::recreateTestData()
 
 void KDirModelTest::cleanupTestCase()
 {
-    delete m_tempDir;
-    m_tempDir = nullptr;
+    m_tempDir.reset();
+
     delete m_dirModel;
     m_dirModel = nullptr;
+
     delete m_dirModelForExpand;
     m_dirModelForExpand = nullptr;
 }
@@ -133,19 +139,19 @@ void KDirModelTest::fillModel(bool reload, bool expectAllIndexes)
     if (!m_dirModel) {
         m_dirModel = new KDirModel;
     }
-    m_dirModel->dirLister()->setAutoErrorHandlingEnabled(false, nullptr);
+    m_dirModel->dirLister()->setAutoErrorHandlingEnabled(false);
     const QString path = m_tempDir->path() + '/';
     KDirLister *dirLister = m_dirModel->dirLister();
     qDebug() << "Calling openUrl";
     m_dirModel->openUrl(QUrl::fromLocalFile(path), reload ? KDirModel::Reload : KDirModel::NoFlags);
-    connect(dirLister, QOverload<>::of(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    connect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
     qDebug() << "enterLoop, waiting for completed()";
     enterLoop();
 
     if (expectAllIndexes) {
         collectKnownIndexes();
     }
-    disconnect(dirLister, QOverload<>::of(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    disconnect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
 }
 
 // Called after test function
@@ -312,7 +318,7 @@ void KDirModelTest::testNames()
     QCOMPARE(fileName, QString("toplevelfile_1"));
 
     QString specialFileName = m_dirModel->data(m_specialFileIndex, Qt::DisplayRole).toString();
-    QCOMPARE(specialFileName, QString(SPECIALCHARS));
+    QCOMPARE(specialFileName, specialChars());
 
     QString dirName = m_dirModel->data(m_dirIndex, Qt::DisplayRole).toString();
     QCOMPARE(dirName, QString("subdir"));
@@ -406,6 +412,140 @@ void KDirModelTest::testData()
     QCOMPARE(m_dirModel->data(m_fileInSubdirIndex.parent(), KDirModel::ChildCountRole).toInt(), 1);
 }
 
+void KDirModelTest::testIcon()
+{
+    /**
+     * Create test data only used in testIcon()
+     * PATH/subdirwithcustomicon
+     * PATH/subdirwithcustomicon/.directory
+     * PATH/subdirwithcustomicon/exampleIcon.svg
+     * PATH/subdirwithcustomicon/subdirwithinvalidicon
+     * PATH/subdirwithcustomicon/subdirwithinvalidicon/.directory
+     * PATH/subdirwithcustomicon/subdirwithinvalidsvgicon
+     * PATH/subdirwithcustomicon/subdirwithinvalidsvgicon/.directory
+     */
+    const QString path(m_tempDir->path() + '/');
+
+    const QString subdirWithCustomIconPath(path + "subdirwithcustomicon/");
+    createTestDirectory(path + "subdirwithcustomicon/", Empty);
+
+    const QString exampleIconPath = subdirWithCustomIconPath + "exampleIcon.svg";
+    const QByteArray exampleSvgIconContent(
+        "<svg version='1.1' width='100' height='100' xmlns='http://www.w3.org/2000/svg'>"
+        "<rect width='100%' height='100%' fill='red' />"
+        "</svg>");
+    const QByteArray directoryFileContent(
+        "[Desktop Entry]\n"
+        "Icon="
+        + exampleIconPath.toLatin1());
+
+    struct Entry {
+        bool isDir;
+        QString name;
+        QByteArray content;
+    };
+
+    const std::array<Entry, 4> topLevelContent{{
+        {false, exampleIconPath, exampleSvgIconContent},
+        {false, subdirWithCustomIconPath + ".directory", directoryFileContent},
+        {true, subdirWithCustomIconPath + "subdirwithinvalidicon", QByteArray()},
+        {true, subdirWithCustomIconPath + "subdirwithinvalidsvgicon", QByteArray()},
+    }};
+
+    for (const auto &entry : topLevelContent) {
+        if (entry.isDir) {
+            createTestDirectory(entry.name, Empty);
+        } else {
+            createTestFile(entry.name, false, entry.content);
+        }
+    }
+
+    // Add an extra suffix to the end of the path to make it become invalid
+    const QByteArray directoryFileWithInvalidIconContent(
+        "[Desktop Entry]\n"
+        "Icon="
+        + exampleIconPath.toLatin1() + ".png");
+    createTestFile(subdirWithCustomIconPath + "subdirwithinvalidicon/.directory", false, directoryFileWithInvalidIconContent);
+
+    // Add an extra ".svg" to the end of the path to make it become invalid
+    const QByteArray directoryFileWithInvalidSvgIconContent(
+        "[Desktop Entry]\n"
+        "Icon="
+        + exampleIconPath.toLatin1() + ".svg");
+    createTestFile(subdirWithCustomIconPath + "subdirwithinvalidsvgicon/.directory", false, directoryFileWithInvalidSvgIconContent);
+
+    // Refresh the directory after adding files
+    KDirLister *dirLister = m_dirModel->dirLister();
+    dirLister->openUrl(QUrl::fromLocalFile(path), KDirLister::Reload);
+    connect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    enterLoop();
+
+    QModelIndex dirWithIconIndex; // subdirwithcustomicon
+
+    for (int row = 0; row < m_topLevelFileNames.count() + 2 /*subdir, subdirwithinvalidicon*/; ++row) {
+        const QModelIndex idx = m_dirModel->index(row, 0, QModelIndex());
+        QVERIFY(idx.isValid());
+        const KFileItem item = m_dirModel->itemForIndex(idx);
+        if (item.isDir() && item.name() == QStringLiteral("subdirwithcustomicon")) {
+            dirWithIconIndex = idx;
+            break;
+        }
+    }
+
+    QVERIFY(dirWithIconIndex.isValid());
+
+    // Now list subdirwithcustomicon/
+    QVERIFY(m_dirModel->canFetchMore(dirWithIconIndex));
+    qDebug() << "Listing subdirwithcustomicon";
+    m_dirModel->fetchMore(dirWithIconIndex);
+    enterLoop();
+
+    // Indexes of files inside a directory
+    QModelIndex dirWithInvalidIconIndex; // subdirwithcustomicon/subdirwithinvalidicon
+    QModelIndex dirWithInvalidSvgIconIndex; // subdirwithcustomicon/subdirwithinvalidsvgicon
+
+    for (int row = 0; row < static_cast<int>(topLevelContent.size()); ++row) {
+        QModelIndex idx = m_dirModel->index(row, 0, dirWithIconIndex);
+        const KFileItem item = m_dirModel->itemForIndex(idx);
+        if (item.isDir()) {
+            if (item.name() == QLatin1String("subdirwithinvalidicon")) {
+                dirWithInvalidIconIndex = idx;
+            } else if (item.name() == QLatin1String("subdirwithinvalidsvgicon")) {
+                dirWithInvalidSvgIconIndex = idx;
+            }
+        }
+    }
+
+    QVERIFY(dirWithInvalidIconIndex.isValid());
+    QVERIFY(dirWithInvalidSvgIconIndex.isValid());
+
+    // Create an expected icon image
+    const QSize comparedSize(100, 100);
+    const QImage expectedIconImage = QIcon(exampleIconPath).pixmap(comparedSize).toImage();
+
+    // Test the custom icon is correctly loaded for the directory
+    const QIcon icon = m_dirModel->data(dirWithIconIndex, Qt::DecorationRole).value<QIcon>();
+    QCOMPARE(m_dirModel->itemForIndex(dirWithIconIndex).iconName(), exampleIconPath);
+    QVERIFY(icon.pixmap(comparedSize).toImage() == expectedIconImage);
+
+    // Test "unknown" icon will be used when the icon path refers to an invalid icon
+    const QIcon icon2 = m_dirModel->data(dirWithInvalidIconIndex, Qt::DecorationRole).value<QIcon>();
+    QCOMPARE(icon2.name(), "unknown");
+
+    // Test "unknown" icon will be used when the icon path refers to an invalid svg icon
+    const QIcon icon3 = m_dirModel->data(dirWithInvalidSvgIconIndex, Qt::DecorationRole).value<QIcon>();
+    QCOMPARE(icon3.name(), "unknown");
+
+    // Delete the folder
+    QDir dir(subdirWithCustomIconPath);
+    QVERIFY(dir.removeRecursively());
+
+    // Refresh the directory again after deleting the folder
+    dirLister->openUrl(QUrl::fromLocalFile(path), KDirLister::Reload);
+    connect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    enterLoop();
+}
+
 void KDirModelTest::testReload()
 {
     fillModel(true);
@@ -503,7 +643,7 @@ void KDirModelTest::testMoveDirectory(const QString &dir /*just a dir name, no s
     const QString path = m_tempDir->path() + '/';
     const QString srcdir = path + dir;
     QVERIFY(QDir(srcdir).exists());
-    QTemporaryDir destDir;
+    QTemporaryDir destDir(homeTmpDir());
     const QString dest = destDir.path() + '/';
     QVERIFY(QDir(dest).exists());
 
@@ -553,7 +693,7 @@ void KDirModelTest::testRenameDirectory() // #172945, #174703, (and #180156)
     delete m_dirModelForExpand;
     m_dirModelForExpand = new KDirModel;
     KDirLister *dirListerForExpand = m_dirModelForExpand->dirLister();
-    connect(dirListerForExpand, QOverload<>::of(&KDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    connect(dirListerForExpand, qOverload<>(&KDirLister::completed), this, &KDirModelTest::slotListingCompleted);
     dirListerForExpand->openUrl(url); // async
     enterLoop();
 
@@ -664,9 +804,7 @@ void KDirModelTest::testChmodDirectory() // #53397
     // QVERIFY(origPerm & QFile::ReadOwner);
     // const QFile::Permissions newPerm = origPerm ^ QFile::WriteGroup;
     QVERIFY(newPerm != origPerm);
-    KFileItemList items;
-    items << rootItem;
-    KIO::Job *job = KIO::chmod(items, newPerm, S_IWGRP /*TODO: QFile::WriteGroup*/, QString(), QString(), false, KIO::HideProgressInfo);
+    KIO::Job *job = KIO::chmod({rootItem}, newPerm, S_IWGRP /*TODO: QFile::WriteGroup*/, QString(), QString(), false, KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     QVERIFY(job->exec());
     // ChmodJob doesn't talk to KDirNotify, kpropertiesdialog does.
@@ -678,7 +816,7 @@ void KDirModelTest::testChmodDirectory() // #53397
     // If we come here, then dataChanged() was emitted - all good.
     QCOMPARE(spyDataChanged.count(), 1);
     QModelIndex receivedIndex = spyDataChanged[0][0].value<QModelIndex>();
-    qDebug() << receivedIndex;
+    qDebug() << "receivedIndex" << receivedIndex;
     QVERIFY(!receivedIndex.isValid());
 
     const KFileItem newRootItem = m_dirModel->itemForIndex(QModelIndex());
@@ -754,13 +892,13 @@ void KDirModelTest::testExpandToUrl()
     if (flags & CacheSubdir) {
         // This way, the listDir for subdir will find items in cache, and will schedule a CachedItemsJob
         m_dirModel->dirLister()->openUrl(QUrl::fromLocalFile(path + "subdir"));
-        QSignalSpy completedSpy(m_dirModel->dirLister(), QOverload<>::of(&KCoreDirLister::completed));
+        QSignalSpy completedSpy(m_dirModel->dirLister(), qOverload<>(&KCoreDirLister::completed));
         QVERIFY(completedSpy.wait(2000));
     }
     if (flags & ListFinalDir) {
         // This way, the last listDir will find items in cache, and will schedule a CachedItemsJob
         m_dirModel->dirLister()->openUrl(QUrl::fromLocalFile(path + "subdir/subsubdir"));
-        QSignalSpy completedSpy(m_dirModel->dirLister(), QOverload<>::of(&KCoreDirLister::completed));
+        QSignalSpy completedSpy(m_dirModel->dirLister(), qOverload<>(&KCoreDirLister::completed));
         QVERIFY(completedSpy.wait(2000));
     }
 
@@ -912,6 +1050,48 @@ void KDirModelTest::testFilter()
     fillModel(true);
 }
 
+void KDirModelTest::testFilterPatterns()
+{
+    QVERIFY(m_dirIndex.isValid());
+
+    const int oldTopLevelRowCount = m_dirModel->rowCount();
+    const int oldSubdirRowCount = m_dirModel->rowCount(m_dirIndex);
+
+    m_dirModel->dirLister()->setNameFilter(QStringLiteral("toplevel"));
+    QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount); // no change yet
+    QCOMPARE(m_dirModel->rowCount(m_dirIndex), oldSubdirRowCount); // no change yet
+    m_dirModel->dirLister()->emitChanges();
+
+    QCOMPARE(m_dirModel->rowCount(), 4); // 3 files, one subdir with "toplevel" in the name
+    QCOMPARE(m_dirModel->rowCount(m_dirIndex), 2); // the files get filtered out, subsubdir and hasChildren are remaining
+
+    // Reset the filter
+    m_dirModel->dirLister()->setNameFilter(QString());
+    m_dirModel->dirLister()->emitChanges();
+
+    // Back to original state
+    QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount);
+    QCOMPARE(m_dirModel->rowCount(m_dirIndex), oldSubdirRowCount);
+
+    m_dirModel->dirLister()->setNameFilter(QStringLiteral("toplevel*")); // Matching with a wildcard
+    QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount); // no change yet
+    QCOMPARE(m_dirModel->rowCount(m_dirIndex), oldSubdirRowCount); // no change yet
+    m_dirModel->dirLister()->emitChanges();
+
+    QCOMPARE(m_dirModel->rowCount(), 4); // 3 files, one subdir with "toplevel*" in the name
+    QCOMPARE(m_dirModel->rowCount(m_dirIndex), 2); // the files get filtered out, subsubdir and hasChildren are remaining
+
+    m_dirModel->dirLister()->setNameFilter(QString());
+    m_dirModel->dirLister()->emitChanges();
+
+    QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount);
+    QCOMPARE(m_dirModel->rowCount(m_dirIndex), oldSubdirRowCount);
+
+    // The order of things changed because of filtering.
+    // Fill again, so that m_fileIndex etc. are correct again.
+    fillModel(true);
+}
+
 void KDirModelTest::testMimeFilter()
 {
     QVERIFY(m_dirIndex.isValid());
@@ -998,12 +1178,12 @@ void KDirModelTest::testUrlWithRef() // #171117
     url.setFragment(QStringLiteral("ref"));
     QVERIFY(url.url().endsWith(QLatin1String("#ref")));
     dirLister->openUrl(url, KDirLister::NoFlags);
-    connect(dirLister, QOverload<>::of(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    connect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
     enterLoop();
 
     QCOMPARE(dirLister->url().toString(), url.toString(QUrl::StripTrailingSlash));
     collectKnownIndexes();
-    disconnect(dirLister, QOverload<>::of(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    disconnect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
 }
 
 // void KDirModelTest::testFontUrlWithHost() // #160057 --> moved to kio_fonts (kfontinst/kio/autotests)
@@ -1016,7 +1196,7 @@ void KDirModelTest::testRemoteUrlWithHost() // #178416
     QUrl url(QStringLiteral("remote://foo"));
     KDirLister *dirLister = m_dirModel->dirLister();
     dirLister->openUrl(url, KDirLister::NoFlags);
-    connect(dirLister, QOverload<>::of(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    connect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
     enterLoop();
 
     QCOMPARE(dirLister->url().toString(), QString("remote://foo"));
@@ -1027,9 +1207,9 @@ void KDirModelTest::testZipFile() // # 171721
     const QString path = QFileInfo(QFINDTESTDATA("wronglocalsizes.zip")).absolutePath();
     KDirLister *dirLister = m_dirModel->dirLister();
     dirLister->openUrl(QUrl::fromLocalFile(path), KDirLister::NoFlags);
-    connect(dirLister, QOverload<>::of(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    connect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
     enterLoop();
-    disconnect(dirLister, QOverload<>::of(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    disconnect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
 
     QUrl zipUrl(QUrl::fromLocalFile(path));
     zipUrl.setPath(zipUrl.path() + "/wronglocalsizes.zip"); // just a zip file lying here for other reasons
@@ -1091,7 +1271,7 @@ void KDirModelTest::testDotHiddenFile_data()
     const QStringList allItems{QStringLiteral("toplevelfile_1"),
                                QStringLiteral("toplevelfile_2"),
                                QStringLiteral("toplevelfile_3"),
-                               SPECIALCHARS,
+                               specialChars(),
                                QStringLiteral("subdir")};
     QTest::newRow("empty_file") << (QStringList{}) << allItems;
 
@@ -1099,7 +1279,7 @@ void KDirModelTest::testDotHiddenFile_data()
 
     QStringList allButSpecialChars = allItems;
     allButSpecialChars.removeAt(3);
-    QTest::newRow("special_chars") << (QStringList{SPECIALCHARS}) << allButSpecialChars;
+    QTest::newRow("special_chars") << (QStringList{specialChars()}) << allButSpecialChars;
 
     QStringList allButSubdir = allItems;
     allButSubdir.removeAt(4);
@@ -1107,7 +1287,7 @@ void KDirModelTest::testDotHiddenFile_data()
 
     QTest::newRow("many_lines")
         << (QStringList{QStringLiteral("subdir"), QStringLiteral("toplevelfile_1"), QStringLiteral("toplevelfile_3"), QStringLiteral("toplevelfile_2")})
-        << QStringList{SPECIALCHARS};
+        << QStringList{specialChars()};
 }
 
 void KDirModelTest::testDotHiddenFile()
@@ -1237,7 +1417,7 @@ void KDirModelTest::testHasChildren()
     QVERIFY(m_dirModel->hasChildren(m_dirIndex));
 
     auto listDir = [this](const QModelIndex &index) {
-        QSignalSpy completedSpy(m_dirModel->dirLister(), QOverload<>::of(&KDirLister::completed));
+        QSignalSpy completedSpy(m_dirModel->dirLister(), qOverload<>(&KDirLister::completed));
         m_dirModel->fetchMore(index);
         return completedSpy.wait();
     };
@@ -1281,7 +1461,7 @@ void KDirModelTest::testHasChildren()
 
 void KDirModelTest::testInvalidUrl()
 {
-    QSignalSpy completedSpy(m_dirModel->dirLister(), QOverload<>::of(&KCoreDirLister::completed));
+    QSignalSpy completedSpy(m_dirModel->dirLister(), qOverload<>(&KCoreDirLister::completed));
     m_dirModel->openUrl(QUrl(":/"));
     // currently ends up in KCoreDirLister::handleError. TODO: add error signal to KDirModel
 }
@@ -1336,8 +1516,8 @@ void KDirModelTest::testDeleteFileWhileListing() // doesn't really test that yet
     const QUrl url = QUrl::fromLocalFile(file);
 
     KDirLister *dirLister = m_dirModel->dirLister();
-    QSignalSpy spyCompleted(dirLister, QOverload<>::of(&KCoreDirLister::completed));
-    connect(dirLister, QOverload<>::of(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
+    QSignalSpy spyCompleted(dirLister, qOverload<>(&KCoreDirLister::completed));
+    connect(dirLister, qOverload<>(&KCoreDirLister::completed), this, &KDirModelTest::slotListingCompleted);
     dirLister->openUrl(QUrl::fromLocalFile(path), KDirLister::NoFlags);
     if (!spyCompleted.isEmpty()) {
         QSKIP("listing completed too early");
