@@ -7,13 +7,16 @@
 #ifndef KDIRMODELTEST_H
 #define KDIRMODELTEST_H
 
+#include <kdirmodel.h>
+
+#include <QEventLoop>
 #include <QObject>
 #include <QTemporaryDir>
-#include <kdirmodel.h>
-#include <QEventLoop>
 #include <QTest>
 #include <QTestEventLoop>
 
+#include <memory>
+
 // If you disable this, you need to change all exitLoop into quit in connect() statements...
 #define USE_QTESTEVENTLOOP
 
@@ -30,6 +33,13 @@ private Q_SLOTS:
     void testItemForIndex();
     void testIndexForItem();
     void testData();
+
+    /**
+     * Test if the icon is valid if "Icon" is specified in the desktop file, and can fall back to "unknown"
+     * if KDirModel fails to load the icon.
+     */
+    void testIcon();
+
     void testReload();
     void testModifyFile();
     void testRenameFile();
@@ -40,6 +50,7 @@ private Q_SLOTS:
     void testExpandToUrl_data();
     void testExpandToUrl();
     void testFilter();
+    void testFilterPatterns();
     void testMimeFilter();
     void testShowHiddenFiles();
     void testMultipleSlashes();
@@ -55,6 +66,7 @@ private Q_SLOTS:
     void testShowRootAndExpandToUrl();
     void testHasChildren_data();
     void testHasChildren();
+    void testInvalidUrl();
 
     // These tests must be done last
     void testDeleteFile();
@@ -87,7 +99,7 @@ private:
 #else
     QEventLoop m_eventLoop;
 #endif
-    QTemporaryDir *m_tempDir;
+    std::unique_ptr<QTemporaryDir> m_tempDir;
     KDirModel *m_dirModel;
     QModelIndex m_fileIndex;
     QModelIndex m_specialFileIndex;
