@@ -6,24 +6,25 @@
 */
 
 #include "kfileitemtest.h"
-#include <kfileitemlistproperties.h>
 #include <QTest>
 #include <kfileitem.h>
+#include <kfileitemlistproperties.h>
 
+#include "kiotesthelper.h"
+#include <KConfigGroup>
+#include <KDesktopFile>
+#include <KUser>
 #include <QTemporaryDir>
 #include <QTemporaryFile>
-#include <KUser>
-#include <KDesktopFile>
-#include <KConfigGroup>
-#include "kiotesthelper.h"
 
-#include <QMimeDatabase>
 #include <KProtocolInfo>
+#include <QMimeDatabase>
 
 QTEST_MAIN(KFileItemTest)
 
 void KFileItemTest::initTestCase()
 {
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 void KFileItemTest::testPermissionsString()
@@ -202,7 +203,7 @@ void KFileItemTest::testMimeTypeOnDemand()
         QVERIFY(fileItem.currentMimeType().isDefault());
         QVERIFY(!fileItem.isMimeTypeKnown());
         QVERIFY(!fileItem.isFinalIconKnown());
-        //qDebug() << fileItem.determineMimeType().name();
+        // qDebug() << fileItem.determineMimeType().name();
         QCOMPARE(fileItem.determineMimeType().name(), QStringLiteral("application/x-zerosize"));
         QCOMPARE(fileItem.mimetype(), QStringLiteral("application/x-zerosize"));
         QVERIFY(fileItem.isMimeTypeKnown());
@@ -210,7 +211,7 @@ void KFileItemTest::testMimeTypeOnDemand()
     }
 
     {
-        // Calling mimeType directly also does mimetype determination
+        // Calling mimeType directly also does MIME type determination
         KFileItem fileItem(QUrl::fromLocalFile(file.fileName()));
         fileItem.setDelayedMimeTypes(true);
         QVERIFY(!fileItem.isMimeTypeKnown());
@@ -219,7 +220,7 @@ void KFileItemTest::testMimeTypeOnDemand()
     }
 
     {
-        // Calling overlays should NOT do mimetype determination (#237668)
+        // Calling overlays should NOT do MIME type determination (#237668)
         KFileItem fileItem(QUrl::fromLocalFile(file.fileName()));
         fileItem.setDelayedMimeTypes(true);
         QVERIFY(!fileItem.isMimeTypeKnown());
@@ -262,7 +263,7 @@ void KFileItemTest::testMimeTypeOnDemand()
         QCOMPARE(fileItem.determineMimeType().name(), QStringLiteral("text/plain"));
         QCOMPARE(fileItem.mimetype(), QStringLiteral("text/plain"));
 
-        // And if the mimetype is not on demand?
+        // And if the MIME type is not on demand?
         KFileItem fileItem2(QUrl::fromLocalFile(fileName));
         QCOMPARE(fileItem2.currentMimeType().name(), QStringLiteral("text/plain")); // XDG says: application/smil; but can't sniff all files so this can't work
         QVERIFY(fileItem2.isMimeTypeKnown());
@@ -313,7 +314,7 @@ void KFileItemTest::testCmpAndInit()
 void KFileItemTest::testCmpByUrl()
 {
     const QUrl nulUrl;
-    const QUrl url  = QUrl::fromLocalFile(QStringLiteral("1foo"));
+    const QUrl url = QUrl::fromLocalFile(QStringLiteral("1foo"));
     const QUrl url2 = QUrl::fromLocalFile(QStringLiteral("fo1"));
     const QUrl url3 = QUrl::fromLocalFile(QStringLiteral("foo"));
     KFileItem nulFileItem;
@@ -402,8 +403,7 @@ void KFileItemTest::testRefresh()
     // ...but it looks like the kernel rounds up when the msecs are .998 or .999,
     // so add a bit of tolerance
     auto expectedLastModified = lastModified;
-    if (fileItem.time(KFileItem::ModificationTime) != lastModified &&
-            fileItem.time(KFileItem::ModificationTime) == lastModified.addSecs(1)) {
+    if (fileItem.time(KFileItem::ModificationTime) != lastModified && fileItem.time(KFileItem::ModificationTime) == lastModified.addSecs(1)) {
         expectedLastModified = expectedLastModified.addSecs(1);
     }
     QCOMPARE(fileItem.time(KFileItem::ModificationTime), expectedLastModified);
@@ -459,7 +459,7 @@ void KFileItemTest::testDotDirectory()
         QCOMPARE(fileItem.mimeComment(), QStringLiteral("com"));
         QCOMPARE(fileItem.iconName(), QStringLiteral("foo"));
     }
-    // Test for calling iconName first, to trigger mimetype resolution
+    // Test for calling iconName first, to trigger MIME type resolution
     {
         KFileItem fileItem(QUrl::fromLocalFile(tempDir.path()), QString(), KFileItem::Unknown);
         QVERIFY(fileItem.isLocalFile());
@@ -472,7 +472,8 @@ void KFileItemTest::testDecodeFileName_data()
     QTest::addColumn<QString>("filename");
     QTest::addColumn<QString>("expectedText");
 
-    QTest::newRow("simple") << "filename" << "filename";
+    QTest::newRow("simple") << "filename"
+                            << "filename";
     QTest::newRow("/ at end") << QString(QStringLiteral("foo") + QChar(0x2044)) << QString(QStringLiteral("foo") + QChar(0x2044));
     QTest::newRow("/ at begin") << QString(QChar(0x2044)) << QString(QChar(0x2044));
 }
@@ -489,7 +490,8 @@ void KFileItemTest::testEncodeFileName_data()
     QTest::addColumn<QString>("text");
     QTest::addColumn<QString>("expectedFileName");
 
-    QTest::newRow("simple") << "filename" << "filename";
+    QTest::newRow("simple") << "filename"
+                            << "filename";
     QTest::newRow("/ at end") << "foo/" << QString(QStringLiteral("foo") + QChar(0x2044));
     QTest::newRow("/ at begin") << "/" << QString(QChar(0x2044));
 }
@@ -512,6 +514,7 @@ void KFileItemTest::testListProperties_data()
     QTest::addColumn<QString>("expectedMimeType");
     QTest::addColumn<QString>("expectedMimeGroup");
 
+    /* clang-format off */
     QTest::newRow("one file") << "f" << true << true << true << false << true << "text/plain" << "text";
     QTest::newRow("one dir") << "d" << true << true << true << true << false << "inode/directory" << "inode";
     QTest::newRow("root dir") << "/" << true << false << true << true << false << "inode/directory" << "inode";
@@ -520,10 +523,9 @@ void KFileItemTest::testListProperties_data()
     QTest::newRow("dir+root dir") << "d/" << true << false << true << true << false << "inode/directory" << "inode";
     QTest::newRow("two (text+html) files") << "ff" << true << true << true << false << true << "" << "text";
     QTest::newRow("three (text+html+empty) files") << "fff" << true << true << true << false << true << "" << "";
-    QTest::newRow("http url") << "h" << true << true /*says kio_http...*/
-                              << false << false << true << "application/octet-stream" << "application";
-    QTest::newRow("2 http urls") << "hh" << true << true /*says kio_http...*/
-                                 << false << false << true << "application/octet-stream" << "application";
+    QTest::newRow("http url") << "h" << true << true /*says kio_http...*/ << false << false << true << "application/octet-stream" << "application";
+    QTest::newRow("2 http urls") << "hh" << true << true /*says kio_http...*/ << false << false << true << "application/octet-stream" << "application";
+    /* clang-format on */
 }
 
 void KFileItemTest::testListProperties()
@@ -556,15 +558,16 @@ void KFileItemTest::testListProperties()
             } // i == 2: leave the file empty
             file.close();
             KFileItem item(QUrl::fromLocalFile(fileName), QString(), KFileItem::Unknown);
-            if (i == 0)
+            if (i == 0) {
                 QCOMPARE(item.mimetype(), "text/plain");
-            else if (i == 1)
+            } else if (i == 1) {
                 QCOMPARE(item.mimetype(), "text/html");
-            else if (i == 2)
+            } else if (i == 2) {
                 QCOMPARE(item.mimetype(), "application/x-zerosize");
+            }
             items.push_back(std::move(item));
+            break;
         }
-        break;
         case 'd':
             QVERIFY(baseDir.mkdir(fileName));
             items << KFileItem(QUrl::fromLocalFile(fileName), QString(), KFileItem::Unknown);
@@ -754,8 +757,14 @@ class PermissionRestorer
 {
     Q_DISABLE_COPY(PermissionRestorer)
 public:
-    explicit PermissionRestorer(const QString& path) : m_path(path) {}
-    ~PermissionRestorer()  { restore(); }
+    explicit PermissionRestorer(const QString &path)
+        : m_path(path)
+    {
+    }
+    ~PermissionRestorer()
+    {
+        restore();
+    }
 
     inline void restore()
     {
@@ -767,6 +776,7 @@ public:
         file.remove();
 #endif
     }
+
 private:
     const QString m_path;
 };
