@@ -5,10 +5,10 @@
     SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#include <kurlrequester.h>
-#include <kfilewidget.h>
-#include <kdiroperator.h>
 #include <KComboBox>
+#include <kdiroperator.h>
+#include <kfilewidget.h>
+#include <kurlrequester.h>
 
 #include <QLineEdit>
 #include <QSignalSpy>
@@ -32,7 +32,8 @@ private Q_SLOTS:
     void testComboRequester_data();
 
 private:
-    bool createTestFile(const QString &fileName) {
+    bool createTestFile(const QString &fileName)
+    {
         QFile file(fileName);
         if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
             return false;
@@ -56,7 +57,6 @@ static KFileWidget *findFileWidget()
     return (widgets.count() == 1) ? widgets.first() : nullptr;
 }
 
-
 void KUrlRequesterTest::initTestCase()
 {
     qputenv("KDE_FORK_SLAVES", "yes");
@@ -112,7 +112,7 @@ void KUrlRequesterTest::testUrlRequester()
     QVERIFY(fileDialog);
     fw = findFileWidget();
     if (fw) { // no need to wait for dir listing again, but we need it to be visible at least (for Key_Return to accept)
-        //QVERIFY(QTest::qWaitForWindowExposed(fw->window())); // doesn't seem to be enough
+        // QVERIFY(QTest::qWaitForWindowExposed(fw->window())); // doesn't seem to be enough
         QTRY_VERIFY(fw->isVisible());
     }
 
@@ -138,8 +138,11 @@ void KUrlRequesterTest::testComboRequester()
 
     QSignalSpy textSpy(&req, &KUrlComboRequester::textChanged);
     QSignalSpy editSpy(&req, &KUrlComboRequester::textEdited);
-    QSignalSpy returnSpy(&req, QOverload<>::of(&KUrlComboRequester::returnPressed));
-    QSignalSpy returnWithTextSpy(&req, QOverload<const QString&>::of(&KUrlComboRequester::returnPressed));
+
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 80)
+    QSignalSpy returnSpy(&req, qOverload<>(&KUrlComboRequester::returnPressed));
+#endif
+    QSignalSpy returnWithTextSpy(&req, qOverload<const QString &>(&KUrlComboRequester::returnPressed));
 
     QVERIFY(!req.comboBox()->isEditable());
     if (editable) {
@@ -152,10 +155,16 @@ void KUrlRequesterTest::testComboRequester()
         QCOMPARE(textSpy.last().first().toString(), text);
         QCOMPARE(editSpy.last().first().toString(), text);
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 80)
         QCOMPARE(returnSpy.size(), 0);
+#endif
         QCOMPARE(returnWithTextSpy.size(), 0);
+
         QTest::keyEvent(QTest::Click, req.comboBox(), Qt::Key_Return);
+
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 80)
         QCOMPARE(returnSpy.size(), 1);
+#endif
         QCOMPARE(returnWithTextSpy.size(), 1);
         QCOMPARE(returnWithTextSpy.last().first().toString(), text);
     } else {
@@ -174,7 +183,10 @@ void KUrlRequesterTest::testComboRequester()
 
         // only editable combo boxes get the edit and return signals emitted
         QCOMPARE(editSpy.size(), 0);
+
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 80)
         QCOMPARE(returnSpy.size(), 0);
+#endif
         QCOMPARE(returnWithTextSpy.size(), 0);
     }
 }
