@@ -1,22 +1,10 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                       David Faure <faure@kde.org>
-                       Waldo Bastian <bastian@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000 Waldo Bastian <bastian@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "chmodjob.h"
@@ -24,18 +12,18 @@
 
 #include <KLocalizedString>
 #include <KUser>
-#include <QLinkedList>
 #include <QDebug>
 
-
-#include "listjob.h"
+#include "askuseractioninterface.h"
 #include "job_p.h"
 #include "jobuidelegatefactory.h"
 #include "kioglobal_p.h"
+#include "listjob.h"
+
+#include <stack>
 
 namespace KIO
 {
-
 struct ChmodInfo {
     QUrl url;
     int permissions;
@@ -43,14 +31,13 @@ struct ChmodInfo {
 
 enum ChmodJobState {
     CHMODJOB_STATE_LISTING,
-    CHMODJOB_STATE_CHMODING
+    CHMODJOB_STATE_CHMODING,
 };
 
-class ChmodJobPrivate: public KIO::JobPrivate
+class ChmodJobPrivate : public KIO::JobPrivate
 {
 public:
-    ChmodJobPrivate(const KFileItemList &lstItems, int permissions, int mask,
-                    KUserId newOwner, KGroupId newGroup, bool recursive)
+    ChmodJobPrivate(const KFileItemList &lstItems, int permissions, int mask, KUserId newOwner, KGroupId newGroup, bool recursive)
         : state(CHMODJOB_STATE_LISTING)
         , m_permissions(permissions)
         , m_mask(mask)
@@ -70,7 +57,7 @@ public:
     bool m_recursive;
     bool m_bAutoSkipFiles;
     KFileItemList m_lstItems;
-    QLinkedList<ChmodInfo> m_infos; // linkedlist since we keep removing the first item
+    std::stack<ChmodInfo> m_infos;
 
     void _k_chmodNextFile();
     void _k_slotEntries(KIO::Job *, const KIO::UDSEntryList &);
@@ -78,11 +65,10 @@ public:
 
     Q_DECLARE_PUBLIC(ChmodJob)
 
-    static inline ChmodJob *newJob(const KFileItemList &lstItems, int permissions, int mask,
-                                   KUserId newOwner, KGroupId newGroup, bool recursive, JobFlags flags)
+    static inline ChmodJob *
+    newJob(const KFileItemList &lstItems, int permissions, int mask, KUserId newOwner, KGroupId newGroup, bool recursive, JobFlags flags)
     {
-        ChmodJob *job = new ChmodJob(*new ChmodJobPrivate(lstItems, permissions, mask,
-                                     newOwner, newGroup, recursive));
+        ChmodJob *job = new ChmodJob(*new ChmodJobPrivate(lstItems, permissions, mask, newOwner, newGroup, recursive));
         job->setUiDelegate(KIO::createDefaultJobUiDelegate());
         if (!(flags & HideProgressInfo)) {
             KIO::getJobTracker()->registerJob(job);
@@ -127,21 +113,22 @@ void ChmodJobPrivate::_k_processList()
                           << "\n with ~mask (mask bits we keep) =" << QString::number((uint)~m_mask,8)
                           << "\n bits we keep =" << QString::number(permissions & ~m_mask,8)
                           << "\n new permissions = " << QString::number(info.permissions,8);*/
-            m_infos.prepend(info);
-            //qDebug() << "processList : Adding info for " << info.url;
+            m_infos.push(std::move(info));
+            // qDebug() << "processList : Adding info for " << info.url;
             // Directory and recursive -> list
             if (item.isDir() && m_recursive) {
-                //qDebug() << "ChmodJob::processList dir -> listing";
+                // qDebug() << "ChmodJob::processList dir -> listing";
                 KIO::ListJob *listJob = KIO::listRecursive(item.url(), KIO::HideProgressInfo);
-                q->connect(listJob, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
-                           SLOT(_k_slotEntries(KIO::Job*,KIO::UDSEntryList)));
+                q->connect(listJob, &KIO::ListJob::entries, q, [this](KIO::Job *job, const KIO::UDSEntryList &entries) {
+                    _k_slotEntries(job, entries);
+                });
                 q->addSubjob(listJob);
                 return; // we'll come back later, when this one's finished
             }
         }
         m_lstItems.removeFirst();
     }
-    //qDebug() << "ChmodJob::processList -> going to STATE_CHMODING";
+    // qDebug() << "ChmodJob::processList -> going to STATE_CHMODING";
     // We have finished, move on
     state = CHMODJOB_STATE_CHMODING;
     _k_chmodNextFile();
@@ -156,8 +143,7 @@ void ChmodJobPrivate::_k_slotEntries(KIO::Job *, const KIO::UDSEntryList &list)
         const bool isLink = !entry.stringValue(KIO::UDSEntry::UDS_LINK_DEST).isEmpty();
         const QString relativePath = entry.stringValue(KIO::UDSEntry::UDS_NAME);
         if (!isLink && relativePath != QLatin1String("..")) {
-            const mode_t permissions = entry.numberValue(KIO::UDSEntry::UDS_ACCESS)
-                                       & 0777; // get rid of "set gid" and other special flags
+            const mode_t permissions = entry.numberValue(KIO::UDSEntry::UDS_ACCESS) & 0777; // get rid of "set gid" and other special flags
 
             ChmodInfo info;
             info.url = m_lstItems.first().url(); // base directory
@@ -184,9 +170,9 @@ void ChmodJobPrivate::_k_slotEntries(KIO::Job *, const KIO::UDSEntryList &list)
                           << "\n with ~mask (mask bits we keep) =" << QString::number((uint)~mask,8)
                           << "\n bits we keep =" << QString::number(permissions & ~mask,8)
                           << "\n new permissions = " << QString::number(info.permissions,8);*/
-            // Prepend this info in our todo list.
+            // Push this info on top of the stack so it's handled first.
             // This way, the toplevel dirs are done last.
-            m_infos.prepend(info);
+            m_infos.push(std::move(info));
         }
     }
 }
@@ -194,46 +180,59 @@ void ChmodJobPrivate::_k_slotEntries(KIO::Job *, const KIO::UDSEntryList &list)
 void ChmodJobPrivate::_k_chmodNextFile()
 {
     Q_Q(ChmodJob);
-    if (!m_infos.isEmpty()) {
-        ChmodInfo info = m_infos.takeFirst();
+    if (!m_infos.empty()) {
+        ChmodInfo info = m_infos.top();
+        m_infos.pop();
         // First update group / owner (if local file)
-        // (permissions have to set after, in case of suid and sgid)
+        // (permissions have to be set after, in case of suid and sgid)
         if (info.url.isLocalFile() && (m_newOwner.isValid() || m_newGroup.isValid())) {
             QString path = info.url.toLocalFile();
             if (!KIOPrivate::changeOwnership(path, m_newOwner, m_newGroup)) {
-                if (!m_uiDelegateExtension) {
-                    emit q->warning(q, i18n("Could not modify the ownership of file %1", path));
+                auto *askUserActionInterface = KIO::delegateExtension<AskUserActionInterface *>(q);
+                if (!askUserActionInterface) {
+                    Q_EMIT q->warning(q, i18n("Could not modify the ownership of file %1", path));
                 } else if (!m_bAutoSkipFiles) {
-                    const QString errMsg = i18n("<qt>Could not modify the ownership of file <b>%1</b>. You have insufficient access to the file to perform the change.</qt>", path);
                     SkipDialog_Options options;
-                    if (m_infos.count() > 1) {
+                    if (m_infos.size() > 1) {
                         options |= SkipDialog_MultipleItems;
                     }
-                    const SkipDialog_Result skipResult = m_uiDelegateExtension->askSkip(q, options, errMsg);
-                    switch (skipResult) {
-                    case Result_AutoSkip:
-                        m_bAutoSkipFiles = true;
-                    // fall through
-                        Q_FALLTHROUGH();
-                    case Result_Skip:
-                        QMetaObject::invokeMethod(q, "_k_chmodNextFile", Qt::QueuedConnection);
-                        return;
-                    case Result_Retry:
-                        m_infos.prepend(info);
-                        QMetaObject::invokeMethod(q, "_k_chmodNextFile", Qt::QueuedConnection);
-                        return;
-                    case Result_Cancel:
-                    default:
-                        q->setError(ERR_USER_CANCELED);
-                        q->emitResult();
-                        return;
-                    }
+
+                    auto skipSignal = &AskUserActionInterface::askUserSkipResult;
+                    q->connect(askUserActionInterface, skipSignal, q, [=](KIO::SkipDialog_Result result, KJob *parentJob) {
+                        Q_ASSERT(q == parentJob);
+                        q->disconnect(askUserActionInterface, skipSignal, q, nullptr);
+
+                        switch (result) {
+                        case Result_AutoSkip:
+                            m_bAutoSkipFiles = true;
+                            // fall through
+                            Q_FALLTHROUGH();
+                        case Result_Skip:
+                            QMetaObject::invokeMethod(q, "_k_chmodNextFile", Qt::QueuedConnection);
+                            return;
+                        case Result_Retry:
+                            m_infos.push(std::move(info));
+                            QMetaObject::invokeMethod(q, "_k_chmodNextFile", Qt::QueuedConnection);
+                            return;
+                        case Result_Cancel:
+                        default:
+                            q->setError(ERR_USER_CANCELED);
+                            q->emitResult();
+                            return;
+                        }
+                    });
+
+                    askUserActionInterface->askUserSkip(q,
+                                                        options,
+                                                        xi18n("Could not modify the ownership of file <filename>%1</filename>. You have "
+                                                              "insufficient access to the file to perform the change.",
+                                                              path));
+                    return;
                 }
             }
         }
 
-        /*qDebug() << "chmod'ing" << info.url
-                      << "to" << QString::number(info.permissions,8);*/
+        /*qDebug() << "chmod'ing" << info.url << "to" << QString::number(info.permissions,8);*/
         KIO::SimpleJob *job = KIO::chmod(info.url, info.permissions);
         job->setParentJob(q);
         // copy the metadata for acl and default acl
@@ -246,9 +245,7 @@ void ChmodJobPrivate::_k_chmodNextFile()
             job->addMetaData(QStringLiteral("DEFAULT_ACL_STRING"), defaultAclString);
         }
         q->addSubjob(job);
-    } else
-        // We have finished
-    {
+    } else { // We have finished
         q->emitResult();
     }
 }
@@ -263,15 +260,15 @@ void ChmodJob::slotResult(KJob *job)
         emitResult();
         return;
     }
-    //qDebug() << "d->m_lstItems:" << d->m_lstItems.count();
+    // qDebug() << "d->m_lstItems:" << d->m_lstItems.count();
     switch (d->state) {
     case CHMODJOB_STATE_LISTING:
         d->m_lstItems.removeFirst();
-        //qDebug() << "-> processList";
+        // qDebug() << "-> processList";
         d->_k_processList();
         return;
     case CHMODJOB_STATE_CHMODING:
-        //qDebug() << "-> chmodNextFile";
+        // qDebug() << "-> chmodNextFile";
         d->_k_chmodNextFile();
         return;
     default:
@@ -280,14 +277,11 @@ void ChmodJob::slotResult(KJob *job)
     }
 }
 
-ChmodJob *KIO::chmod(const KFileItemList &lstItems, int permissions, int mask,
-                     const QString &owner, const QString &group,
-                     bool recursive, JobFlags flags)
+ChmodJob *KIO::chmod(const KFileItemList &lstItems, int permissions, int mask, const QString &owner, const QString &group, bool recursive, JobFlags flags)
 {
     KUserId uid = KUserId::fromName(owner);
     KGroupId gid = KGroupId::fromName(group);
-    return ChmodJobPrivate::newJob(lstItems, permissions, mask, uid,
-                                   gid, recursive, flags);
+    return ChmodJobPrivate::newJob(lstItems, permissions, mask, uid, gid, recursive, flags);
 }
 
 #include "moc_chmodjob.cpp"
