@@ -1,42 +1,31 @@
 // -*- c++ -*-
-/* This file is part of the KDE libraries
-    Copyright (C) 2002 Jan-Pascal van Best <janpascal@vanbest.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2002 Jan-Pascal van Best <janpascal@vanbest.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_DAVJOB_H
 #define KIO_DAVJOB_H
 
-#include <QtCore/QObject>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QPointer>
-#include <QtXml/QDomDocument>
-
-#include <sys/types.h>
-#include <sys/stat.h>
-
+#include "global.h"
 #include "kiocore_export.h"
 #include "transferjob.h"
-#include "global.h"
+
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 86)
+#include <QDomDocument>
+#endif
+#include <QObject>
+#include <QPointer>
+#include <QString>
+#include <QStringList>
+
+#include <sys/stat.h>
+#include <sys/types.h>
 
 namespace KIO
 {
-
 class Slave;
 
 class DavJobPrivate;
@@ -56,17 +45,31 @@ class KIOCORE_EXPORT DavJob : public TransferJob
     Q_OBJECT
 public:
     /**
-    * Returns the response as a QDomDocument.
-     * @return the response document
+     * Returns the reponse data.
+     *  @since 5.86
      */
+    QByteArray responseData() const;
+
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 86)
+    /**
+     * Returns the response as a QDomDocument.
+     * @return the response document
+     * @deprecated Since 5.86. Use QDomDocument::setContent(job->responseData()) if you need
+     * a QDomDocument of the resonse, but be aware that you need to handle the case that
+     * responseData() doesn't return valid XML if that is a relevant error scenario for you
+     * (response() does wrap such data into a DAV error XML structure).
+     */
+    KIOCORE_DEPRECATED_VERSION(5, 86, "Use responseData() instead.")
     QDomDocument &response();
+#endif
 
 protected Q_SLOTS:
-    void slotFinished() Q_DECL_OVERRIDE;
-    void slotData(const QByteArray &data) Q_DECL_OVERRIDE;
+    void slotFinished() override;
+    void slotData(const QByteArray &data) override;
 
 protected:
     DavJob(DavJobPrivate &dd, int, const QString &);
+
 private:
     Q_DECLARE_PRIVATE(DavJob)
 };
@@ -81,8 +84,9 @@ private:
  * @param depth the depth of the request. Can be "0", "1" or "infinity"
  * @param flags We support HideProgressInfo here
  * @return the new DavJob
+ * @since 5.84
  */
-KIOCORE_EXPORT DavJob *davPropFind(const QUrl &url, const QDomDocument &properties, const QString &depth, JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT DavJob *davPropFind(const QUrl &url, const QString &properties, const QString &depth, JobFlags flags = DefaultFlags);
 
 /**
  * Creates a new DavJob that issues a PROPPATCH command. PROPPATCH sets
@@ -93,8 +97,46 @@ KIOCORE_EXPORT DavJob *davPropFind(const QUrl &url, const QDomDocument &properti
  *        should be modified and its new values
  * @param flags We support HideProgressInfo here
  * @return the new DavJob
+ * @since 5.84
  */
-KIOCORE_EXPORT DavJob *davPropPatch(const QUrl &url, const QDomDocument &properties, JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT DavJob *davPropPatch(const QUrl &url, const QString &properties, JobFlags flags = DefaultFlags);
+
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 84)
+/**
+ * Creates a new DavJob that issues a PROPFIND command. PROPFIND retrieves
+ * the properties of the resource identified by the given @p url.
+ *
+ * @param url the URL of the resource
+ * @param properties a propfind document that describes the properties that
+ *        should be retrieved
+ * @param depth the depth of the request. Can be "0", "1" or "infinity"
+ * @param flags We support HideProgressInfo here
+ * @return the new DavJob
+ * @deprecated since 5.84, use the overload taking a @c QString @p properties argument instead.
+ * This can typically be done by replacing the properties argument with <tt>properties.toString()</tt>.
+ */
+KIOCORE_EXPORT
+KIOCORE_DEPRECATED_VERSION(5, 84, "Use davPropFind(const QUrl &, const QString &, const QString &, JobFlags) instead.")
+DavJob *davPropFind(const QUrl &url, const QDomDocument &properties, const QString &depth, JobFlags flags = DefaultFlags);
+#endif
+
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 84)
+/**
+ * Creates a new DavJob that issues a PROPPATCH command. PROPPATCH sets
+ * the properties of the resource identified by the given @p url.
+ *
+ * @param url the URL of the resource
+ * @param properties a PROPPACTCH document that describes the properties that
+ *        should be modified and its new values
+ * @param flags We support HideProgressInfo here
+ * @return the new DavJob
+ * @deprecated since 5.84, use the overload taking a @c QString @p properties argument instead.
+ * This can typically be done by replacing the properties argument with <tt>properties.toString()</tt>.
+ */
+KIOCORE_EXPORT
+KIOCORE_DEPRECATED_VERSION(5, 84, "Use davPropPatch(const QUrl &, const QString &, JobFlags) instead.")
+DavJob *davPropPatch(const QUrl &url, const QDomDocument &properties, JobFlags flags = DefaultFlags);
+#endif
 
 /**
  * Creates a new DavJob that issues a SEARCH command.
@@ -123,4 +165,3 @@ KIOCORE_EXPORT DavJob *davReport(const QUrl &url, const QString &report, const Q
 }
 
 #endif
-
