@@ -8,26 +8,31 @@
 */
 
 #include "desktopexecparser.h"
+#ifndef Q_OS_ANDROID
 #include "kiofuse_interface.h"
+#endif
 
-#include <KMacroExpander>
-#include <KShell>
-#include <KSharedConfig>
-#include <KDesktopFile>
-#include <KService>
-#include <KConfigGroup>
-#include <kprotocolinfo.h>
 #include <KApplicationTrader>
+#include <KConfigGroup>
+#include <KDesktopFile>
 #include <KLocalizedString>
+#include <KMacroExpander>
+#include <KService>
+#include <KSharedConfig>
+#include <KShell>
+#include <kprotocolinfo.h> // KF6 TODO remove after moving hasSchemeHandler to OpenUrlJob
 
-#include <QFile>
-#include <QDir>
-#include <QUrl>
-#include <QStandardPaths>
+#ifndef Q_OS_ANDROID
 #include <QDBusConnection>
 #include <QDBusReply>
+#endif
+#include <QDir>
+#include <QFile>
+#include <QProcessEnvironment>
+#include <QStandardPaths>
+#include <QUrl>
 
-#include <config-kiocore.h> // CMAKE_INSTALL_FULL_LIBEXECDIR_KF5
+#include <config-kiocore.h> // KDE_INSTALL_FULL_LIBEXECDIR_KF
 
 #include "kiocoredebug.h"
 
@@ -39,7 +44,8 @@ public:
         , hasUrls(false)
         , hasSpec(false)
         , service(_service)
-    {}
+    {
+    }
 
     bool hasUrls;
     bool hasSpec;
@@ -65,9 +71,8 @@ int KRunMX1::expandEscapedMacro(const QString &str, int pos, QStringList &ret)
         ret << QStringLiteral("--icon") << service.icon().replace(QLatin1Char('%'), QLatin1String("%%"));
         break;
     case 'm':
-//       ret << "-miniicon" << service.icon().replace( '%', "%%" );
-        qCWarning(KIO_CORE) << "-miniicon isn't supported anymore (service"
-                   << service.name() << ')';
+        //       ret << "-miniicon" << service.icon().replace( '%', "%%" );
+        qCWarning(KIO_CORE) << "-miniicon isn't supported anymore (service" << service.name() << ')';
         break;
     case 'u':
     case 'U':
@@ -95,9 +100,10 @@ class KRunMX2 : public KMacroExpanderBase
 public:
     explicit KRunMX2(const QList<QUrl> &_urls)
         : KMacroExpanderBase(QLatin1Char('%'))
-        , ignFile(false),
-        urls(_urls)
-    {}
+        , ignFile(false)
+        , urls(_urls)
+    {
+    }
 
     bool ignFile;
 
@@ -114,8 +120,7 @@ void KRunMX2::subst(int option, const QUrl &url, QStringList &ret)
 {
     switch (option) {
     case 'u':
-        ret << ((url.isLocalFile() && url.fragment().isNull() && url.query().isNull()) ?
-                QDir::toNativeSeparators(url.toLocalFile())  : url.toString());
+        ret << ((url.isLocalFile() && url.fragment().isNull() && url.query().isNull()) ? QDir::toNativeSeparators(url.toLocalFile()) : url.toString());
         break;
     case 'd':
         ret << url.adjusted(QUrl::RemoveFilename).path();
@@ -146,7 +151,7 @@ int KRunMX2::expandEscapedMacro(const QString &str, int pos, QStringList &ret)
     case 'v':
         if (urls.isEmpty()) {
             if (!ignFile) {
-                //qCDebug(KIO_CORE) << "No URLs supplied to single-URL service" << str;
+                // qCDebug(KIO_CORE) << "No URLs supplied to single-URL service" << str;
             }
         } else if (urls.count() > 1) {
             qCWarning(KIO_CORE) << urls.count() << "URLs supplied to single-URL service" << str;
@@ -186,9 +191,7 @@ QStringList KIO::DesktopExecParser::supportedProtocols(const KService &service)
         if (supportedProtocols.isEmpty()) {
             // compat mode: assume KIO if not set and it's a KDE app (or a KDE service)
             const QStringList categories = service.property(QStringLiteral("Categories")).toStringList();
-            if (categories.contains(QLatin1String("KDE"))
-                    || !service.isApplication()
-                    || service.entryPath().isEmpty() /*temp service*/) {
+            if (categories.contains(QLatin1String("KDE")) || !service.isApplication() || service.entryPath().isEmpty() /*temp service*/) {
                 supportedProtocols.append(QStringLiteral("KIO"));
             } else { // if no KDE app, be a bit over-generic
                 supportedProtocols.append(QStringLiteral("http"));
@@ -206,7 +209,7 @@ QStringList KIO::DesktopExecParser::supportedProtocols(const KService &service)
         }
     }
 
-    //qCDebug(KIO_CORE) << "supportedProtocols:" << supportedProtocols;
+    // qCDebug(KIO_CORE) << "supportedProtocols:" << supportedProtocols;
     return supportedProtocols;
 }
 
@@ -221,21 +224,11 @@ bool KIO::DesktopExecParser::isProtocolInSupportedList(const QUrl &url, const QS
 // We have up to two sources of data, for protocols not handled by kioslaves (so called "helper") :
 // 1) the exec line of the .protocol file, if there's one
 // 2) the application associated with x-scheme-handler/<protocol> if there's one
-
-// If both exist, then:
-//  A) if the .protocol file says "launch an application", then the new-style handler-app has priority
-//  B) but if the .protocol file is for a kioslave (e.g. kio_http) then this has priority over
-//     firefox or chromium saying x-scheme-handler/http. Gnome people want to send all HTTP urls
-//     to a webbrowser, but we want MIME-type-determination-in-calling-application by default
-//     (the user can configure a BrowserApplication though)
-bool KIO::DesktopExecParser::hasSchemeHandler(const QUrl &url)
+bool KIO::DesktopExecParser::hasSchemeHandler(const QUrl &url) // KF6 TODO move to OpenUrlJob
 {
     if (KProtocolInfo::isHelperProtocol(url)) {
         return true;
     }
-    if (KProtocolInfo::isKnownProtocol(url)) {
-        return false; // this is case B, we prefer kioslaves over the competition
-    }
     const KService::Ptr service = KApplicationTrader::preferredService(QLatin1String("x-scheme-handler/") + url.scheme());
     if (service) {
         qCDebug(KIO_CORE) << QLatin1String("preferred service for x-scheme-handler/") + url.scheme() << service->desktopEntryName();
@@ -247,7 +240,11 @@ class KIO::DesktopExecParserPrivate
 {
 public:
     DesktopExecParserPrivate(const KService &_service, const QList<QUrl> &_urls)
-        : service(_service), urls(_urls), tempFiles(false) {}
+        : service(_service)
+        , urls(_urls)
+        , tempFiles(false)
+    {
+    }
 
     const KService &service;
     QList<QUrl> urls;
@@ -278,8 +275,9 @@ void KIO::DesktopExecParser::setSuggestedFileName(const QString &suggestedFileNa
 static const QString kioexecPath()
 {
     QString kioexec = QCoreApplication::applicationDirPath() + QLatin1String("/kioexec");
-    if (!QFileInfo::exists(kioexec))
-        kioexec = QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/kioexec");
+    if (!QFileInfo::exists(kioexec)) {
+        kioexec = QStringLiteral(KDE_INSTALL_FULL_LIBEXECDIR_KF "/kioexec");
+    }
     Q_ASSERT(QFileInfo::exists(kioexec));
     return kioexec;
 }
@@ -294,18 +292,14 @@ static QString findNonExecutableProgram(const QString &executable)
 
 #ifdef Q_OS_UNIX
     // This is a *very* simplified version of QStandardPaths::findExecutable
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const auto skipEmptyParts = QString::SkipEmptyParts;
-#else
-    const auto skipEmptyParts = Qt::SkipEmptyParts;
-#endif
-    const QStringList searchPaths = QString::fromLocal8Bit(qgetenv("PATH")).split(QDir::listSeparator(), skipEmptyParts);
+    const QStringList searchPaths = QString::fromLocal8Bit(qgetenv("PATH")).split(QDir::listSeparator(), Qt::SkipEmptyParts);
     for (const QString &searchPath : searchPaths) {
         const QString candidate = searchPath + QLatin1Char('/') + executable;
         const QFileInfo fileInfo(candidate);
         if (fileInfo.exists()) {
             if (fileInfo.isExecutable()) {
-                qWarning() << "Internal program error. QStandardPaths::findExecutable couldn't find" << executable << "but our own logic found it at" << candidate << ". Please report a bug at https://bugs.kde.org";
+                qWarning() << "Internal program error. QStandardPaths::findExecutable couldn't find" << executable << "but our own logic found it at"
+                           << candidate << ". Please report a bug at https://bugs.kde.org";
             } else {
                 return candidate;
             }
@@ -333,7 +327,7 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
             // Too bad for commands that need a shell - they must reside in $PATH.
             executableFullPath = QStandardPaths::findExecutable(binary);
             if (executableFullPath.isEmpty()) {
-                executableFullPath = QFile::decodeName(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/") + binary;
+                executableFullPath = QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF "/") + binary;
             }
         } else {
             executableFullPath = binary;
@@ -362,7 +356,7 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
     KRunMX1 mx1(d->service);
     KRunMX2 mx2(d->urls);
 
-    if (!mx1.expandMacrosShellQuote(exec)) {    // Error in shell syntax
+    if (!mx1.expandMacrosShellQuote(exec)) { // Error in shell syntax
         d->m_errorString = i18n("Syntax error in command %1 coming from %2", exec, d->service.entryPath());
         qCWarning(KIO_CORE) << "Syntax error in command" << d->service.exec() << ", service" << d->service.name();
         return QStringList();
@@ -390,34 +384,48 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
 
     // Check if we need kioexec, or KIOFuse
     bool useKioexec = false;
-    org::kde::KIOFuse::VFS kiofuse_iface(QStringLiteral("org.kde.KIOFuse"),
-                                         QStringLiteral("/org/kde/KIOFuse"),
-                                         QDBusConnection::sessionBus());
-    struct MountRequest { QDBusPendingReply<QString> reply; int urlIndex; };
+#ifndef Q_OS_ANDROID
+    org::kde::KIOFuse::VFS kiofuse_iface(QStringLiteral("org.kde.KIOFuse"), QStringLiteral("/org/kde/KIOFuse"), QDBusConnection::sessionBus());
+    struct MountRequest {
+        QDBusPendingReply<QString> reply;
+        int urlIndex;
+    };
     QVector<MountRequest> requests;
     requests.reserve(d->urls.count());
     const QStringList appSupportedProtocols = supportedProtocols(d->service);
-    for (int i = 0; i < d->urls.count(); ++i)  {
+    for (int i = 0; i < d->urls.count(); ++i) {
         const QUrl url = d->urls.at(i);
         const bool supported = mx1.hasUrls ? isProtocolInSupportedList(url, appSupportedProtocols) : url.isLocalFile();
         if (!supported) {
             // if FUSE fails, we'll have to fallback to kioexec
             useKioexec = true;
         }
+
+        // supportedProtocols() only checks whether the .desktop file has MimeType=x-scheme-handler/xxx
+        // We also want to check whether the app has been set as default/associated in mimeapps.list
+        const auto handlers = KApplicationTrader::queryByMimeType(QLatin1String("x-scheme-handler/") + url.scheme());
+        for (const KService::Ptr &handler : handlers) {
+            if (handler->desktopEntryName() == d->service.desktopEntryName()) {
+                useKioexec = false;
+            }
+        }
+
         // NOTE: Some non-KIO apps may support the URLs (e.g. VLC supports smb://)
         // but will not have the password if they are not in the URL itself.
         // Hence convert URL to KIOFuse equivalent in case there is a password.
         // @see https://pointieststick.com/2018/01/17/videos-on-samba-shares/
         // @see https://bugs.kde.org/show_bug.cgi?id=330192
         if (!supported || (!url.userName().isEmpty() && url.password().isEmpty() && isNonKIO())) {
-            requests.push_back({ kiofuse_iface.mountUrl(url.toString()), i });
+            requests.push_back({kiofuse_iface.mountUrl(url.toString()), i});
         }
     }
 
     for (auto &request : requests) {
         request.reply.waitForFinished();
     }
-    const bool fuseError = std::any_of(requests.cbegin(), requests.cend(), [](const MountRequest &request) { return request.reply.isError(); });
+    const bool fuseError = std::any_of(requests.cbegin(), requests.cend(), [](const MountRequest &request) {
+        return request.reply.isError();
+    });
 
     if (fuseError && useKioexec) {
         // We need to run the app through kioexec
@@ -436,11 +444,12 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
 
     // At this point we know we're not using kioexec, so feel free to replace
     // KIO URLs with their KIOFuse local path.
-    for (const auto &request : qAsConst(requests)) {
+    for (const auto &request : std::as_const(requests)) {
         if (!request.reply.isError()) {
             d->urls[request.urlIndex] = QUrl::fromLocalFile(request.reply.value());
         }
     }
+#endif
 
     if (appHasTempFileOption) {
         exec += QLatin1String(" --tempfile");
@@ -454,7 +463,7 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
         mx2.ignFile = true;
     }
 
-    mx2.expandMacrosShellQuote(exec);   // syntax was already checked, so don't check return value
+    mx2.expandMacrosShellQuote(exec); // syntax was already checked, so don't check return value
 
     /*
      1 = need_shell, 2 = terminal, 4 = su
@@ -490,7 +499,7 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
                 terminal += QLatin1String(" --workdir ") + KShell::quoteArg(d->service.workingDirectory());
             }
             terminal += QLatin1String(" -qwindowtitle '%c'");
-            if(!d->service.icon().isEmpty()) {
+            if (!d->service.icon().isEmpty()) {
                 terminal += QLatin1String(" -qwindowicon ") + KShell::quoteArg(d->service.icon().replace(QLatin1Char('%'), QLatin1String("%%")));
             }
         }
@@ -501,7 +510,7 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
             return QStringList();
         }
         mx2.expandMacrosShellQuote(terminal);
-        result = KShell::splitArgs(terminal);   // assuming that the term spec never needs a shell!
+        result = KShell::splitArgs(terminal); // assuming that the term spec never needs a shell!
         result << QStringLiteral("-e");
     }
 
@@ -515,7 +524,7 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
         if (d->service.terminal()) {
             result << QStringLiteral("su");
         } else {
-            QString kdesu = QFile::decodeName(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/kdesu");
+            QString kdesu = QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF "/kdesu");
             if (!QFile::exists(kdesu)) {
                 kdesu = QStandardPaths::findExecutable(QStringLiteral("kdesu"));
             }
@@ -551,23 +560,20 @@ QString KIO::DesktopExecParser::errorMessage() const
     return d->m_errorString;
 }
 
-//static
+// static
 QString KIO::DesktopExecParser::executableName(const QString &execLine)
 {
     const QString bin = executablePath(execLine);
     return bin.mid(bin.lastIndexOf(QLatin1Char('/')) + 1);
 }
 
-//static
+// static
 QString KIO::DesktopExecParser::executablePath(const QString &execLine)
 {
     // Remove parameters and/or trailing spaces.
     const QStringList args = KShell::splitArgs(execLine, KShell::AbortOnMeta | KShell::TildeExpand);
-    for (const QString &arg : args) {
-        if (!arg.contains(QLatin1Char('='))) {
-            return arg;
-        }
-    }
-    return QString();
+    auto it = std::find_if(args.cbegin(), args.cend(), [](const QString &arg) {
+        return !arg.contains(QLatin1Char('='));
+    });
+    return it != args.cend() ? *it : QString{};
 }
-
