@@ -91,8 +91,9 @@ KIOCORE_EXPORT QString convertSeconds(unsigned int seconds);
  * @return calculated remaining time
  * @deprecated Since 3.4, use calculateRemainingSeconds() instead, as QTime is limited to 23:59:59
  */
+KIOCORE_EXPORT
 KIOCORE_DEPRECATED_VERSION(3, 4, "Use KIO::calculateRemainingSeconds(KIO::filesize_t, KIO::filesize_t, KIO::filesize_t")
-KIOCORE_EXPORT QTime calculateRemaining(KIO::filesize_t totalSize, KIO::filesize_t processedSize, KIO::filesize_t speed);
+QTime calculateRemaining(KIO::filesize_t totalSize, KIO::filesize_t processedSize, KIO::filesize_t speed);
 #endif
 
 /**
@@ -132,8 +133,9 @@ KIOCORE_EXPORT QString decodeFileName(const QString &str);
  * @since 5.0
  * @deprecated since 5.61, use KFileUtils::suggestName() from KCoreAddons
  */
+KIOCORE_EXPORT
 KIOCORE_DEPRECATED_VERSION(5, 61, "Use KFileUtils::suggestName(const QUrl &, const QString &) from KCoreAddons")
-KIOCORE_EXPORT QString suggestName(const QUrl &baseURL, const QString &oldName);
+QString suggestName(const QUrl &baseURL, const QString &oldName);
 #endif
 
 /**
@@ -149,7 +151,7 @@ enum Error {
     ERR_NO_SOURCE_PROTOCOL = KJob::UserDefinedError + 7,
     ERR_UNSUPPORTED_ACTION = KJob::UserDefinedError + 8,
     ERR_IS_DIRECTORY = KJob::UserDefinedError + 9, ///< ... where a file was expected
-    ERR_IS_FILE = KJob::UserDefinedError + 10, ///< ... where a directory was expected (e.g. listing)
+    ERR_IS_FILE = KJob::UserDefinedError + 10, ///< ... where a directory was expected (e.g.\ listing)
     ERR_DOES_NOT_EXIST = KJob::UserDefinedError + 11,
     ERR_FILE_ALREADY_EXIST = KJob::UserDefinedError + 12,
     ERR_DIR_ALREADY_EXIST = KJob::UserDefinedError + 13,
@@ -162,61 +164,75 @@ enum Error {
     ERR_USER_CANCELED = KJob::KilledJobError,
     ERR_CYCLIC_COPY = KJob::UserDefinedError + 21,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_CREATE_SOCKET = KJob::UserDefinedError + 22, ///< @deprecated Since 5.0, use ERR_CANNOT_CREATE_SOCKET
+    ERR_COULD_NOT_CREATE_SOCKET KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_CREATE_SOCKET.") =
+        KJob::UserDefinedError + 22, ///< @deprecated Since 5.0, use ERR_CANNOT_CREATE_SOCKET
 #endif
     ERR_CANNOT_CREATE_SOCKET = KJob::UserDefinedError + 22,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_CONNECT = KJob::UserDefinedError + 23, ///< @deprecated Since 5.0, use ERR_CANNOT_CONNECT
+    ERR_COULD_NOT_CONNECT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_CONNECT.") =
+        KJob::UserDefinedError + 23, ///< @deprecated Since 5.0, use ERR_CANNOT_CONNECT
 #endif
     ERR_CANNOT_CONNECT = KJob::UserDefinedError + 23,
     ERR_CONNECTION_BROKEN = KJob::UserDefinedError + 24,
     ERR_NOT_FILTER_PROTOCOL = KJob::UserDefinedError + 25,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_MOUNT = KJob::UserDefinedError + 26, ///< @deprecated Since 5.0, use ERR_CANNOT_MOUNT
+    ERR_COULD_NOT_MOUNT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_MOUNT.") =
+        KJob::UserDefinedError + 26, ///< @deprecated Since 5.0, use ERR_CANNOT_MOUNT
 #endif
     ERR_CANNOT_MOUNT = KJob::UserDefinedError + 26,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_UNMOUNT = KJob::UserDefinedError + 27, ///< @deprecated Since 5.0, use ERR_CANNOT_UNMOUNT
+    ERR_COULD_NOT_UNMOUNT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_UNMOUNT.") =
+        KJob::UserDefinedError + 27, ///< @deprecated Since 5.0, use ERR_CANNOT_UNMOUNT
 #endif
     ERR_CANNOT_UNMOUNT = KJob::UserDefinedError + 27,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_READ = KJob::UserDefinedError + 28, ///< @deprecated Since 5.0, use ERR_CANNOT_READ
+    ERR_COULD_NOT_READ KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_READ.") =
+        KJob::UserDefinedError + 28, ///< @deprecated Since 5.0, use ERR_CANNOT_READ
 #endif
     ERR_CANNOT_READ = KJob::UserDefinedError + 28,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_WRITE = KJob::UserDefinedError + 29, ///< @deprecated Since 5.0, use ERR_CANNOT_WRITE
+    ERR_COULD_NOT_WRITE KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_WRITE.") =
+        KJob::UserDefinedError + 29, ///< @deprecated Since 5.0, use ERR_CANNOT_WRITE
 #endif
     ERR_CANNOT_WRITE = KJob::UserDefinedError + 29,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_BIND = KJob::UserDefinedError + 30, ///< @deprecated Since 5.0, use ERR_CANNOT_BIND
+    ERR_COULD_NOT_BIND KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_BIND.") =
+        KJob::UserDefinedError + 30, ///< @deprecated Since 5.0, use ERR_CANNOT_BIND
 #endif
     ERR_CANNOT_BIND = KJob::UserDefinedError + 30,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_LISTEN = KJob::UserDefinedError + 31, ///< @deprecated Since 5.0, use ERR_CANNOT_LISTEN
+    ERR_COULD_NOT_LISTEN KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_LISTEN.") =
+        KJob::UserDefinedError + 31, ///< @deprecated Since 5.0, use ERR_CANNOT_LISTEN
 #endif
     ERR_CANNOT_LISTEN = KJob::UserDefinedError + 31,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_ACCEPT = KJob::UserDefinedError + 32, ///< @deprecated Since 5.0, use ERR_CANNOT_ACCEPT
+    ERR_COULD_NOT_ACCEPT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_ACCEPT.") =
+        KJob::UserDefinedError + 32, ///< @deprecated Since 5.0, use ERR_CANNOT_ACCEPT
 #endif
     ERR_CANNOT_ACCEPT = KJob::UserDefinedError + 32,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_LOGIN = KJob::UserDefinedError + 33, ///< @deprecated Since 5.0, use ERR_CANNOT_LOGIN
+    ERR_COULD_NOT_LOGIN KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_LOGIN.") =
+        KJob::UserDefinedError + 33, ///< @deprecated Since 5.0, use ERR_CANNOT_LOGIN
 #endif
     ERR_CANNOT_LOGIN = KJob::UserDefinedError + 33,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_STAT = KJob::UserDefinedError + 34, ///< @deprecated Since 5.0, use ERR_CANNOT_STAT
+    ERR_COULD_NOT_STAT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_STAT.") =
+        KJob::UserDefinedError + 34, ///< @deprecated Since 5.0, use ERR_CANNOT_STAT
 #endif
     ERR_CANNOT_STAT = KJob::UserDefinedError + 34,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_CLOSEDIR = KJob::UserDefinedError + 35, ///< @deprecated Since 5.0, use ERR_CANNOT_CLOSEDIR
+    ERR_COULD_NOT_CLOSEDIR KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_CLOSEDIR.") =
+        KJob::UserDefinedError + 35, ///< @deprecated Since 5.0, use ERR_CANNOT_CLOSEDIR
 #endif
     ERR_CANNOT_CLOSEDIR = KJob::UserDefinedError + 35,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_MKDIR = KJob::UserDefinedError + 37, ///< @deprecated Since 5.0, use ERR_CANNOT_MKDIR
+    ERR_COULD_NOT_MKDIR KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_AUTHENTICATE.") =
+        KJob::UserDefinedError + 37, ///< @deprecated Since 5.0, use ERR_CANNOT_MKDIR
 #endif
     ERR_CANNOT_MKDIR = KJob::UserDefinedError + 37,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_RMDIR = KJob::UserDefinedError + 38, ///< @deprecated Since 5.0, use ERR_CANNOT_RMDIR
+    ERR_COULD_NOT_RMDIR KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_RMDIR.") =
+        KJob::UserDefinedError + 38, ///< @deprecated Since 5.0, use ERR_CANNOT_RMDIR
 #endif
     ERR_CANNOT_RMDIR = KJob::UserDefinedError + 38,
     ERR_CANNOT_RESUME = KJob::UserDefinedError + 39,
@@ -229,7 +245,8 @@ enum Error {
     ERR_OUT_OF_MEMORY = KJob::UserDefinedError + 44,
     ERR_UNKNOWN_PROXY_HOST = KJob::UserDefinedError + 45,
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_AUTHENTICATE = KJob::UserDefinedError + 46, ///< @deprecated Since 5.0, use ERR_CANNOT_AUTHENTICATE
+    ERR_COULD_NOT_AUTHENTICATE KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_AUTHENTICATE.") =
+        KJob::UserDefinedError + 46, ///< @deprecated Since 5.0, use ERR_CANNOT_AUTHENTICATE
 #endif
     ERR_CANNOT_AUTHENTICATE = KJob::UserDefinedError + 46,
     ERR_ABORTED = KJob::UserDefinedError + 47, ///< Action got aborted from application side
@@ -259,7 +276,8 @@ enum Error {
     ///< the server in order to continue.
     ERR_POST_DENIED = KJob::UserDefinedError + 65, ///< Issued when trying to POST data to a certain Ports
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_SEEK = KJob::UserDefinedError + 66, ///< @deprecated Since 5.0, use ERR_CANNOT_SEEK
+    ERR_COULD_NOT_SEEK KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_SEEK.") =
+        KJob::UserDefinedError + 66, ///< @deprecated Since 5.0, use ERR_CANNOT_SEEK
 #endif
     // see job.cpp
     ERR_CANNOT_SEEK = KJob::UserDefinedError + 66,
@@ -275,6 +293,12 @@ enum Error {
         + 75, ///< Value used between kuiserver and views when the job owner disappears unexpectedly. It should not be emitted by slaves. @since 5.54
     ERR_PRIVILEGE_NOT_REQUIRED = KJob::UserDefinedError + 76, ///< used by file ioslave, @since 5.60
     ERR_CANNOT_TRUNCATE = KJob::UserDefinedError + 77, // used by FileJob::truncate, @since 5.66
+    /**
+     * Indicates failure to create a symlink due to the underlying filesystem (FAT/ExFAT)
+     * not supporting them. Used by e.g. CopyJob.
+     * @since 5.88
+     */
+    ERR_SYMLINKS_NOT_SUPPORTED = KJob::UserDefinedError + 78
 };
 
 /**
@@ -317,14 +341,19 @@ enum StatDetail {
     StatTime = 0x4,
     /// Resolve symlinks
     StatResolveSymlink = 0x8,
-    /// acl Data
+    /// ACL data
     StatAcl = 0x10,
     /// dev, inode
     StatInode = 0x20,
-    /// recursive size @since 5.70
+    /// Recursive size
+    /// @since 5.70
     StatRecursiveSize = 0x40,
+    /// MIME type
+    /// @since 5.82
+    StatMimeType = 0x80,
 
-    /// Default value includes fields provided by other entries
+    /// Default StatDetail flag when creating a @c StatJob.
+    /// Equivalent to setting <tt>StatBasic | StatUser | StatTime | StatAcl | StatResolveSymlink</tt>
     StatDefaultDetails = StatBasic | StatUser | StatTime | StatAcl | StatResolveSymlink,
 };
 /**
