@@ -1,22 +1,10 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2009 David Faure <faure@kde.org>
-                       Waldo Bastian <bastian@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 Waldo Bastian <bastian@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "job.h"
@@ -24,24 +12,25 @@
 
 #include <time.h>
 
+#include <KLocalizedString>
+#include <KStringHandler>
 
-#include <klocalizedstring.h>
-#include <kstringhandler.h>
-
-#include <kio/jobuidelegateextension.h>
-#include "slave.h"
 #include "scheduler.h"
+#include "slave.h"
+#include <kio/jobuidelegateextension.h>
 
 using namespace KIO;
 
-Job::Job() : KCompositeJob(nullptr)
+Job::Job()
+    : KCompositeJob(nullptr)
     , d_ptr(new JobPrivate)
 {
     d_ptr->q_ptr = this;
     setCapabilities(KJob::Killable | KJob::Suspendable);
 }
 
-Job::Job(JobPrivate &dd) : KCompositeJob(nullptr)
+Job::Job(JobPrivate &dd)
+    : KCompositeJob(nullptr)
     , d_ptr(&dd)
 {
     d_ptr->q_ptr = this;
@@ -53,11 +42,12 @@ Job::~Job()
     delete d_ptr;
 }
 
-// Exists for historical reasons only
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 0)
 KJobUiDelegate *Job::ui() const
 {
     return uiDelegate();
 }
+#endif
 
 JobUiDelegateExtension *Job::uiDelegateExtension() const
 {
@@ -73,7 +63,7 @@ void Job::setUiDelegateExtension(JobUiDelegateExtension *extension)
 
 bool Job::addSubjob(KJob *jobBase)
 {
-    //qDebug() << "addSubjob(" << jobBase << ") this=" << this;
+    // qDebug() << "addSubjob(" << jobBase << ") this=" << this;
 
     bool ok = KCompositeJob::addSubjob(jobBase);
     KIO::Job *job = qobject_cast<KIO::Job *>(jobBase);
@@ -87,6 +77,7 @@ bool Job::addSubjob(KJob *jobBase)
             Q_UNUSED(job);
             emitSpeed(speed);
         });
+        job->setProperty("widget", property("widget")); // see KJobWidgets
         job->setProperty("window", property("window")); // see KJobWidgets
         job->setProperty("userTimestamp", property("userTimestamp")); // see KJobWidgets
         job->setUiDelegateExtension(d->m_uiDelegateExtension);
@@ -96,14 +87,13 @@ bool Job::addSubjob(KJob *jobBase)
 
 bool Job::removeSubjob(KJob *jobBase)
 {
-    //qDebug() << "removeSubjob(" << jobBase << ") this=" << this << "subjobs=" << subjobs().count();
+    // qDebug() << "removeSubjob(" << jobBase << ") this=" << this << "subjobs=" << subjobs().count();
     return KCompositeJob::removeSubjob(jobBase);
 }
 
-static QString url_description_string(const QUrl& url)
+static QString url_description_string(const QUrl &url)
 {
-    return url.scheme() == QLatin1String("data") ? QStringLiteral("data:[...]") :
-                                    KStringHandler::csqueeze(url.toDisplayString(QUrl::PreferLocalFile), 100);
+    return url.scheme() == QLatin1String("data") ? QStringLiteral("data:[...]") : KStringHandler::csqueeze(url.toDisplayString(QUrl::PreferLocalFile), 100);
 }
 
 KIO::JobPrivate::~JobPrivate()
@@ -115,9 +105,7 @@ void JobPrivate::emitMoving(KIO::Job *job, const QUrl &src, const QUrl &dest)
     static const QString s_title = i18nc("@title job", "Moving");
     static const QString s_source = i18nc("The source of a file operation", "Source");
     static const QString s_destination = i18nc("The destination of a file operation", "Destination");
-    emit job->description(job, s_title,
-                          qMakePair(s_source, url_description_string(src)),
-                          qMakePair(s_destination, url_description_string(dest)));
+    Q_EMIT job->description(job, s_title, qMakePair(s_source, url_description_string(src)), qMakePair(s_destination, url_description_string(dest)));
 }
 
 void JobPrivate::emitCopying(KIO::Job *job, const QUrl &src, const QUrl &dest)
@@ -125,54 +113,50 @@ void JobPrivate::emitCopying(KIO::Job *job, const QUrl &src, const QUrl &dest)
     static const QString s_title = i18nc("@title job", "Copying");
     static const QString s_source = i18nc("The source of a file operation", "Source");
     static const QString s_destination = i18nc("The destination of a file operation", "Destination");
-    emit job->description(job, s_title,
-                          qMakePair(s_source, url_description_string(src)),
-                          qMakePair(s_destination, url_description_string(dest)));
+    Q_EMIT job->description(job, s_title, qMakePair(s_source, url_description_string(src)), qMakePair(s_destination, url_description_string(dest)));
 }
 
 void JobPrivate::emitCreatingDir(KIO::Job *job, const QUrl &dir)
 {
     static const QString s_title = i18nc("@title job", "Creating directory");
     static const QString s_directory = i18n("Directory");
-    emit job->description(job, s_title,
-                          qMakePair(s_directory, url_description_string(dir)));
+    Q_EMIT job->description(job, s_title, qMakePair(s_directory, url_description_string(dir)));
 }
 
 void JobPrivate::emitDeleting(KIO::Job *job, const QUrl &url)
 {
     static const QString s_title = i18nc("@title job", "Deleting");
     static const QString s_file = i18n("File");
-    emit job->description(job, s_title,
-                          qMakePair(s_file, url_description_string(url)));
+    Q_EMIT job->description(job, s_title, qMakePair(s_file, url_description_string(url)));
 }
 
 void JobPrivate::emitStating(KIO::Job *job, const QUrl &url)
 {
     static const QString s_title = i18nc("@title job", "Examining");
     static const QString s_file = i18n("File");
-    emit job->description(job, s_title,
-                          qMakePair(s_file, url_description_string(url)));
+    Q_EMIT job->description(job, s_title, qMakePair(s_file, url_description_string(url)));
 }
 
 void JobPrivate::emitTransferring(KIO::Job *job, const QUrl &url)
 {
     static const QString s_title = i18nc("@title job", "Transferring");
     static const QString s_source = i18nc("The source of a file operation", "Source");
-    emit job->description(job, s_title,
-                          qMakePair(s_source, url_description_string(url)));
+    Q_EMIT job->description(job, s_title, qMakePair(s_source, url_description_string(url)));
 }
 
 void JobPrivate::emitMounting(KIO::Job *job, const QString &dev, const QString &point)
 {
-    emit job->description(job, i18nc("@title job", "Mounting"),
-                          qMakePair(i18n("Device"), dev),
-                          qMakePair(i18n("Mountpoint"), point));
+    Q_EMIT job->description(job, i18nc("@title job", "Mounting"), qMakePair(i18n("Device"), dev), qMakePair(i18n("Mountpoint"), point));
 }
 
 void JobPrivate::emitUnmounting(KIO::Job *job, const QString &point)
 {
-    emit job->description(job, i18nc("@title job", "Unmounting"),
-                          qMakePair(i18n("Mountpoint"), point));
+    Q_EMIT job->description(job, i18nc("@title job", "Unmounting"), qMakePair(i18n("Mountpoint"), point));
+}
+
+void JobPrivate::setTransient(KIO::Job *job, bool transient)
+{
+    job->setProperty("transientProgressReporting", transient);
 }
 
 bool Job::doKill()
@@ -208,7 +192,7 @@ bool Job::doResume()
     return true;
 }
 
-//Job::errorString is implemented in job_error.cpp
+// Job::errorString is implemented in job_error.cpp
 
 void Job::setParentJob(Job *job)
 {
@@ -247,8 +231,7 @@ void Job::addMetaData(const QString &key, const QString &value)
 void Job::addMetaData(const QMap<QString, QString> &values)
 {
     Q_D(Job);
-    QMap<QString, QString>::const_iterator it = values.begin();
-    for (; it != values.end(); ++it) {
+    for (auto it = values.cbegin(); it != values.cend(); ++it) {
         d->m_outgoingMetaData.insert(it.key(), it.value());
     }
 }
@@ -256,12 +239,12 @@ void Job::addMetaData(const QMap<QString, QString> &values)
 void Job::mergeMetaData(const QMap<QString, QString> &values)
 {
     Q_D(Job);
-    QMap<QString, QString>::const_iterator it = values.begin();
-    for (; it != values.end(); ++it)
+    for (auto it = values.cbegin(); it != values.cend(); ++it) {
         // there's probably a faster way
         if (!d->m_outgoingMetaData.contains(it.key())) {
             d->m_outgoingMetaData.insert(it.key(), it.value());
         }
+    }
 }
 
 MetaData Job::outgoingMetaData() const
@@ -284,43 +267,51 @@ QByteArray JobPrivate::privilegeOperationData()
             switch (m_operationType) {
             case ChangeAttr:
                 m_caption = i18n("Change Attribute");
-                m_message = i18n("Root privileges are required to change file attributes. "
-                                 "Do you want to continue?");
+                m_message = i18n(
+                    "Root privileges are required to change file attributes. "
+                    "Do you want to continue?");
                 break;
             case Copy:
                 m_caption = i18n("Copy Files");
-                m_message = i18n("Root privileges are required to complete the copy operation. "
-                                 "Do you want to continue?");
+                m_message = i18n(
+                    "Root privileges are required to complete the copy operation. "
+                    "Do you want to continue?");
                 break;
             case Delete:
                 m_caption = i18n("Delete Files");
-                m_message = i18n("Root privileges are required to complete the delete operation. "
-                                 "However, doing so may damage your system. Do you want to continue?");
+                m_message = i18n(
+                    "Root privileges are required to complete the delete operation. "
+                    "However, doing so may damage your system. Do you want to continue?");
                 break;
             case MkDir:
                 m_caption = i18n("Create Folder");
-                m_message = i18n("Root privileges are required to create this folder. "
-                                 "Do you want to continue?");
+                m_message = i18n(
+                    "Root privileges are required to create this folder. "
+                    "Do you want to continue?");
                 break;
             case Move:
                 m_caption = i18n("Move Items");
-                m_message = i18n("Root privileges are required to complete the move operation. "
-                                 "Do you want to continue?");
+                m_message = i18n(
+                    "Root privileges are required to complete the move operation. "
+                    "Do you want to continue?");
                 break;
             case Rename:
                 m_caption = i18n("Rename");
-                m_message = i18n("Root privileges are required to complete renaming. "
-                                 "Do you want to continue?");
+                m_message = i18n(
+                    "Root privileges are required to complete renaming. "
+                    "Do you want to continue?");
                 break;
             case Symlink:
                 m_caption = i18n("Create Symlink");
-                m_message = i18n("Root privileges are required to create a symlink. "
-                                 "Do you want to continue?");
+                m_message = i18n(
+                    "Root privileges are required to create a symlink. "
+                    "Do you want to continue?");
                 break;
             case Transfer:
                 m_caption = i18n("Transfer data");
-                m_message = i18n("Root privileges are required to complete transferring data. "
-                                 "Do you want to continue?");
+                m_message = i18n(
+                    "Root privileges are required to complete transferring data. "
+                    "Do you want to continue?");
                 Q_FALLTHROUGH();
             default:
                 break;
@@ -341,12 +332,13 @@ QByteArray JobPrivate::privilegeOperationData()
 
 //////////////////////////
 
-class KIO::DirectCopyJobPrivate: public KIO::SimpleJobPrivate
+class KIO::DirectCopyJobPrivate : public KIO::SimpleJobPrivate
 {
 public:
     DirectCopyJobPrivate(const QUrl &url, int command, const QByteArray &packedArgs)
         : SimpleJobPrivate(url, command, packedArgs)
-    {}
+    {
+    }
 
     /**
      * @internal
@@ -372,14 +364,13 @@ DirectCopyJob::~DirectCopyJob()
 void DirectCopyJobPrivate::start(Slave *slave)
 {
     Q_Q(DirectCopyJob);
-    q->connect(slave, &SlaveInterface::canResume,
-               q, &DirectCopyJob::slotCanResume);
+    q->connect(slave, &SlaveInterface::canResume, q, &DirectCopyJob::slotCanResume);
     SimpleJobPrivate::start(slave);
 }
 
 void DirectCopyJob::slotCanResume(KIO::filesize_t offset)
 {
-    emit canResume(this, offset);
+    Q_EMIT canResume(this, offset);
 }
 
 //////////////////////////
