@@ -99,6 +99,7 @@ public:
     static void emitTransferring(KIO::Job *, const QUrl &url);
     static void emitMounting(KIO::Job *, const QString &dev, const QString &point);
     static void emitUnmounting(KIO::Job *, const QString &point);
+    static void setTransient(KIO::Job *, bool transient = true);
 
     Q_DECLARE_PUBLIC(Job)
 };
@@ -332,6 +333,7 @@ public:
         TransferJob *job = new TransferJob(*new TransferJobPrivate(url, command, packedArgs, _staticData));
         job->setUiDelegate(KIO::createDefaultJobUiDelegate());
         if (!(flags & HideProgressInfo)) {
+            JobPrivate::setTransient(job);
             KIO::getJobTracker()->registerJob(job);
         }
         if (!(flags & NoPrivilegeExecution)) {
@@ -346,6 +348,7 @@ public:
         TransferJob *job = new TransferJob(*new TransferJobPrivate(url, command, packedArgs, ioDevice));
         job->setUiDelegate(KIO::createDefaultJobUiDelegate());
         if (!(flags & HideProgressInfo)) {
+            JobPrivate::setTransient(job);
             KIO::getJobTracker()->registerJob(job);
         }
         if (!(flags & NoPrivilegeExecution)) {
@@ -359,7 +362,7 @@ public:
 class DirectCopyJobPrivate;
 /**
  * @internal
- * Used for direct copy from or to the local filesystem (i.e. SlaveBase::copy())
+ * Used for direct copy from or to the local filesystem (i.e.\ SlaveBase::copy())
  */
 class DirectCopyJob : public SimpleJob
 {
