@@ -8,6 +8,12 @@
 
 #include "kfileitem.h"
 
+#include "config-kiocore.h"
+
+#if HAVE_POSIX_ACL
+#include "../aclhelpers_p.h"
+#endif
+
 #include "../pathhelpers_p.h"
 #include "kiocoredebug.h"
 #include "kioglobal_p.h"
@@ -31,6 +37,8 @@
 #include <KFileSystemType>
 #include <KProtocolManager>
 
+#define KFILEITEM_DEBUG 0
+
 class KFileItemPrivate : public QSharedData
 {
 public:
@@ -50,6 +58,7 @@ public:
         , m_mimeType()
         , m_fileMode(mode)
         , m_permissions(permissions)
+        , m_addACL(false)
         , m_bLink(false)
         , m_bIsLocalUrl(itemOrDirUrl.isLocalFile())
         , m_bMimeTypeKnown(false)
@@ -86,6 +95,7 @@ public:
     void setTime(KFileItem::FileTimes which, uint time_t_val) const;
     void setTime(KFileItem::FileTimes which, const QDateTime &val) const;
     bool cmp(const KFileItemPrivate &item) const;
+    void printCompareDebug(const KFileItemPrivate &item) const;
     bool isSlow() const;
 
     /**
@@ -148,6 +158,11 @@ public:
      */
     mutable mode_t m_permissions;
 
+    /**
+     * Whether the UDSEntry ACL fields should be added to m_entry.
+     */
+    mutable bool m_addACL : 1;
+
     /**
      * Whether the file is a link
      */
@@ -197,50 +212,57 @@ void KFileItemPrivate::init() const
     //  metaInfo = KFileMetaInfo();
 
     // stat() local files if needed
-    if (m_fileMode == KFileItem::Unknown || m_permissions == KFileItem::Unknown || m_entry.count() == 0) {
-        if (m_url.isLocalFile()) {
-            /* directories may not have a slash at the end if
-             * we want to stat() them; it requires that we
-             * change into it .. which may not be allowed
-             * stat("/is/unaccessible")  -> rwx------
-             * stat("/is/unaccessible/") -> EPERM            H.Z.
-             * This is the reason for the StripTrailingSlash
-             */
-            QT_STATBUF buf;
-            const QString path = m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile();
-            const QByteArray pathBA = QFile::encodeName(path);
-            if (QT_LSTAT(pathBA.constData(), &buf) == 0) {
-                m_entry.reserve(9);
-                m_entry.replace(KIO::UDSEntry::UDS_DEVICE_ID, buf.st_dev);
-                m_entry.replace(KIO::UDSEntry::UDS_INODE, buf.st_ino);
+    const bool shouldStat = (m_fileMode == KFileItem::Unknown || m_permissions == KFileItem::Unknown || m_entry.count() == 0) && m_url.isLocalFile();
+    if (shouldStat) {
+        /* directories may not have a slash at the end if we want to stat()
+         * them; it requires that we change into it .. which may not be allowed
+         * stat("/is/unaccessible")  -> rwx------
+         * stat("/is/unaccessible/") -> EPERM            H.Z.
+         * This is the reason for the StripTrailingSlash
+         */
+        QT_STATBUF buf;
+        const QString path = m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile();
+        const QByteArray pathBA = QFile::encodeName(path);
+        if (QT_LSTAT(pathBA.constData(), &buf) == 0) {
+            m_entry.reserve(9);
+            m_entry.replace(KIO::UDSEntry::UDS_DEVICE_ID, buf.st_dev);
+            m_entry.replace(KIO::UDSEntry::UDS_INODE, buf.st_ino);
 
-                mode_t mode = buf.st_mode;
-                if ((buf.st_mode & QT_STAT_MASK) == QT_STAT_LNK) {
-                    m_bLink = true;
-                    if (QT_STAT(pathBA.constData(), &buf) == 0) {
-                        mode = buf.st_mode;
-                    } else { // link pointing to nowhere (see FileProtocol::createUDSEntry() in ioslaves/file/file.cpp)
-                        mode = (QT_STAT_MASK - 1) | S_IRWXU | S_IRWXG | S_IRWXO;
-                    }
-                }
-                m_entry.replace(KIO::UDSEntry::UDS_SIZE, buf.st_size);
-                m_entry.replace(KIO::UDSEntry::UDS_FILE_TYPE, buf.st_mode & QT_STAT_MASK); // extract file type
-                m_entry.replace(KIO::UDSEntry::UDS_ACCESS, buf.st_mode & 07777); // extract permissions
-                m_entry.replace(KIO::UDSEntry::UDS_MODIFICATION_TIME, buf.st_mtime); // TODO: we could use msecs too...
-                m_entry.replace(KIO::UDSEntry::UDS_ACCESS_TIME, buf.st_atime);
-#ifndef Q_OS_WIN
-                m_entry.replace(KIO::UDSEntry::UDS_USER, KUser(buf.st_uid).loginName());
-                m_entry.replace(KIO::UDSEntry::UDS_GROUP, KUserGroup(buf.st_gid).name());
-#endif
-
-                // TODO: these can be removed, we can use UDS_FILE_TYPE and UDS_ACCESS everywhere
-                if (m_fileMode == KFileItem::Unknown) {
-                    m_fileMode = mode & QT_STAT_MASK; // extract file type
-                }
-                if (m_permissions == KFileItem::Unknown) {
-                    m_permissions = mode & 07777; // extract permissions
+            mode_t mode = buf.st_mode;
+            if ((buf.st_mode & QT_STAT_MASK) == QT_STAT_LNK) {
+                m_bLink = true;
+                if (QT_STAT(pathBA.constData(), &buf) == 0) {
+                    mode = buf.st_mode;
+                } else { // link pointing to nowhere (see FileProtocol::createUDSEntry() in ioslaves/file/file.cpp)
+                    mode = (QT_STAT_MASK - 1) | S_IRWXU | S_IRWXG | S_IRWXO;
                 }
             }
+
+            const mode_t type = mode & QT_STAT_MASK;
+
+            m_entry.replace(KIO::UDSEntry::UDS_SIZE, buf.st_size);
+            m_entry.replace(KIO::UDSEntry::UDS_FILE_TYPE, type); // extract file type
+            m_entry.replace(KIO::UDSEntry::UDS_ACCESS, mode & 07777); // extract permissions
+            m_entry.replace(KIO::UDSEntry::UDS_MODIFICATION_TIME, buf.st_mtime); // TODO: we could use msecs too...
+            m_entry.replace(KIO::UDSEntry::UDS_ACCESS_TIME, buf.st_atime);
+#ifndef Q_OS_WIN
+            m_entry.replace(KIO::UDSEntry::UDS_USER, KUser(buf.st_uid).loginName());
+            m_entry.replace(KIO::UDSEntry::UDS_GROUP, KUserGroup(buf.st_gid).name());
+#endif
+
+            // TODO: these can be removed, we can use UDS_FILE_TYPE and UDS_ACCESS everywhere
+            if (m_fileMode == KFileItem::Unknown) {
+                m_fileMode = type; // extract file type
+            }
+            if (m_permissions == KFileItem::Unknown) {
+                m_permissions = mode & 07777; // extract permissions
+            }
+
+#if HAVE_POSIX_ACL
+            if (m_addACL) {
+                appendACLAtoms(pathBA, m_entry, type);
+            }
+#endif
         }
     }
 
@@ -359,6 +381,39 @@ QDateTime KFileItemPrivate::time(KFileItem::FileTimes mappedWhich) const
     return QDateTime();
 }
 
+void KFileItemPrivate::printCompareDebug(const KFileItemPrivate &item) const
+{
+    Q_UNUSED(item);
+
+#if KFILEITEM_DEBUG
+    const KIO::UDSEntry &otherEntry = item.m_entry;
+
+    qDebug() << "Comparing" << m_url << "and" << item.m_url;
+    qDebug() << " name" << (m_strName == item.m_strName);
+    qDebug() << " local" << (m_bIsLocalUrl == item.m_bIsLocalUrl);
+
+    qDebug() << " mode" << (m_fileMode == item.m_fileMode);
+    qDebug() << " perm" << (m_permissions == item.m_permissions);
+    qDebug() << " group" << (m_entry.stringValue(KIO::UDSEntry::UDS_GROUP) == otherEntry.stringValue(KIO::UDSEntry::UDS_GROUP));
+    qDebug() << " user" << (m_entry.stringValue(KIO::UDSEntry::UDS_USER) == otherEntry.stringValue(KIO::UDSEntry::UDS_USER));
+
+    qDebug() << " UDS_EXTENDED_ACL" << (m_entry.stringValue(KIO::UDSEntry::UDS_EXTENDED_ACL) == otherEntry.stringValue(KIO::UDSEntry::UDS_EXTENDED_ACL));
+    qDebug() << " UDS_ACL_STRING" << (m_entry.stringValue(KIO::UDSEntry::UDS_ACL_STRING) == otherEntry.stringValue(KIO::UDSEntry::UDS_ACL_STRING));
+    qDebug() << " UDS_DEFAULT_ACL_STRING"
+             << (m_entry.stringValue(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING) == otherEntry.stringValue(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING));
+
+    qDebug() << " m_bLink" << (m_bLink == item.m_bLink);
+    qDebug() << " m_hidden" << (m_hidden == item.m_hidden);
+
+    qDebug() << " size" << (size() == item.size());
+
+    qDebug() << " ModificationTime" << m_entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME)
+             << otherEntry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME);
+
+    qDebug() << " UDS_ICON_NAME" << (m_entry.stringValue(KIO::UDSEntry::UDS_ICON_NAME) == otherEntry.stringValue(KIO::UDSEntry::UDS_ICON_NAME));
+#endif
+}
+
 // Inlined because it is used only in one place
 inline bool KFileItemPrivate::cmp(const KFileItemPrivate &item) const
 {
@@ -370,22 +425,8 @@ inline bool KFileItemPrivate::cmp(const KFileItemPrivate &item) const
         item.ensureInitialized();
     }
 
-#if 0
-    qDebug() << "Comparing" << m_url << "and" << item.m_url;
-    qDebug() << " name" << (m_strName == item.m_strName);
-    qDebug() << " local" << (m_bIsLocalUrl == item.m_bIsLocalUrl);
-    qDebug() << " mode" << (m_fileMode == item.m_fileMode);
-    qDebug() << " perm" << (m_permissions == item.m_permissions);
-    qDebug() << " group" << (m_entry.stringValue(KIO::UDSEntry::UDS_GROUP) == item.m_entry.stringValue(KIO::UDSEntry::UDS_GROUP));
-    qDebug() << " user" << (m_entry.stringValue(KIO::UDSEntry::UDS_USER) == item.m_entry.stringValue(KIO::UDSEntry::UDS_USER));
-    qDebug() << " UDS_EXTENDED_ACL" << (m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ));
-    qDebug() << " UDS_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ));
-    qDebug() << " UDS_DEFAULT_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ));
-    qDebug() << " m_bLink" << (m_bLink == item.m_bLink);
-    qDebug() << " m_hidden" << (m_hidden == item.m_hidden);
-    qDebug() << " size" << (size() == item.size());
-    qDebug() << " ModificationTime" << m_entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME) << item.m_entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME);
-    qDebug() << " UDS_ICON_NAME" << (m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_ICON_NAME ));
+#if KFILEITEM_DEBUG
+    printCompareDebug(item);
 #endif
 
     /* clang-format off */
@@ -577,6 +618,11 @@ void KFileItem::refresh()
     d->m_hidden = KFileItemPrivate::Auto;
     refreshMimeType();
 
+#if HAVE_POSIX_ACL
+    // If the item had ACL, re-add them in init()
+    d->m_addACL = !d->m_entry.stringValue(KIO::UDSEntry::UDS_ACL_STRING).isEmpty();
+#endif
+
     // Basically, we can't trust any information we got while listing.
     // Everything could have changed...
     // Clearing m_entry makes it possible to detect changes in the size of the file,
@@ -950,9 +996,8 @@ static QString iconFromDirectoryFile(const QString &path)
     }
 
     if (icon.startsWith(QLatin1String("./"))) {
-        // path is relative with respect to the location
-        // of the .directory file (#73463)
-        return path + icon.midRef(1);
+        // path is relative with respect to the location of the .directory file (#73463)
+        return path + QStringView(icon).mid(1);
     }
     return icon;
 }
@@ -1010,27 +1055,31 @@ QString KFileItem::iconName() const
 
     const bool delaySlowOperations = d->m_delayedMimeTypes;
 
-    if (isLocalUrl && !delaySlowOperations && mime.inherits(QStringLiteral("application/x-desktop"))) {
-        d->m_iconName = iconFromDesktopFile(url.toLocalFile());
-        if (!d->m_iconName.isEmpty()) {
-            d->m_useIconNameCache = d->m_bMimeTypeKnown;
-            return d->m_iconName;
-        }
-    }
+    if (isLocalUrl && !delaySlowOperations) {
+        const QString &localFile = url.toLocalFile();
 
-    if (isLocalUrl && !delaySlowOperations && isDir()) {
-        if (isDirectoryMounted(url)) {
-            d->m_iconName = iconFromDirectoryFile(url.toLocalFile());
+        if (mime.inherits(QStringLiteral("application/x-desktop"))) {
+            d->m_iconName = iconFromDesktopFile(localFile);
             if (!d->m_iconName.isEmpty()) {
                 d->m_useIconNameCache = d->m_bMimeTypeKnown;
                 return d->m_iconName;
             }
         }
 
-        d->m_iconName = KIOPrivate::iconForStandardPath(url.toLocalFile());
-        if (!d->m_iconName.isEmpty()) {
-            d->m_useIconNameCache = d->m_bMimeTypeKnown;
-            return d->m_iconName;
+        if (isDir()) {
+            if (isDirectoryMounted(url)) {
+                d->m_iconName = iconFromDirectoryFile(localFile);
+                if (!d->m_iconName.isEmpty()) {
+                    d->m_useIconNameCache = d->m_bMimeTypeKnown;
+                    return d->m_iconName;
+                }
+            }
+
+            d->m_iconName = KIOPrivate::iconForStandardPath(localFile);
+            if (!d->m_iconName.isEmpty()) {
+                d->m_useIconNameCache = d->m_bMimeTypeKnown;
+                return d->m_iconName;
+            }
         }
     }
 
@@ -1666,35 +1715,29 @@ KFileItemList::KFileItemList(std::initializer_list<KFileItem> items)
 
 KFileItem KFileItemList::findByName(const QString &fileName) const
 {
-    const_iterator it = begin();
-    const const_iterator itend = end();
-    for (; it != itend; ++it) {
-        if ((*it).name() == fileName) {
-            return *it;
-        }
-    }
-    return KFileItem();
+    auto it = std::find_if(cbegin(), cend(), [&fileName](const KFileItem &item) {
+        return item.name() == fileName;
+    });
+
+    return it != cend() ? *it : KFileItem();
 }
 
 KFileItem KFileItemList::findByUrl(const QUrl &url) const
 {
-    const_iterator it = begin();
-    const const_iterator itend = end();
-    for (; it != itend; ++it) {
-        if ((*it).url() == url) {
-            return *it;
-        }
-    }
-    return KFileItem();
+    auto it = std::find_if(cbegin(), cend(), [&url](const KFileItem &item) {
+        return item.url() == url;
+    });
+
+    return it != cend() ? *it : KFileItem();
 }
 
 QList<QUrl> KFileItemList::urlList() const
 {
     QList<QUrl> lst;
-    const_iterator it = begin();
-    const const_iterator itend = end();
-    for (; it != itend; ++it) {
-        lst.append((*it).url());
+    lst.reserve(size());
+
+    for (const auto &item : *this) {
+        lst.append(item.url());
     }
     return lst;
 }
@@ -1702,10 +1745,10 @@ QList<QUrl> KFileItemList::urlList() const
 QList<QUrl> KFileItemList::targetUrlList() const
 {
     QList<QUrl> lst;
-    const_iterator it = begin();
-    const const_iterator itend = end();
-    for (; it != itend; ++it) {
-        lst.append((*it).targetUrl());
+    lst.reserve(size());
+
+    for (const auto &item : *this) {
+        lst.append(item.targetUrl());
     }
     return lst;
 }
