@@ -7,15 +7,19 @@
 */
 
 #include "kmountpoint.h"
+
 #include <stdlib.h>
 
 #include <config-kmountpoint.h>
+#include <kioglobal_p.h> // Defines QT_LSTAT on windows to kio_windows_lstat
 
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
 #include <QTextStream>
 
+#include <qplatformdefs.h>
+
 #ifdef Q_OS_WIN
 #include <qt_windows.h>
 static const Qt::CaseSensitivity cs = Qt::CaseInsensitive;
@@ -25,9 +29,6 @@ static const Qt::CaseSensitivity cs = Qt::CaseSensitive;
 
 // This is the *BSD branch
 #if HAVE_SYS_MOUNT_H
-#if HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
 #if HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
@@ -43,11 +44,33 @@ static const Qt::CaseSensitivity cs = Qt::CaseSensitive;
 #endif
 
 // Linux
-#if HAVE_LIBS_MOUNT_AND_BLKID
+#if HAVE_LIB_MOUNT
 #include <libmount/libmount.h>
 #include <blkid/blkid.h>
 #endif
 
+static bool isNetfs(const QString &mountType)
+{
+    // List copied from util-linux/libmount/src/utils.c
+    static const std::vector<QLatin1String> netfsList{
+        QLatin1String("cifs"),
+        QLatin1String("smb3"),
+        QLatin1String("smbfs"),
+        QLatin1String("nfs"),
+        QLatin1String("nfs3"),
+        QLatin1String("nfs4"),
+        QLatin1String("afs"),
+        QLatin1String("ncpfs"),
+        QLatin1String("fuse.curlftpfs"),
+        QLatin1String("fuse.sshfs"),
+        QLatin1String("9p"),
+    };
+
+    return std::any_of(netfsList.cbegin(), netfsList.cend(), [mountType](const QLatin1String netfs) {
+        return mountType == netfs;
+    });
+}
+
 class KMountPointPrivate
 {
 public:
@@ -60,6 +83,8 @@ public:
     QString m_mountPoint;
     QString m_mountType;
     QStringList m_mountOptions;
+    dev_t m_deviceId = 0;
+    bool m_isNetFs = false;
 };
 
 KMountPoint::KMountPoint()
@@ -112,19 +137,15 @@ static void translateMountOptions(QStringList &list, uint64_t flags)
 
 void KMountPointPrivate::finalizePossibleMountPoint(KMountPoint::DetailsNeededFlags infoNeeded)
 {
-    if (m_mountedFrom.startsWith(QLatin1String("UUID="))) {
-        const QStringRef uuid = m_mountedFrom.midRef(5);
-        const QString potentialDevice = QFile::symLinkTarget(QLatin1String("/dev/disk/by-uuid/") + uuid);
-        if (QFile::exists(potentialDevice)) {
-            m_mountedFrom = potentialDevice;
-        }
+    QString potentialDevice;
+    if (const auto tag = QLatin1String("UUID="); m_mountedFrom.startsWith(tag)) {
+        potentialDevice = QFile::symLinkTarget(QLatin1String("/dev/disk/by-uuid/") + QStringView(m_mountedFrom).mid(tag.size()));
+    } else if (const auto tag = QLatin1String("LABEL="); m_mountedFrom.startsWith(tag)) {
+        potentialDevice = QFile::symLinkTarget(QLatin1String("/dev/disk/by-label/") + QStringView(m_mountedFrom).mid(tag.size()));
     }
-    if (m_mountedFrom.startsWith(QLatin1String("LABEL="))) {
-        const QStringRef label = m_mountedFrom.midRef(6);
-        const QString potentialDevice = QFile::symLinkTarget(QLatin1String("/dev/disk/by-label/") + label);
-        if (QFile::exists(potentialDevice)) {
-            m_mountedFrom = potentialDevice;
-        }
+
+    if (QFile::exists(potentialDevice)) {
+        m_mountedFrom = potentialDevice;
     }
 
     if (infoNeeded & KMountPoint::NeedRealDeviceName) {
@@ -155,7 +176,7 @@ KMountPoint::List KMountPoint::possibleMountPoints(DetailsNeededFlags infoNeeded
 #ifdef Q_OS_WIN
     result = KMountPoint::currentMountPoints(infoNeeded);
 
-#elif HAVE_LIBS_MOUNT_AND_BLKID
+#elif HAVE_LIB_MOUNT
     if (struct libmnt_table *table = mnt_new_table()) {
         // By default parses "/etc/fstab"
         if (mnt_table_parse_fstab(table, nullptr) == 0) {
@@ -170,29 +191,24 @@ KMountPoint::List KMountPoint::possibleMountPoints(DetailsNeededFlags infoNeeded
 
                 Ptr mp(new KMountPoint);
                 mp->d->m_mountType = QFile::decodeName(fsType);
-                mp->d->m_mountPoint = QFile::decodeName(mnt_fs_get_target(fs));
+                const char *target = mnt_fs_get_target(fs);
+                mp->d->m_mountPoint = QFile::decodeName(target);
+
+                if (QT_STATBUF buff; QT_LSTAT(target, &buff) == 0) {
+                    mp->d->m_deviceId = buff.st_dev;
+                }
 
                 // First field in /etc/fstab, e.g. /dev/sdXY, LABEL=, UUID=, /some/bind/mount/dir
                 // or some network mount
                 if (const char *source = mnt_fs_get_source(fs)) {
                     mp->d->m_mountedFrom = QFile::decodeName(source);
-                    if (mp->d->m_mountedFrom.startsWith(QLatin1String("UUID")) || mp->d->m_mountedFrom.startsWith(QLatin1String("LABEL"))) {
-                        // Use blkid to resolve UUID/LABEL to the device file
-                        if (char *blkSource = blkid_evaluate_spec(source, nullptr)) {
-                            mp->d->m_mountedFrom = QFile::decodeName(blkSource);
-                            free(blkSource);
-                            if ((infoNeeded & KMountPoint::NeedRealDeviceName) //
-                                && mp->d->m_mountedFrom.startsWith(QLatin1String("/dev/"))) {
-                                mp->d->m_device = mp->d->m_mountedFrom;
-                            }
-                        }
-                    }
                 }
 
                 if (infoNeeded & NeedMountOptions) {
                     mp->d->m_mountOptions = QFile::decodeName(mnt_fs_get_options(fs)).split(QLatin1Char(','));
                 }
 
+                mp->d->finalizePossibleMountPoint(infoNeeded);
                 result.append(mp);
             }
             mnt_free_iter(itr);
@@ -283,12 +299,18 @@ KMountPoint::List KMountPoint::currentMountPoints(DetailsNeededFlags infoNeeded)
 
     int num_fs = getmntinfo(&mounted, MNT_NOWAIT);
 
+    result.reserve(num_fs);
+
     for (int i = 0; i < num_fs; i++) {
         Ptr mp(new KMountPoint);
         mp->d->m_mountedFrom = QFile::decodeName(mounted[i].f_mntfromname);
         mp->d->m_mountPoint = QFile::decodeName(mounted[i].f_mntonname);
         mp->d->m_mountType = QFile::decodeName(mounted[i].f_fstypename);
 
+        if (QT_STATBUF buff; QT_LSTAT(mounted[i].f_mntonname, &buff) == 0) {
+            mp->d->m_deviceId = buff.st_dev;
+        }
+
         if (infoNeeded & NeedMountOptions) {
             struct fstab *ft = getfsfile(mounted[i].f_mntonname);
             if (ft != nullptr) {
@@ -319,10 +341,12 @@ KMountPoint::List KMountPoint::currentMountPoints(DetailsNeededFlags infoNeeded)
         }
     }
 
-#elif HAVE_LIBS_MOUNT_AND_BLKID
+#elif HAVE_LIB_MOUNT
     if (struct libmnt_table *table = mnt_new_table()) {
-        // By default, parses "/proc/self/mountinfo"
-        if (mnt_table_parse_mtab(table, nullptr) == 0) {
+        // if "/etc/mtab" is a regular file,
+        // "/etc/mtab" is used by default instead of "/proc/self/mountinfo" file.
+        // This leads to NTFS mountpoints being hidden.
+        if (mnt_table_parse_mtab(table, "/proc/self/mountinfo") == 0) {
             struct libmnt_iter *itr = mnt_new_iter(MNT_ITER_FORWARD);
             struct libmnt_fs *fs;
 
@@ -331,6 +355,8 @@ KMountPoint::List KMountPoint::currentMountPoints(DetailsNeededFlags infoNeeded)
                 mp->d->m_mountedFrom = QFile::decodeName(mnt_fs_get_source(fs));
                 mp->d->m_mountPoint = QFile::decodeName(mnt_fs_get_target(fs));
                 mp->d->m_mountType = QFile::decodeName(mnt_fs_get_fstype(fs));
+                mp->d->m_isNetFs = mnt_fs_is_netfs(fs) == 1;
+                mp->d->m_deviceId = mnt_fs_get_devno(fs);
 
                 if (infoNeeded & NeedMountOptions) {
                     mp->d->m_mountOptions = QFile::decodeName(mnt_fs_get_options(fs)).split(QLatin1Char(','));
@@ -363,6 +389,16 @@ QString KMountPoint::mountedFrom() const
     return d->m_mountedFrom;
 }
 
+dev_t KMountPoint::deviceId() const
+{
+    return d->m_deviceId;
+}
+
+bool KMountPoint::isOnNetwork() const
+{
+    return d->m_isNetFs || isNetfs(d->m_mountType);
+}
+
 QString KMountPoint::realDeviceName() const
 {
     return d->m_device;
@@ -388,45 +424,32 @@ KMountPoint::List::List()
 {
 }
 
-static bool pathsAreParentAndChildOrEqual(const QString &parent, const QString &child)
-{
-    const QLatin1Char slash('/');
-    if (child.startsWith(parent, cs)) {
-        // Check if either
-        // (a) both paths are equal, or
-        // (b) parent ends with '/', or
-        // (c) the first character of child that is not shared with parent is '/'.
-        //     Note that child is guaranteed to be longer than parent if (a) is false.
-        //
-        // This prevents that we incorrectly consider "/books" a child of "/book".
-        return parent.compare(child, cs) == 0 || parent.endsWith(slash) || child.at(parent.length()) == slash;
-    } else {
-        // Note that "/books" is a child of "/books/".
-        return parent.endsWith(slash) && (parent.length() == child.length() + 1) && parent.startsWith(child, cs);
-    }
-}
-
 KMountPoint::Ptr KMountPoint::List::findByPath(const QString &path) const
 {
-#ifndef Q_OS_WIN
+#ifdef Q_OS_WIN
+    const QString realPath = QDir::fromNativeSeparators(QDir(path).absolutePath());
+#else
     /* If the path contains symlinks, get the real name */
     QFileInfo fileinfo(path);
-    const QString realname = fileinfo.exists() ? fileinfo.canonicalFilePath() : fileinfo.absolutePath(); // canonicalFilePath won't work unless file exists
-#else
-    const QString realname = QDir::fromNativeSeparators(QDir(path).absolutePath());
+    // canonicalFilePath won't work unless file exists
+    const QString realPath = fileinfo.exists() ? fileinfo.canonicalFilePath() : fileinfo.absolutePath();
 #endif
 
-    int max = 0;
     KMountPoint::Ptr result;
-    for (const KMountPoint::Ptr &mp : *this) {
-        const QString mountpoint = mp->d->m_mountPoint;
-        const int length = mountpoint.length();
-        if (length > max && pathsAreParentAndChildOrEqual(mountpoint, realname)) {
-            max = length;
-            result = mp;
-            // keep iterating to check for a better match (bigger max)
+
+    if (QT_STATBUF buff; QT_LSTAT(QFile::encodeName(realPath).constData(), &buff) == 0) {
+        auto it = std::find_if(this->cbegin(), this->cend(), [&buff, &realPath](const KMountPoint::Ptr &mountPtr) {
+            // For a bind mount, the deviceId() is that of the base mount point, e.g. /mnt/foo,
+            // however the path we're looking for, e.g. /home/user/bar, doesn't start with the
+            // mount point of the base device, so we go on searching
+            return mountPtr->deviceId() == buff.st_dev && realPath.startsWith(mountPtr->mountPoint());
+        });
+
+        if (it != this->cend()) {
+            result = *it;
         }
     }
+
     return result;
 }
 
@@ -447,9 +470,7 @@ KMountPoint::Ptr KMountPoint::List::findByDevice(const QString &device) const
 bool KMountPoint::probablySlow() const
 {
     /* clang-format off */
-    return d->m_mountType == QLatin1String("nfs")
-        || d->m_mountType == QLatin1String("nfs4")
-        || d->m_mountType == QLatin1String("cifs")
+    return isOnNetwork()
         || d->m_mountType == QLatin1String("autofs")
         || d->m_mountType == QLatin1String("subfs")
         // Technically KIOFUSe mounts local slaves as well,
@@ -471,6 +492,7 @@ bool KMountPoint::testFileSystemFlag(FileSystemFlag flag) const
                         || d->m_mountType == QLatin1String("fuseblk");
 
     const bool isSmb = d->m_mountType == QLatin1String("cifs")
+                       || d->m_mountType == QLatin1String("smb3")
                        || d->m_mountType == QLatin1String("smbfs")
                        // gvfs-fuse mounted SMB share
                        || d->m_mountType == QLatin1String("smb-share");
