@@ -1,22 +1,12 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2000-2001 Waldo Bastian <bastian@kde.org>
-   Copyright     2012 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2000-2001 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2012 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
+
 #ifndef KPROTOCOLINFOPRIVATE_H
 #define KPROTOCOLINFOPRIVATE_H
 
@@ -30,7 +20,9 @@
 class KProtocolInfoPrivate
 {
 public:
-    KProtocolInfoPrivate(const QString &path);
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 84)
+    explicit KProtocolInfoPrivate(const QString &path);
+#endif
     KProtocolInfoPrivate(const QString &name, const QString &exec, const QJsonObject &json);
 
     QString m_name;
@@ -48,6 +40,7 @@ public:
     bool m_supportsLinking : 1;
     bool m_supportsMoving : 1;
     bool m_supportsOpening : 1;
+    bool m_supportsTruncating : 1;
     bool m_determineMimetypeFromExtension : 1;
     bool m_canCopyFromFile : 1;
     bool m_canCopyToFile : 1;
