@@ -11,21 +11,22 @@
 
 using namespace KIO;
 
-class KIO::MimetypeJobPrivate: public KIO::TransferJobPrivate
+class KIO::MimetypeJobPrivate : public KIO::TransferJobPrivate
 {
 public:
     MimetypeJobPrivate(const QUrl &url, int command, const QByteArray &packedArgs)
         : TransferJobPrivate(url, command, packedArgs, QByteArray())
-    {}
+    {
+    }
 
     Q_DECLARE_PUBLIC(MimetypeJob)
 
-    static inline MimetypeJob *newJob(const QUrl &url, int command, const QByteArray &packedArgs,
-                                      JobFlags flags)
+    static inline MimetypeJob *newJob(const QUrl &url, int command, const QByteArray &packedArgs, JobFlags flags)
     {
         MimetypeJob *job = new MimetypeJob(*new MimetypeJobPrivate(url, command, packedArgs));
         job->setUiDelegate(KIO::createDefaultJobUiDelegate());
         if (!(flags & HideProgressInfo)) {
+            JobPrivate::setTransient(job);
             KIO::getJobTracker()->registerJob(job);
             emitStating(job, url);
         }
@@ -45,24 +46,24 @@ MimetypeJob::~MimetypeJob()
 void MimetypeJob::slotFinished()
 {
     Q_D(MimetypeJob);
-    //qDebug();
+    // qDebug();
     if (error() == KIO::ERR_IS_DIRECTORY) {
         // It is in fact a directory. This happens when HTTP redirects to FTP.
         // Due to the "protocol doesn't support listing" code in KRun, we
         // assumed it was a file.
-        //qDebug() << "It is in fact a directory!";
+        // qDebug() << "It is in fact a directory!";
         d->m_mimetype = QStringLiteral("inode/directory");
 #if KIOCORE_BUILD_DEPRECATED_SINCE(5, 78)
-        emit TransferJob::mimetype(this, d->m_mimetype);
+        Q_EMIT TransferJob::mimetype(this, d->m_mimetype);
 #endif
-        emit TransferJob::mimeTypeFound(this, d->m_mimetype);
+        Q_EMIT TransferJob::mimeTypeFound(this, d->m_mimetype);
         setError(0);
     }
 
     if (!d->m_redirectionURL.isEmpty() && d->m_redirectionURL.isValid() && !error()) {
-        //qDebug() << "Redirection to " << m_redirectionURL;
+        // qDebug() << "Redirection to " << m_redirectionURL;
         if (queryMetaData(QStringLiteral("permanent-redirect")) == QLatin1String("true")) {
-            emit permanentRedirection(this, d->m_url, d->m_redirectionURL);
+            Q_EMIT permanentRedirection(this, d->m_url, d->m_redirectionURL);
         }
 
         if (d->m_redirectionHandlingEnabled) {
