@@ -7,12 +7,12 @@
 */
 
 #include "mkpathjob.h"
+#include "../pathhelpers_p.h"
 #include "job_p.h"
 #include "mkdirjob.h"
-#include "../pathhelpers_p.h"
 
-#include <QTimer>
 #include <QFileInfo>
+#include <QTimer>
 
 using namespace KIO;
 
@@ -20,21 +20,13 @@ class KIO::MkpathJobPrivate : public KIO::JobPrivate
 {
 public:
     MkpathJobPrivate(const QUrl &url, const QUrl &baseUrl, JobFlags flags)
-        : JobPrivate(),
-          m_url(url),
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-          m_pathComponents(url.path().split(QLatin1Char('/'), QString::SkipEmptyParts)),
-#else
-          m_pathComponents(url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts)),
-#endif
-          m_pathIterator(),
-          m_flags(flags)
+        : JobPrivate()
+        , m_url(url)
+        , m_pathComponents(url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts))
+        , m_pathIterator()
+        , m_flags(flags)
     {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        const QStringList basePathComponents = baseUrl.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
-#else
         const QStringList basePathComponents = baseUrl.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#endif
 
 #ifdef Q_OS_WIN
         const QString startPath;
@@ -102,7 +94,6 @@ public:
         }
         return job;
     }
-
 };
 
 MkpathJob::MkpathJob(MkpathJobPrivate &dd)
@@ -125,7 +116,7 @@ void MkpathJobPrivate::slotStart()
 
     if (m_pathIterator != m_pathComponents.constEnd()) {
         m_url.setPath(concatPaths(m_url.path(), *m_pathIterator));
-        KIO::Job* job = KIO::mkdir(m_url);
+        KIO::Job *job = KIO::mkdir(m_url);
         job->setParentJob(q);
         q->addSubjob(job);
         q->setProcessedAmount(KJob::Directories, q->processedAmount(KJob::Directories) + 1);
@@ -143,7 +134,7 @@ void MkpathJob::slotResult(KJob *job)
     }
     removeSubjob(job);
 
-    emit directoryCreated(d->m_url);
+    Q_EMIT directoryCreated(d->m_url);
 
     // Move on to next one
     ++d->m_pathIterator;
@@ -151,7 +142,7 @@ void MkpathJob::slotResult(KJob *job)
     d->slotStart();
 }
 
-MkpathJob * KIO::mkpath(const QUrl &url, const QUrl &baseUrl, KIO::JobFlags flags)
+MkpathJob *KIO::mkpath(const QUrl &url, const QUrl &baseUrl, KIO::JobFlags flags)
 {
     return MkpathJobPrivate::newJob(url, baseUrl, flags);
 }
