@@ -1,20 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright 2014  David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2014 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_RESTOREJOB_H
@@ -23,14 +11,15 @@
 #include <QObject>
 #include <QUrl>
 
-#include "kiocore_export.h"
 #include "job_base.h"
+#include "kiocore_export.h"
 
 namespace KIO
 {
-
 class RestoreJobPrivate;
 /**
+ * @class KIO::RestoreJob restorejob.h <KIO/RestoreJob>
+ *
  * RestoreJob is used to restore files from the trash.
  * Don't create the job directly, but use KIO::restoreFromTrash().
  *
@@ -43,7 +32,7 @@ class KIOCORE_EXPORT RestoreJob : public Job
     Q_OBJECT
 
 public:
-    virtual ~RestoreJob();
+    ~RestoreJob() override;
 
     /**
      * Returns the list of trash URLs to restore.
@@ -53,7 +42,7 @@ public:
 Q_SIGNALS:
 
 protected Q_SLOTS:
-    void slotResult(KJob *job) Q_DECL_OVERRIDE;
+    void slotResult(KJob *job) override;
 
 protected:
     RestoreJob(RestoreJobPrivate &dd);
