@@ -53,7 +53,7 @@ class SchedulerPrivate;
  *    KIO::Scheduler::setJobPriority(job, 1);
  * \endcode
  *
- * <h3>3. Connection Oriented</h3>
+ * <h3>3. Connection Oriented (TODO KF6 remove this section)</h3>
  * For some operations it is important that multiple jobs use
  * the same connection. This can only be ensured if all these jobs
  * use the same slave.
@@ -118,6 +118,7 @@ public:
     static void scheduleJob(SimpleJob *job);
 #endif
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 90)
     /**
      * Changes the priority of @p job; jobs of the same priority run in the order in which
      * they were created. Jobs of lower numeric priority always run before any
@@ -125,8 +126,15 @@ public:
      * the default priority of jobs is 0.
      * @param job the job to change
      * @param priority new priority of @p job, lower runs earlier
+     * @deprecated Since 5.90. Changing priorities was only used by KHTML. If you need this, please contact kde-frameworks-devel to request the feature back,
+     * but as better API like Job::setPriority.
      */
+    KIOCORE_DEPRECATED_VERSION(5,
+                               90,
+                               "Changing priorities was only used by KHTML. If you need this, please contact kde-frameworks-devel to request the feature back, "
+                               "but as better API like Job::setPriority.")
     static void setJobPriority(SimpleJob *job, int priority);
+#endif
 
     /**
      * Stop the execution of a job.
@@ -160,13 +168,18 @@ public:
      */
     static void removeSlaveOnHold();
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 88)
     /**
      * Send the slave that was put on hold back to KLauncher. This
      * allows another process to take over the slave and resume the job
      * that was started.
+     * @deprecated since 5.88, the feature of holding slaves between processes is gone, just remove the call
      */
+    KIOCORE_DEPRECATED_VERSION(5, 88, "Remove this call. The feature is gone")
     static void publishSlaveOnHold();
+#endif
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 91)
     /**
      * Requests a slave for use in connection-oriented mode.
      *
@@ -177,9 +190,13 @@ public:
      * @return A pointer to a connected slave or @c nullptr if an error occurred.
      * @see assignJobToSlave()
      * @see disconnectSlave()
+     * @deprecated since 5.91 Port away from the connected slave feature, e.g. making a library out of the slave code.
      */
+    KIOCORE_DEPRECATED_VERSION(5, 91, "Port away from the connected slave feature, e.g. making a library out of the slave code.")
     static KIO::Slave *getConnectedSlave(const QUrl &url, const KIO::MetaData &config = MetaData());
+#endif
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 91)
     /**
      * Uses @p slave to do @p job.
      * This function should be called immediately after creating a Job.
@@ -195,9 +212,13 @@ public:
      * @see disconnectSlave()
      * @see slaveConnected()
      * @see slaveError()
+     * @deprecated since 5.91 Port away from the connected slave feature, e.g. making a library out of the slave code.
      */
+    KIOCORE_DEPRECATED_VERSION(5, 91, "Port away from the connected slave feature, e.g. making a library out of the slave code.")
     static bool assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job);
+#endif
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 91)
     /**
      * Disconnects @p slave.
      *
@@ -209,8 +230,11 @@ public:
      *
      * @see getConnectedSlave
      * @see assignJobToSlave
+     * @deprecated since 5.91 Port away from the connected slave feature, e.g. making a library out of the slave code.
      */
+    KIOCORE_DEPRECATED_VERSION(5, 91, "Port away from the connected slave feature, e.g. making a library out of the slave code.")
     static bool disconnectSlave(KIO::Slave *slave);
+#endif
 
     /**
      * Function to connect signals emitted by the scheduler.
@@ -227,12 +251,16 @@ public:
 
     bool connect(const QObject *sender, const char *signal, const char *member);
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 88)
     /**
      * When true, the next job will check whether KLauncher has a slave
      * on hold that is suitable for the job.
      * @param b true when KLauncher has a job on hold
+     * @deprecated since 5.88, the feature of holding slaves between processes is gone, just remove the call
      */
+    KIOCORE_DEPRECATED_VERSION(5, 88, "Remove this call. The feature is gone")
     static void checkSlaveOnHold(bool b);
+#endif
 
     static void emitReparseSlaveConfiguration();
 
@@ -251,29 +279,52 @@ public:
     static void updateInternalMetaData(SimpleJob *job);
 
 Q_SIGNALS:
-    void slaveConnected(KIO::Slave *slave);
-    void slaveError(KIO::Slave *slave, int error, const QString &errorMsg);
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 91)
+    /**
+     * @deprecated since 5.91 Port away from the connected slave feature, e.g. making a library out of the slave code.
+     */
+    KIOCORE_DEPRECATED_VERSION(5, 91, "Port away from the connected slave feature, e.g. making a library out of the slave code.")
+    QT_MOC_COMPAT void slaveConnected(KIO::Slave *slave);
+
+    /**
+     * @deprecated since 5.91 Port away from the connected slave feature, e.g. making a library out of the slave code.
+     */
+    KIOCORE_DEPRECATED_VERSION(5, 91, "Port away from the connected slave feature, e.g. making a library out of the slave code.")
+    QT_MOC_COMPAT void slaveError(KIO::Slave *slave, int error, const QString &errorMsg);
+#endif
 
     // DBUS
     Q_SCRIPTABLE void reparseSlaveConfiguration(const QString &);
+
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 91)
+    /**
+     * @deprecated since 5.91 Port away from the connected slave feature, e.g. making a library out of the slave code.
+     */
+    KIOCORE_DEPRECATED_VERSION(5, 91, "Removed for lack of usage, and due to feature removal.")
     Q_SCRIPTABLE void slaveOnHoldListChanged();
+#endif
 
 private:
     Q_DISABLE_COPY(Scheduler)
     Scheduler();
-    ~Scheduler();
+    ~Scheduler() override;
 
     static Scheduler *self();
 
-    Q_PRIVATE_SLOT(d_func(), void slotSlaveDied(KIO::Slave *slave))
-    Q_PRIVATE_SLOT(d_func(), void slotSlaveStatus(qint64 pid, const QByteArray &protocol, const QString &host, bool connected))
+    friend class AccessManager;
+    // For internal use, since 5.90
+    static void setSimpleJobPriority(SimpleJob *job, int priority);
 
     // connected to D-Bus signal:
+#ifndef KIO_ANDROID_STUB
     Q_PRIVATE_SLOT(d_func(), void slotReparseSlaveConfiguration(const QString &, const QDBusMessage &))
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotSlaveOnHoldListChanged())
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 91)
     Q_PRIVATE_SLOT(d_func(), void slotSlaveConnected())
     Q_PRIVATE_SLOT(d_func(), void slotSlaveError(int error, const QString &errorMsg))
+#endif
 private:
     friend class SchedulerPrivate;
     SchedulerPrivate *d_func();
