@@ -11,25 +11,26 @@
 #include <qplatformdefs.h>
 #include <stdio.h>
 
+#include <QCoreApplication>
+#include <QDataStream>
+#include <QDir>
 #include <QElapsedTimer>
 #include <QFile>
+#include <QLibraryInfo>
+#include <QPluginLoader>
 #include <QProcess>
 #include <QStandardPaths>
 #include <QTimer>
 
+#include <KLibexec>
 #include <KLocalizedString>
-#include <QDBusConnection>
-
-#include <KDEInitInterface>
-#include <KPluginLoader>
-#include <klauncher_interface.h>
 
 #include "commands_p.h"
 #include "connection_p.h"
 #include "connectionserver.h"
 #include "dataprotocol_p.h"
 #include "kioglobal_p.h"
-#include <config-kiocore.h> // KDE_INSTALL_FULL_LIBEXECDIR_KF5
+#include <config-kiocore.h> // KDE_INSTALL_FULL_LIBEXECDIR_KF
 #include <kprotocolinfo.h>
 
 #include "kiocoredebug.h"
@@ -37,72 +38,18 @@
 
 using namespace KIO;
 
-#define SLAVE_CONNECTION_TIMEOUT_MIN 2
+static constexpr int s_slaveConnectionTimeoutMin = 2;
 
 // Without debug info we consider it an error if the slave doesn't connect
 // within 10 seconds.
 // With debug info we give the slave an hour so that developers have a chance
 // to debug their slave.
 #ifdef NDEBUG
-#define SLAVE_CONNECTION_TIMEOUT_MAX 10
+static constexpr int s_slaveConnectionTimeoutMax = 10;
 #else
-#define SLAVE_CONNECTION_TIMEOUT_MAX 3600
+static constexpr int s_slaveConnectionTimeoutMax = 3600;
 #endif
 
-static QThreadStorage<org::kde::KSlaveLauncher *> s_kslaveLauncher;
-
-static org::kde::KSlaveLauncher *klauncher()
-{
-    KDEInitInterface::ensureKdeinitRunning();
-    if (!s_kslaveLauncher.hasLocalData()) {
-        org::kde::KSlaveLauncher *launcher =
-            new org::kde::KSlaveLauncher(QStringLiteral("org.kde.klauncher5"), QStringLiteral("/KLauncher"), QDBusConnection::sessionBus());
-        s_kslaveLauncher.setLocalData(launcher);
-        return launcher;
-    }
-    return s_kslaveLauncher.localData();
-}
-
-// In such case we start the slave via QProcess.
-// It's possible to force this by setting the env. variable
-// KDE_FORK_SLAVES, Clearcase seems to require this.
-static QBasicAtomicInt bForkSlaves =
-#if KIO_FORK_SLAVES
-    Q_BASIC_ATOMIC_INITIALIZER(1);
-#else
-    Q_BASIC_ATOMIC_INITIALIZER(-1);
-#endif
-
-static bool forkSlaves()
-{
-    // In such case we start the slave via QProcess.
-    // It's possible to force this by setting the env. variable
-    // KDE_FORK_SLAVES, Clearcase seems to require this.
-    if (bForkSlaves.loadRelaxed() == -1) {
-        bool fork = qEnvironmentVariableIsSet("KDE_FORK_SLAVES");
-
-        // no dbus? => fork slaves as we can't talk to klauncher
-        if (!fork) {
-            fork = !QDBusConnection::sessionBus().interface();
-        }
-
-#ifdef Q_OS_UNIX
-        if (!fork) {
-            // check the UID of klauncher
-            QDBusReply<uint> reply = QDBusConnection::sessionBus().interface()->serviceUid(klauncher()->service());
-            // if reply is not valid, fork, most likely klauncher can not be run or is not installed
-            // fallback: if there's an klauncher process owned by a different user: still fork
-            if (!reply.isValid() || getuid() != reply) {
-                fork = true;
-            }
-        }
-#endif
-
-        bForkSlaves.testAndSetRelaxed(-1, fork ? 1 : 0);
-    }
-    return bForkSlaves.loadRelaxed() == 1;
-}
-
 namespace KIO
 {
 /**
@@ -175,8 +122,8 @@ void Slave::timeout()
     if (d->m_pid && KIOPrivate::isProcessAlive(d->m_pid)) {
         int delta_t = d->contact_started.elapsed() / 1000;
         // qDebug() << "slave is slow... pid=" << d->m_pid << " t=" << delta_t;
-        if (delta_t < SLAVE_CONNECTION_TIMEOUT_MAX) {
-            QTimer::singleShot(1000 * SLAVE_CONNECTION_TIMEOUT_MIN, this, &Slave::timeout);
+        if (delta_t < s_slaveConnectionTimeoutMax) {
+            QTimer::singleShot(1000 * s_slaveConnectionTimeoutMin, this, &Slave::timeout);
             return;
         }
     }
@@ -338,6 +285,7 @@ bool Slave::isAlive()
     return !d->dead;
 }
 
+// TODO KF6: remove, unused
 void Slave::hold(const QUrl &url)
 {
     Q_D(Slave);
@@ -352,10 +300,6 @@ void Slave::hold(const QUrl &url)
         Q_EMIT slaveDied(this);
     }
     deref();
-    // Call KSlaveLauncher::waitForSlave(pid);
-    {
-        klauncher()->waitForSlave(d->m_pid);
-    }
 }
 
 void Slave::suspend()
@@ -416,6 +360,7 @@ void Slave::kill()
         KIOPrivate::sendTerminateSignal(d->m_pid);
         d->m_pid = 0;
     }
+    deref();
 }
 
 void Slave::setHost(const QString &host, quint16 port, const QString &user, const QString &passwd)
@@ -451,6 +396,7 @@ void Slave::setConfig(const MetaData &config)
 
 Slave *Slave::createSlave(const QString &protocol, const QUrl &url, int &error, QString &error_text)
 {
+    Q_UNUSED(url)
     // qDebug() << "createSlave" << protocol << "for" << url;
     // Firstly take into account all special slaves
     if (protocol == QLatin1String("data")) {
@@ -465,112 +411,64 @@ Slave *Slave::createSlave(const QString &protocol, const QUrl &url, int &error,
         return nullptr;
     }
 
-    if (forkSlaves() == 1) {
-        QString _name = KProtocolInfo::exec(protocol);
-        if (_name.isEmpty()) {
-            error_text = i18n("Unknown protocol '%1'.", protocol);
-            error = KIO::ERR_CANNOT_CREATE_SLAVE;
-            delete slave;
-            return nullptr;
-        }
-        // find the kioslave using KPluginLoader; kioslave would do this
-        // anyway, but if it doesn't exist, we want to be able to return
-        // a useful error message immediately
-        QString lib_path = KPluginLoader::findPlugin(_name);
-        if (lib_path.isEmpty()) {
-            error_text = i18n("Can not find io-slave for protocol '%1'.", protocol);
-            error = KIO::ERR_CANNOT_CREATE_SLAVE;
-            delete slave;
-            return nullptr;
-        }
-
-        const QStringList args = QStringList{lib_path, protocol, QString(), slaveAddress.toString()};
-        // qDebug() << "kioslave" << ", " << lib_path << ", " << protocol << ", " << QString() << ", " << slaveAddress;
-
-        // look where libexec path is (can be set in qt.conf)
-        const QString qlibexec = QLibraryInfo::location(QLibraryInfo::LibraryExecutablesPath);
-        // on !win32 we use a kf5 suffix
-        const QString qlibexecKF5 = QDir(qlibexec).filePath(QStringLiteral("kf5"));
-
-        // search paths
-        const QStringList searchPaths = QStringList() << QCoreApplication::applicationDirPath() // then look where our application binary is located
-                                                      << qlibexec << qlibexecKF5
-                                                      << QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF5); // look at our installation location
-        QString kioslaveExecutable = QStandardPaths::findExecutable(QStringLiteral("kioslave5"), searchPaths);
-        if (kioslaveExecutable.isEmpty()) {
-            // Fallback to PATH. On win32 we install to bin/ which tests outside
-            // KIO cannot not find at the time ctest is run because it
-            // isn't the same as applicationDirPath().
-            kioslaveExecutable = QStandardPaths::findExecutable(QStringLiteral("kioslave5"));
-        }
-        if (kioslaveExecutable.isEmpty()) {
-            error_text = i18n("Can not find 'kioslave5' executable at '%1'", searchPaths.join(QLatin1String(", ")));
-            error = KIO::ERR_CANNOT_CREATE_SLAVE;
-            delete slave;
-            return nullptr;
-        }
-
-        qint64 pid = 0;
-        QProcess::startDetached(kioslaveExecutable, args, QString(), &pid);
-        slave->setPID(pid);
-
-        return slave;
-    }
-
-    QString errorStr;
-    QDBusReply<int> reply = klauncher()->requestSlave(protocol, url.host(), slaveAddress.toString(), errorStr);
-    if (!reply.isValid()) {
-        error_text = i18n("Cannot talk to klauncher: %1", klauncher()->lastError().message());
+    const QString _name = KProtocolInfo::exec(protocol);
+    if (_name.isEmpty()) {
+        error_text = i18n("Unknown protocol '%1'.", protocol);
         error = KIO::ERR_CANNOT_CREATE_SLAVE;
         delete slave;
         return nullptr;
     }
-    qint64 pid = reply;
-    if (!pid) {
-        error_text = i18n("klauncher said: %1", errorStr);
+    // find the kioslave using QPluginLoader; kioslave would do this
+    // anyway, but if it doesn't exist, we want to be able to return
+    // a useful error message immediately
+    QPluginLoader loader(_name);
+    const QString lib_path = loader.fileName();
+    if (lib_path.isEmpty()) {
+        error_text = i18n("Can not find io-slave for protocol '%1'.", protocol);
         error = KIO::ERR_CANNOT_CREATE_SLAVE;
         delete slave;
         return nullptr;
     }
+
+    const QStringList args = QStringList{lib_path, protocol, QString(), slaveAddress.toString()};
+    // qDebug() << "kioslave" << ", " << lib_path << ", " << protocol << ", " << QString() << ", " << slaveAddress;
+
+    // search paths
+    QStringList searchPaths = KLibexec::kdeFrameworksPaths(QStringLiteral("libexec/kf5"));
+    searchPaths.append(QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF)); // look at our installation location
+    QString kioslaveExecutable = QStandardPaths::findExecutable(QStringLiteral("kioslave5"), searchPaths);
+    if (kioslaveExecutable.isEmpty()) {
+        // Fallback to PATH. On win32 we install to bin/ which tests outside
+        // KIO cannot not find at the time ctest is run because it
+        // isn't the same as applicationDirPath().
+        kioslaveExecutable = QStandardPaths::findExecutable(QStringLiteral("kioslave5"));
+    }
+    if (kioslaveExecutable.isEmpty()) {
+        error_text = i18n("Can not find 'kioslave5' executable at '%1'", searchPaths.join(QLatin1String(", ")));
+        error = KIO::ERR_CANNOT_CREATE_SLAVE;
+        delete slave;
+        return nullptr;
+    }
+
+    qint64 pid = 0;
+    QProcess::startDetached(kioslaveExecutable, args, QString(), &pid);
     slave->setPID(pid);
-    QTimer::singleShot(1000 * SLAVE_CONNECTION_TIMEOUT_MIN, slave, &Slave::timeout);
+
     return slave;
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 88)
 Slave *Slave::holdSlave(const QString &protocol, const QUrl &url)
 {
-    // qDebug() << "holdSlave" << protocol << "for" << url;
-    // Firstly take into account all special slaves
-    if (protocol == QLatin1String("data")) {
-        return nullptr;
-    }
-
-    if (forkSlaves()) {
-        return nullptr;
-    }
-
-    Slave *slave = new Slave(protocol);
-    QUrl slaveAddress = slave->d_func()->slaveconnserver->address();
-    QDBusReply<int> reply = klauncher()->requestHoldSlave(url.toString(), slaveAddress.toString());
-    if (!reply.isValid()) {
-        delete slave;
-        return nullptr;
-    }
-    qint64 pid = reply;
-    if (!pid) {
-        delete slave;
-        return nullptr;
-    }
-    slave->setPID(pid);
-    QTimer::singleShot(1000 * SLAVE_CONNECTION_TIMEOUT_MIN, slave, &Slave::timeout);
-    return slave;
+    Q_UNUSED(protocol)
+    Q_UNUSED(url)
+    return nullptr;
 }
+#endif
 
-bool Slave::checkForHeldSlave(const QUrl &url)
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 88)
+bool Slave::checkForHeldSlave(const QUrl &)
 {
-    if (forkSlaves()) {
-        return false;
-    }
-
-    return klauncher()->checkForHeldSlave(url.toString());
+    return false;
 }
+#endif
