@@ -9,24 +9,25 @@
 #include "slaveinterface_p.h"
 #include "usernotificationhandler_p.h"
 
-#include "slavebase.h"
-#include "connection_p.h"
 #include "commands_p.h"
+#include "connection_p.h"
 #include "hostinfo.h"
-#include <signal.h>
+#include "slavebase.h"
 #include <KLocalizedString>
+#include <signal.h>
 #include <time.h>
 
-#include <QDebug>
-#include <QDateTime>
 #include <QDataStream>
+#include <QDateTime>
+#include <QDebug>
 
 using namespace KIO;
 
 Q_GLOBAL_STATIC(UserNotificationHandler, globalUserNotificationHandler)
 
 SlaveInterface::SlaveInterface(SlaveInterfacePrivate &dd, QObject *parent)
-    : QObject(parent), d_ptr(&dd)
+    : QObject(parent)
+    , d_ptr(&dd)
 {
     connect(&d_ptr->speed_timer, &QTimer::timeout, this, &SlaveInterface::calcSpeed);
 }
@@ -103,26 +104,26 @@ void SlaveInterface::calcSpeed()
 
         KIO::filesize_t lspeed = 1000 * (d->sizes[d->nums - 1] - d->sizes[0]) / (d->times[d->nums - 1] - d->times[0]);
 
-//qDebug() << (long)d->filesize << diff
-//          << long(d->sizes[d->nums-1] - d->sizes[0])
-//          << d->times[d->nums-1] - d->times[0]
-//          << long(lspeed) << double(d->filesize) / diff
-//          << convertSize(lspeed)
-//          << convertSize(long(double(d->filesize) / diff) * 1000);
+        // qDebug() << (long)d->filesize << diff
+        //          << long(d->sizes[d->nums-1] - d->sizes[0])
+        //          << d->times[d->nums-1] - d->times[0]
+        //          << long(lspeed) << double(d->filesize) / diff
+        //          << convertSize(lspeed)
+        //          << convertSize(long(double(d->filesize) / diff) * 1000);
 
         if (!lspeed) {
             d->nums = 1;
             d->times[0] = diff;
             d->sizes[0] = d->filesize - d->offset;
         }
-        emit speed(lspeed);
+        Q_EMIT speed(lspeed);
     }
 }
 
 bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
 {
     Q_D(SlaveInterface);
-    //qDebug() << "dispatch " << _cmd;
+    // qDebug() << "dispatch " << _cmd;
 
     QDataStream stream(rawdata);
 
@@ -133,24 +134,24 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
 
     switch (_cmd) {
     case MSG_DATA:
-        emit data(rawdata);
+        Q_EMIT data(rawdata);
         break;
     case MSG_DATA_REQ:
-        emit dataReq();
+        Q_EMIT dataReq();
         break;
     case MSG_OPENED:
-        emit open();
+        Q_EMIT open();
         break;
     case MSG_FINISHED:
-        //qDebug() << "Finished [this = " << this << "]";
+        // qDebug() << "Finished [this = " << this << "]";
         d->offset = 0;
         d->speed_timer.stop();
-        emit finished();
+        Q_EMIT finished();
         break;
     case MSG_STAT_ENTRY: {
         UDSEntry entry;
         stream >> entry;
-        emit statEntry(entry);
+        Q_EMIT statEntry(entry);
         break;
     }
     case MSG_LIST_ENTRIES: {
@@ -162,22 +163,22 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
             list.append(entry);
         }
 
-        emit listEntries(list);
+        Q_EMIT listEntries(list);
         break;
     }
     case MSG_RESUME: { // From the put job
         d->offset = readFilesize_t(stream);
-        emit canResume(d->offset);
+        Q_EMIT canResume(d->offset);
         break;
     }
     case MSG_CANRESUME: // From the get job
         d->filesize = d->offset;
-        emit canResume(0); // the arg doesn't matter
+        Q_EMIT canResume(0); // the arg doesn't matter
         break;
     case MSG_ERROR:
         stream >> i >> str1;
-        //qDebug() << "error " << i << " " << str1;
-        emit error(i, str1);
+        // qDebug() << "error " << i << " " << str1;
+        Q_EMIT error(i, str1);
         break;
 #if KIOCORE_BUILD_DEPRECATED_SINCE(5, 45)
     case MSG_SLAVE_STATUS:
@@ -186,15 +187,15 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
         qint64 pid;
         QByteArray protocol;
         stream >> pid >> protocol >> str1 >> b;
-        emit slaveStatus(pid, protocol, str1, (b != 0));
+        Q_EMIT slaveStatus(pid, protocol, str1, (b != 0));
         break;
     }
     case MSG_CONNECTED:
-        emit connected();
+        Q_EMIT connected();
         break;
     case MSG_WRITTEN: {
         KIO::filesize_t size = readFilesize_t(stream);
-        emit written(size);
+        Q_EMIT written(size);
         break;
     }
     case INF_TOTAL_SIZE: {
@@ -207,58 +208,62 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
         d->nums = 1;
         d->speed_timer.start(1000);
         d->slave_calcs_speed = false;
-        emit totalSize(size);
+        Q_EMIT totalSize(size);
         break;
     }
     case INF_PROCESSED_SIZE: {
         KIO::filesize_t size = readFilesize_t(stream);
-        emit processedSize(size);
+        Q_EMIT processedSize(size);
         d->filesize = size;
         break;
     }
     case INF_POSITION: {
         KIO::filesize_t pos = readFilesize_t(stream);
-        emit position(pos);
+        Q_EMIT position(pos);
         break;
     }
     case INF_TRUNCATED: {
         KIO::filesize_t length = readFilesize_t(stream);
-        emit truncated(length);
+        Q_EMIT truncated(length);
         break;
     }
     case INF_SPEED:
         stream >> ul;
         d->slave_calcs_speed = true;
         d->speed_timer.stop();
-        emit speed(ul);
+        Q_EMIT speed(ul);
         break;
 #if KIOCORE_BUILD_DEPRECATED_SINCE(3, 0)
     case INF_GETTING_FILE:
         break;
 #endif
     case INF_ERROR_PAGE:
-        emit errorPage();
+        Q_EMIT errorPage();
         break;
     case INF_REDIRECTION: {
         QUrl url;
         stream >> url;
-        emit redirection(url);
+        Q_EMIT redirection(url);
         break;
     }
     case INF_MIME_TYPE:
         stream >> str1;
-        emit mimeType(str1);
+        Q_EMIT mimeType(str1);
         if (!d->connection->suspended()) {
             d->connection->sendnow(CMD_NONE, QByteArray());
         }
         break;
     case INF_WARNING:
         stream >> str1;
-        emit warning(str1);
+        Q_EMIT warning(str1);
         break;
     case INF_MESSAGEBOX: {
-        //qDebug() << "needs a msg box";
-        QString text, caption, buttonYes, buttonNo, dontAskAgainName;
+        // qDebug() << "needs a msg box";
+        QString text;
+        QString caption;
+        QString buttonYes;
+        QString buttonNo;
+        QString dontAskAgainName;
         int type;
         stream >> type >> text >> caption >> buttonYes >> buttonNo;
         if (stream.atEnd()) {
@@ -272,7 +277,7 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
     case INF_INFOMESSAGE: {
         QString msg;
         stream >> msg;
-        emit infoMessage(msg);
+        Q_EMIT infoMessage(msg);
         break;
     }
     case INF_META_DATA: {
@@ -292,7 +297,7 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
         } else if (m.contains(QStringLiteral("privilege_conf_details"))) { // KF6 TODO Remove this conditional.
             d->privilegeConfMetaData = m;
         }
-        emit metaData(m);
+        Q_EMIT metaData(m);
         break;
     }
     case MSG_NET_REQUEST: {
@@ -310,7 +315,7 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
         break;
     }
     case MSG_NEED_SUBURL_DATA: {
-        emit needSubUrlData();
+        Q_EMIT needSubUrlData();
         break;
     }
     case MSG_HOST_INFO_REQ: {
@@ -320,7 +325,7 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
         break;
     }
     case MSG_PRIVILEGE_EXEC:
-        emit privilegeOperationRequested();
+        Q_EMIT privilegeOperationRequested();
         break;
     default:
         qCWarning(KIO_CORE) << "Slave sends unknown command (" << _cmd << "), dropping slave";
@@ -346,7 +351,7 @@ void SlaveInterface::requestNetwork(const QString &host, const QString &slaveid)
     Q_D(SlaveInterface);
     Q_UNUSED(host);
     Q_UNUSED(slaveid);
-    //qDebug() << "requestNetwork " << host << slaveid;
+    // qDebug() << "requestNetwork " << host << slaveid;
 
     // This is old stuff. We just always return true...
 
@@ -360,13 +365,13 @@ void SlaveInterface::dropNetwork(const QString &host, const QString &slaveid)
 {
     Q_UNUSED(host);
     Q_UNUSED(slaveid);
-    //qDebug() << "dropNetwork " << host << slaveid;
+    // qDebug() << "dropNetwork " << host << slaveid;
 }
 
 void SlaveInterface::sendResumeAnswer(bool resume)
 {
     Q_D(SlaveInterface);
-    //qDebug() << "ok for resuming:" << resume;
+    // qDebug() << "ok for resuming:" << resume;
     d->connection->sendnow(resume ? CMD_RESUMEANSWER : CMD_NONE, QByteArray());
 }
 
@@ -387,14 +392,17 @@ void SlaveInterface::sendMessageBoxAnswer(int result)
     // qDebug() << "message box answer" << result;
 }
 
-void SlaveInterface::messageBox(int type, const QString &text, const QString &_caption,
-                                const QString &buttonYes, const QString &buttonNo)
+void SlaveInterface::messageBox(int type, const QString &text, const QString &_caption, const QString &buttonYes, const QString &buttonNo)
 {
     messageBox(type, text, _caption, buttonYes, buttonNo, QString());
 }
 
-void SlaveInterface::messageBox(int type, const QString &text, const QString &caption,
-                                const QString &buttonYes, const QString &buttonNo, const QString &dontAskAgainName)
+void SlaveInterface::messageBox(int type,
+                                const QString &text,
+                                const QString &caption,
+                                const QString &buttonYes,
+                                const QString &buttonNo,
+                                const QString &dontAskAgainName)
 {
     Q_D(SlaveInterface);
     if (d->connection) {
@@ -435,7 +443,7 @@ void SlaveInterfacePrivate::slotHostInfo(const QHostInfo &info)
 {
     QByteArray data;
     QDataStream stream(&data, QIODevice::WriteOnly);
-    stream <<  info.hostName() << info.addresses() << info.error() << info.errorString();
+    stream << info.hostName() << info.addresses() << info.error() << info.errorString();
     connection->send(CMD_HOST_INFO, data);
 }
 
