@@ -10,10 +10,10 @@
 #ifndef UDSENTRY_H
 #define UDSENTRY_H
 
-#include <QString>
 #include <QList>
-#include <QSharedData>
 #include <QMetaType>
+#include <QSharedData>
+#include <QString>
 #include <QtGlobal>
 #include <qplatformdefs.h>
 
@@ -24,8 +24,8 @@ namespace KIO
 class UDSEntry;
 }
 
-KIOCORE_EXPORT QDataStream &operator<< (QDataStream &s, const KIO::UDSEntry &a);
-KIOCORE_EXPORT QDataStream &operator>> (QDataStream &s, KIO::UDSEntry &a);
+KIOCORE_EXPORT QDataStream &operator<<(QDataStream &s, const KIO::UDSEntry &a);
+KIOCORE_EXPORT QDataStream &operator>>(QDataStream &s, KIO::UDSEntry &a);
 
 /**
  * Support for qDebug() << aUDSEntry
@@ -37,13 +37,13 @@ KIOCORE_EXPORT QDebug operator<<(QDebug stream, const KIO::UDSEntry &entry);
  * Returns true if the entry contains the same data as the other
  * @since 5.63
  */
-KIOCORE_EXPORT bool operator== (const KIO::UDSEntry &entry, const KIO::UDSEntry &other);
+KIOCORE_EXPORT bool operator==(const KIO::UDSEntry &entry, const KIO::UDSEntry &other);
 
 /**
  * Returns true if the entry does not contain the same data as the other
  * @since 5.63
  */
-KIOCORE_EXPORT bool operator!= (const KIO::UDSEntry &entry, const KIO::UDSEntry &other);
+KIOCORE_EXPORT bool operator!=(const KIO::UDSEntry &entry, const KIO::UDSEntry &other);
 
 namespace KIO
 {
@@ -77,7 +77,6 @@ class UDSEntryPrivate;
 class KIOCORE_EXPORT UDSEntry
 {
 public:
-
     UDSEntry();
 
     /**
@@ -91,7 +90,7 @@ public:
     /**
      * Copy constructor
      */
-    UDSEntry(const UDSEntry&);
+    UDSEntry(const UDSEntry &);
 
     /**
      * Destructor
@@ -102,18 +101,18 @@ public:
      * Move constructor
      * @since 5.44
      */
-    UDSEntry(UDSEntry&&);
+    UDSEntry(UDSEntry &&);
 
     /**
      * Copy assignment
      */
-    UDSEntry& operator=(const UDSEntry&);
+    UDSEntry &operator=(const UDSEntry &);
 
     /**
      * Move assignment
      * @since 5.44
      */
-    UDSEntry& operator=(UDSEntry&&);
+    UDSEntry &operator=(UDSEntry &&);
 
     /**
      * @return value of a textual field
@@ -221,9 +220,9 @@ public:
         /// Indicates that the field is a QString
         UDS_STRING = 0x01000000,
         /// Indicates that the field is a number (long long)
-        UDS_NUMBER   = 0x02000000,
+        UDS_NUMBER = 0x02000000,
         /// Indicates that the field represents a time, which is modelled by a long long
-        UDS_TIME   = 0x04000000 | UDS_NUMBER,
+        UDS_TIME = 0x04000000 | UDS_NUMBER,
 
         // The rest isn't a bit field
 
@@ -249,7 +248,7 @@ public:
         /// of the items, use UDS_DISPLAY_NAME.
         UDS_NAME = 6 | UDS_STRING,
         /// A local file path if the ioslave display files sitting
-        /// on the local filesystem (but in another hierarchy, e.g. settings:/ or remote:/)
+        /// on the local filesystem (but in another hierarchy, e.g.\ settings:/ or remote:/)
         UDS_LOCAL_PATH = 7 | UDS_STRING,
         /// Treat the file as a hidden file (if set to 1) or as a normal file (if set to 0).
         /// This field overrides the default behavior (the check for a leading dot in the filename).
@@ -281,7 +280,7 @@ public:
         /// But when 'running' the file, the MIME type is re-determined
         /// This is for special cases like symlinks in FTP; you probably don't want to use this one.
         UDS_GUESSED_MIME_TYPE = 17 | UDS_STRING,
-        /// XML properties, e.g. for WebDAV
+        /// XML properties, e.g.\ for WebDAV
         UDS_XML_PROPERTIES = 18 | UDS_STRING,
 
         /// Indicates that the entry has extended ACL entries
@@ -341,14 +340,14 @@ public:
         /// Extra data (used only if you specified Columns/ColumnsTypes)
         /// NB: you cannot repeat this entry; use UDS_EXTRA + i
         /// until UDS_EXTRA_END.
-        UDS_EXTRA_END = 140 | UDS_STRING
+        UDS_EXTRA_END = 140 | UDS_STRING,
     };
 
 private:
     QSharedDataPointer<UDSEntryPrivate> d;
-    friend KIOCORE_EXPORT QDataStream& ::operator<< (QDataStream &s, const KIO::UDSEntry &a);
-    friend KIOCORE_EXPORT QDataStream& ::operator>> (QDataStream &s, KIO::UDSEntry &a);
-    friend KIOCORE_EXPORT QDebug (::operator<<) (QDebug stream, const KIO::UDSEntry &entry);
+    friend KIOCORE_EXPORT QDataStream & ::operator<<(QDataStream &s, const KIO::UDSEntry &a);
+    friend KIOCORE_EXPORT QDataStream & ::operator>>(QDataStream &s, KIO::UDSEntry &a);
+    friend KIOCORE_EXPORT QDebug(::operator<<)(QDebug stream, const KIO::UDSEntry &entry);
 
 public:
     /**
@@ -374,7 +373,6 @@ Q_DECLARE_TYPEINFO(KIO::UDSEntry, Q_MOVABLE_TYPE);
 
 namespace KIO
 {
-
 /**
  * A directory listing is a list of UDSEntry instances.
  *
