@@ -8,12 +8,13 @@
 #include "kfileplacesitem_p.h"
 
 #include <QDateTime>
+#include <QDir>
 #include <QIcon>
 
 #include <KBookmarkManager>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KIconLoader>
+#include <KIconUtils>
 #include <KLocalizedString>
 #include <KMountPoint>
 #include <kprotocolinfo.h>
@@ -31,11 +32,13 @@ static bool isTrash(const KBookmark &bk)
     return bk.url().toString() == QLatin1String("trash:/");
 }
 
-KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager, const QString &address, const QString &udi)
-    : m_manager(manager)
+KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager, const QString &address, const QString &udi, KFilePlacesModel *parent)
+    : QObject(static_cast<QObject *>(parent))
+    , m_manager(manager)
     , m_folderIsEmpty(true)
     , m_isCdrom(false)
     , m_isAccessible(false)
+    , m_isTeardownAllowed(false)
 {
     updateDeviceInfo(udi);
     setBookmark(m_manager->findByAddress(address));
@@ -52,11 +55,19 @@ KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager, const QString &addre
 
     // Hide SSHFS network device mounted by kdeconnect, since we already have the kdeconnect:// place.
     if (isDevice() && m_access && device().vendor() == QLatin1String("fuse.sshfs")) {
-        auto mountPoint = KMountPoint::currentMountPoints().findByPath(m_access->filePath());
-        if (mountPoint->mountedFrom().startsWith(QLatin1String("kdeconnect@"))) {
-            // Hide only if the user never set the "Hide" checkbox on the device.
-            if (m_bookmark.metaDataItem(QStringLiteral("IsHidden")).isEmpty()) {
-                setHidden(true);
+        const QString storageFilePath = m_access->filePath();
+        // Not using findByPath() as it resolves symlinks, potentially blocking,
+        // but here we know we query for an existing actual mount point.
+        const auto mountPoints = KMountPoint::currentMountPoints();
+        auto it = std::find_if(mountPoints.cbegin(), mountPoints.cend(), [&storageFilePath](const KMountPoint::Ptr &mountPoint) {
+            return mountPoint->mountPoint() == storageFilePath;
+        });
+        if (it != mountPoints.cend()) {
+            if ((*it)->mountedFrom().startsWith(QLatin1String("kdeconnect@"))) {
+                // Hide only if the user never set the "Hide" checkbox on the device.
+                if (m_bookmark.metaDataItem(QStringLiteral("IsHidden")).isEmpty()) {
+                    setHidden(true);
+                }
             }
         }
     }
@@ -107,6 +118,11 @@ bool KFilePlacesItem::isDevice() const
     return !bookmark().metaDataItem(QStringLiteral("UDI")).isEmpty();
 }
 
+bool KFilePlacesItem::isTeardownAllowed() const
+{
+    return m_isTeardownAllowed;
+}
+
 KBookmark KFilePlacesItem::bookmark() const
 {
     return m_bookmark;
@@ -264,7 +280,8 @@ QVariant KFilePlacesItem::deviceData(int role) const
         case Qt::DisplayRole:
             return d.displayName();
         case Qt::DecorationRole:
-            return KDE::icon(m_iconPath, m_emblems);
+            // qDebug() << "adding emblems" << m_emblems << "to device icon" << m_deviceIconName;
+            return KIconUtils::addOverlays(m_deviceIconName, m_emblems);
         case KFilePlacesModel::UrlRole:
             if (m_access) {
                 const QString path = m_access->filePath();
@@ -295,6 +312,13 @@ QVariant KFilePlacesItem::deviceData(int role) const
                 return QVariant();
             }
 
+        case KFilePlacesModel::TeardownAllowedRole:
+            if (m_access) {
+                return m_isTeardownAllowed;
+            } else {
+                return QVariant();
+            }
+
         case KFilePlacesModel::FixedDeviceRole: {
             if (m_drive != nullptr) {
                 return !m_drive->isHotpluggable() && !m_drive->isRemovable();
@@ -306,7 +330,7 @@ QVariant KFilePlacesItem::deviceData(int role) const
             return m_isAccessible && !m_isCdrom;
 
         case KFilePlacesModel::IconNameRole:
-            return m_iconPath;
+            return m_deviceIconName;
 
         default:
             return QVariant();
@@ -341,15 +365,11 @@ KBookmark KFilePlacesItem::createBookmark(KBookmarkManager *manager, const QStri
 }
 
 KBookmark KFilePlacesItem::createSystemBookmark(KBookmarkManager *manager,
-                                                const char *translationContext,
-                                                const QByteArray &untranslatedLabel,
+                                                const char *untranslatedLabel,
                                                 const QUrl &url,
                                                 const QString &iconName,
                                                 const KBookmark &after)
 {
-    Q_UNUSED(translationContext); // parameter is only necessary to force the caller
-    // to provide a marked-for-translation string for the label, with context
-
     KBookmark bookmark = createBookmark(manager, QString::fromUtf8(untranslatedLabel), url, iconName);
     if (!bookmark.isNull()) {
         bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), QStringLiteral("true"));
@@ -374,9 +394,14 @@ KBookmark KFilePlacesItem::createDeviceBookmark(KBookmarkManager *manager, const
 
 KBookmark KFilePlacesItem::createTagBookmark(KBookmarkManager *manager, const QString &tag)
 {
-    KBookmark bookmark = createSystemBookmark(manager, tag.toUtf8().data(), tag.toUtf8(), QUrl(QLatin1String("tags:/") + tag), QLatin1String("tag"));
-    bookmark.setMetaDataItem(QStringLiteral("tag"), tag);
-    bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), QStringLiteral("true"));
+    // TODO: Currently KFilePlacesItem::setBookmark() only decides by the "isSystemItem" property
+    // if the label text should be looked up for translation. So there is a small risk that
+    // labelTexts which match existing untranslated system labels accidentally get translated.
+    KBookmark bookmark = createBookmark(manager, tag, QUrl(QLatin1String("tags:/") + tag), QStringLiteral("tag"));
+    if (!bookmark.isNull()) {
+        bookmark.setMetaDataItem(QStringLiteral("tag"), tag);
+        bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), QStringLiteral("true"));
+    }
 
     return bookmark;
 }
@@ -410,7 +435,7 @@ bool KFilePlacesItem::updateDeviceInfo(const QString &udi)
         m_disc = m_device.as<Solid::OpticalDisc>();
         m_player = m_device.as<Solid::PortableMediaPlayer>();
         m_networkShare = m_device.as<Solid::NetworkShare>();
-        m_iconPath = m_device.icon();
+        m_deviceIconName = m_device.icon();
         m_emblems = m_device.emblems();
 
         m_drive = nullptr;
@@ -431,7 +456,7 @@ bool KFilePlacesItem::updateDeviceInfo(const QString &udi)
         m_player = nullptr;
         m_drive = nullptr;
         m_networkShare = nullptr;
-        m_iconPath.clear();
+        m_deviceIconName.clear();
         m_emblems.clear();
     }
 
@@ -441,9 +466,22 @@ bool KFilePlacesItem::updateDeviceInfo(const QString &udi)
 void KFilePlacesItem::onAccessibilityChanged(bool isAccessible)
 {
     m_isAccessible = isAccessible;
-    m_isCdrom = m_device.is<Solid::OpticalDrive>() || m_device.parent().is<Solid::OpticalDrive>();
+    m_isCdrom =
+        m_device.is<Solid::OpticalDrive>() || m_device.parent().is<Solid::OpticalDrive>() || (m_volume && m_volume->fsType() == QLatin1String("iso9660"));
     m_emblems = m_device.emblems();
 
+    m_isTeardownAllowed = isAccessible;
+    if (m_isTeardownAllowed) {
+        if (m_access->filePath() == QDir::rootPath()) {
+            m_isTeardownAllowed = false;
+        } else {
+            KMountPoint::Ptr mountPoint = KMountPoint::currentMountPoints().findByPath(QDir::homePath());
+            if (mountPoint && m_access->filePath() == mountPoint->mountPoint()) {
+                m_isTeardownAllowed = false;
+            }
+        }
+    }
+
     Q_EMIT itemChanged(id());
 }
 
