@@ -41,12 +41,13 @@ public:
         TagsType,
     };
 
-    KFilePlacesItem(KBookmarkManager *manager, const QString &address, const QString &udi = QString());
-    ~KFilePlacesItem();
+    KFilePlacesItem(KBookmarkManager *manager, const QString &address, const QString &udi, KFilePlacesModel *parent);
+    ~KFilePlacesItem() override;
 
     QString id() const;
 
     bool isDevice() const;
+    bool isTeardownAllowed() const;
     KBookmark bookmark() const;
     void setBookmark(const KBookmark &bookmark);
     Solid::Device device() const;
@@ -59,9 +60,11 @@ public:
 
     static KBookmark
     createBookmark(KBookmarkManager *manager, const QString &label, const QUrl &url, const QString &iconName, KFilePlacesItem *after = nullptr);
+    /**
+     * @param untranslatedLabel text for label. If to be translated, should be set by kli18nc("KFile System Bookmarks", "Label text").untranslatedText().
+     */
     static KBookmark createSystemBookmark(KBookmarkManager *manager,
-                                          const char *translationContext,
-                                          const QByteArray &untranslatedLabel,
+                                          const char *untranslatedLabel,
                                           const QUrl &url,
                                           const QString &iconName,
                                           const KBookmark &after = KBookmark());
@@ -88,6 +91,7 @@ private:
     bool m_folderIsEmpty;
     bool m_isCdrom;
     bool m_isAccessible;
+    bool m_isTeardownAllowed;
     QString m_text;
     Solid::Device m_device;
     QPointer<Solid::StorageAccess> m_access;
