@@ -671,6 +671,23 @@ QModelIndex KFilePlacesModel::parent(const QModelIndex &child) const
     return QModelIndex();
 }
 
+QHash<int, QByteArray> KFilePlacesModel::roleNames() const
+{
+    auto super = QAbstractItemModel::roleNames();
+
+    super[UrlRole] = "url";
+    super[HiddenRole] = "isHidden";
+    super[SetupNeededRole] = "isSetupNeeded";
+    super[FixedDeviceRole] = "isFixedDevice";
+    super[CapacityBarRecommendedRole] = "isCapacityBarRecommended";
+    super[GroupRole] = "group";
+    super[IconNameRole] = "iconName";
+    super[GroupHiddenRole] = "isGroupHidden";
+    super[TeardownAllowedRole] = "isTeardownAllowed";
+
+    return super;
+}
+
 int KFilePlacesModel::rowCount(const QModelIndex &parent) const
 {
     if (parent.isValid()) {
@@ -702,9 +719,10 @@ QModelIndex KFilePlacesModel::closestItem(const QUrl &url) const
             continue;
         }
 
-        const QUrl itemUrl(item->data(UrlRole).toUrl());
+        const QUrl itemUrl = convertedUrl(item->data(UrlRole).toUrl());
 
-        if (itemUrl.matches(url, QUrl::StripTrailingSlash) || itemUrl.isParentOf(url)) {
+        if (itemUrl.matches(url, QUrl::StripTrailingSlash)
+            || (itemUrl.isParentOf(url) && itemUrl.query() == url.query() && itemUrl.fragment() == url.fragment())) {
             const int length = itemUrl.toString().length();
             if (length > maxLength) {
                 foundRow = row;
@@ -1063,6 +1081,10 @@ bool KFilePlacesModel::dropMimeData(const QMimeData *data, Qt::DropAction action
         // let's do it in the views to get the good old drop menu
     }
 
+    if (data->hasFormat(QStringLiteral("application/x-kfileplacesmodel-ignore"))) {
+        return false;
+    }
+
     if (data->hasFormat(_k_internalMimetype(this))) {
         // The operation is an internal move
         QByteArray itemData = data->data(_k_internalMimetype(this));
