@@ -34,12 +34,14 @@
 #include <QHBoxLayout>
 #include <QKeyEvent>
 #include <QMenu>
+#include <QMetaMethod>
 #include <QMimeData>
 #include <QMimeDatabase>
 #include <QTimer>
 #include <QUrlQuery>
 
 #include <algorithm>
+#include <numeric>
 
 using namespace KDEPrivate;
 
@@ -60,6 +62,17 @@ class KUrlNavigatorPrivate
 public:
     KUrlNavigatorPrivate(KUrlNavigator *qq, KFilePlacesModel *placesModel);
 
+    ~KUrlNavigatorPrivate()
+    {
+        m_dropDownButton->removeEventFilter(q);
+        m_pathBox->removeEventFilter(q);
+        m_toggleEditableMode->removeEventFilter(q);
+
+        for (KUrlNavigatorButton *button : std::as_const(m_navButtons)) {
+            button->removeEventFilter(q);
+        }
+    }
+
     /** Applies the edited URL in m_pathBox to the URL navigator */
     void applyUncommittedUrl();
 
@@ -90,9 +103,13 @@ public:
     void dropUrls(const QUrl &destination, QDropEvent *event, KUrlNavigatorButton *dropButton);
 
     /**
-     * Is invoked when a navigator button has been clicked. Changes the URL
-     * of the navigator if the left mouse button has been used. If the middle
-     * mouse button has been used, the signal tabRequested() will be emitted.
+     * Is invoked when a navigator button has been clicked.
+     * Different combinations of mouse clicks and keyboard modifiers have different effects on how
+     * the url is opened. The behaviours are the following:
+     * - shift+middle-click or ctrl+shift+left-click => activeTabRequested() signal is emitted
+     * - ctrl+left-click or middle-click => tabRequested() signal is emitted
+     * - shift+left-click => newWindowRequested() signal is emitted
+     * - left-click => open the new url in-place
      */
     void slotNavigatorButtonClicked(const QUrl &url, Qt::MouseButton button, Qt::KeyboardModifiers modifiers);
 
@@ -456,8 +473,12 @@ void KUrlNavigatorPrivate::dropUrls(const QUrl &destination, QDropEvent *event,
 
 void KUrlNavigatorPrivate::slotNavigatorButtonClicked(const QUrl &url, Qt::MouseButton button, Qt::KeyboardModifiers modifiers)
 {
-    if (button & Qt::MiddleButton || (button & Qt::LeftButton && modifiers & Qt::ControlModifier)) {
+    if ((button & Qt::MiddleButton && modifiers & Qt::ShiftModifier) || (button & Qt::LeftButton && modifiers & (Qt::ControlModifier | Qt::ShiftModifier))) {
+        Q_EMIT q->activeTabRequested(url);
+    } else if (button & Qt::MiddleButton || (button & Qt::LeftButton && modifiers & Qt::ControlModifier)) {
         Q_EMIT q->tabRequested(url);
+    } else if (button & Qt::LeftButton && modifiers & Qt::ShiftModifier) {
+        Q_EMIT q->newWindowRequested(url);
     } else if (button & Qt::LeftButton) {
         q->setLocationUrl(url);
     }
@@ -481,9 +502,9 @@ void KUrlNavigatorPrivate::openContextMenu(const QPoint &p)
 
     popup->addSeparator();
 
-    // We are checking for receivers because it's odd to have a tab entry even
+    // We are checking whether the signal is connected because it's odd to have a tab entry even
     // if it's not supported, like in the case of the open dialog
-    if (q->receivers(SIGNAL(tabRequested(QUrl))) > 0) {
+    if (q->isSignalConnected(QMetaMethod::fromSignal(&KUrlNavigator::tabRequested))) {
         for (auto button : std::as_const(m_navButtons)) {
             if (button->geometry().contains(p)) {
                 const auto url = button->url();
@@ -605,13 +626,12 @@ void KUrlNavigatorPrivate::updateButtons(int startIndex)
 
     const QString path = currentUrl.path();
 
-    bool createButton = false;
     const int oldButtonCount = m_navButtons.count();
 
     int idx = startIndex;
     bool hasNext = true;
     do {
-        createButton = (idx - startIndex >= oldButtonCount);
+        const bool createButton = (idx - startIndex) >= oldButtonCount;
         const bool isFirstButton = (idx == startIndex);
         const QString dirName = path.section(QLatin1Char('/'), idx, idx);
         hasNext = isFirstButton || !dirName.isEmpty();
@@ -698,11 +718,11 @@ void KUrlNavigatorPrivate::updateButtonVisibility()
         availableWidth -= m_protocols->width();
     }
 
+    auto MinWidth = [](const KUrlNavigatorButton *button) {
+        return button->minimumWidth();
+    };
     // Check whether buttons must be hidden at all...
-    int requiredButtonWidth = 0;
-    for (const KUrlNavigatorButton *button : std::as_const(m_navButtons)) {
-        requiredButtonWidth += button->minimumWidth();
-    }
+    const int requiredButtonWidth = std::transform_reduce(m_navButtons.cbegin(), m_navButtons.cend(), 0, std::plus<>(), MinWidth);
 
     if (requiredButtonWidth > availableWidth) {
         // At least one button must be hidden. This implies that the
@@ -767,7 +787,7 @@ QString KUrlNavigatorPrivate::firstButtonText() const
 #ifdef Q_OS_WIN
             text = currentUrl.path().length() > 1 ? currentUrl.path().left(2) : QDir::rootPath();
 #else
-            text = m_showFullPath ? QStringLiteral("/") : i18n("Custom Path");
+            text = QStringLiteral("/");
 #endif
         }
     }
@@ -891,7 +911,14 @@ KUrlNavigator::KUrlNavigator(KFilePlacesModel *placesModel, const QUrl &url, QWi
     d->updateContent();
 }
 
-KUrlNavigator::~KUrlNavigator() = default;
+KUrlNavigator::~KUrlNavigator()
+{
+    d->m_dropDownButton->removeEventFilter(this);
+    d->m_pathBox->removeEventFilter(this);
+    for (auto *button : std::as_const(d->m_navButtons)) {
+        button->removeEventFilter(this);
+    }
+}
 
 QUrl KUrlNavigator::locationUrl(int historyIndex) const
 {
