@@ -82,7 +82,7 @@ public:
      * @param parent         Parent widget.
      */
     KUrlNavigator(KFilePlacesModel *placesModel, const QUrl &url, QWidget *parent);
-    virtual ~KUrlNavigator();
+    ~KUrlNavigator() override;
 
     /**
      * @return URL of the location given by the \a historyIndex. If \a historyIndex
@@ -281,6 +281,30 @@ public:
      */
     QWidget *dropWidget() const;
 
+    /** 
+     * Sets whether to show hidden folders in the subdirectories popup.
+     * @since 5.87
+     */
+    void setShowHiddenFolders(bool showHiddenFolders);
+
+    /**
+     * Returns whether to show hidden folders in the subdirectories popup.
+     * @since 5.87
+     */
+    bool showHiddenFolders() const;
+
+    /** 
+     * Sets whether to sort hidden folders in the subdirectories popup last.
+     * @since 5.87
+     */
+    void setSortHiddenFoldersLast(bool sortHiddenFoldersLast);
+
+    /**
+     * Returns whether to sort hidden folders in the subdirectories popup last.
+     * @since 5.87
+     */
+    bool sortHiddenFoldersLast() const;
+
 #if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
     /**
      * @return     The current URL of the location.
@@ -440,16 +464,33 @@ Q_SIGNALS:
     void returnPressed();
 
     /**
-     * Is emitted if the URL \a url should be opened in a new tab because
-     * the user clicked on a breadcrumb with the middle mouse button.
+     * Is emitted if the URL \a url should be opened in a new inactive tab because
+     * the user clicked on a breadcrumb with the middle mouse button or
+     * left-clicked with the ctrl modifier pressed.
      * @since 4.5
      */
     void tabRequested(const QUrl &url);
 
     /**
-     * When the URL is changed and the new URL (e.g. /home/user1/)
-     * is a parent of the previous URL (e.g. /home/user1/data/stuff),
-     * then this signal is emitted and \a url is set to the child
+     * Is emitted if the URL \a url should be opened in a new active tab because
+     * the user clicked on a breadcrumb with the middle mouse button with
+     * the shift modifier pressed or left-clicked with both the ctrl and shift
+     * modifiers pressed.
+     * @since 5.89
+     */
+    void activeTabRequested(const QUrl &url);
+
+    /**
+     * Is emitted if the URL \a url should be opened in a new window because
+     * the user left-clicked on a breadcrumb with the shift modifier pressed.
+     * @since 5.89
+     */
+    void newWindowRequested(const QUrl &url);
+
+    /**
+     * When the URL is changed and the new URL (e.g.\ /home/user1/)
+     * is a parent of the previous URL (e.g.\ /home/user1/data/stuff),
+     * then this signal is emitted and \p url is set to the child
      * directory of the new URL which is an ancestor of the old URL
      * (in the example paths this would be /home/user1/data/).
      * This signal allows file managers to pre-select the directory
