@@ -4,8 +4,8 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "kurlnavigatordropdownbutton_p.h"
 #include "kurlnavigator.h"
+#include "kurlnavigatordropdownbutton_p.h"
 
 #include <QKeyEvent>
 #include <QPainter>
@@ -13,9 +13,8 @@
 
 namespace KDEPrivate
 {
-
-KUrlNavigatorDropDownButton::KUrlNavigatorDropDownButton(QWidget *parent) :
-    KUrlNavigatorButtonBase(parent)
+KUrlNavigatorDropDownButton::KUrlNavigatorDropDownButton(KUrlNavigator *parent)
+    : KUrlNavigatorButtonBase(parent)
 {
 }
 
@@ -60,7 +59,7 @@ void KUrlNavigatorDropDownButton::keyPressEvent(QKeyEvent *event)
     case Qt::Key_Enter:
     case Qt::Key_Return:
     case Qt::Key_Down:
-        emit clicked();
+        Q_EMIT clicked();
         break;
     default:
         KUrlNavigatorButtonBase::keyPressEvent(event);
