@@ -1,42 +1,25 @@
-/*****************************************************************************
- * Copyright (C) 2006 by Peter Penz <peter.penz@gmx.at>                      *
- *                                                                           *
- * This library is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU Library General Public               *
- * License as published by the Free Software Foundation; either              *
- * version 2 of the License, or (at your option) any later version.          *
- *                                                                           *
- * This library is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- * Library General Public License for more details.                          *
- *                                                                           *
- * You should have received a copy of the GNU Library General Public License *
- * along with this library; see the file COPYING.LIB.  If not, write to      *
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- * Boston, MA 02110-1301, USA.                                               *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Peter Penz <peter.penz@gmx.at>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kurlnavigatortogglebutton_p.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
+#include <QPaintEvent>
 #include <QPainter>
 #include <QStyle>
-#include <QKeyEvent>
-#include <QApplication>
 
 namespace KDEPrivate
 {
-
-KUrlNavigatorToggleButton::KUrlNavigatorToggleButton(QWidget *parent) :
-    KUrlNavigatorButtonBase(parent)
+KUrlNavigatorToggleButton::KUrlNavigatorToggleButton(KUrlNavigator *parent)
+    : KUrlNavigatorButtonBase(parent)
 {
     setCheckable(true);
-    connect(this, &QAbstractButton::toggled,
-            this, &KUrlNavigatorToggleButton::updateToolTip);
-    connect(this, &QAbstractButton::clicked,
-            this, &KUrlNavigatorToggleButton::updateCursor);
+    connect(this, &QAbstractButton::toggled, this, &KUrlNavigatorToggleButton::updateToolTip);
+    connect(this, &QAbstractButton::clicked, this, &KUrlNavigatorToggleButton::updateCursor);
     m_pixmap = QIcon::fromTheme(QStringLiteral("dialog-ok")).pixmap(QSize(22, 22).expandedTo(iconSize()));
 
 #ifndef QT_NO_ACCESSIBILITY
@@ -57,7 +40,11 @@ QSize KUrlNavigatorToggleButton::sizeHint() const
     return size;
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+void KUrlNavigatorToggleButton::enterEvent(QEnterEvent *event)
+#else
 void KUrlNavigatorToggleButton::enterEvent(QEvent *event)
+#endif
 {
     KUrlNavigatorButtonBase::enterEvent(event);
     updateCursor();
