@@ -32,6 +32,9 @@
 #include <QOperatingSystemVersion>
 #include <mimetypefinderjob.h>
 
+// For unit test purposes, to test both code paths in externalBrowser()
+KIOGUI_EXPORT bool openurljob_force_use_browserapp_kdeglobals = false;
+
 class KIO::OpenUrlJobPrivate
 {
 public:
@@ -150,15 +153,28 @@ void KIO::OpenUrlJob::start()
         d->emitAccessDenied();
         return;
     }
-    if (d->m_externalBrowserEnabled && checkNeedPortalSupport()) {
-        // Use the function from QDesktopServices as it handles portals correctly
-        // Note that it falls back to "normal way" if the portal service isn't running.
+
+    auto qtOpenUrl = [this]() {
         if (!QDesktopServices::openUrl(d->m_url)) {
             // Is this an actual error, or USER_CANCELED?
             setError(KJob::UserDefinedError);
             setErrorText(i18n("Failed to open %1", d->m_url.toDisplayString()));
         }
         emitResult();
+    };
+
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+    if (d->m_externalBrowserEnabled) {
+        // For Windows and MacOS, the mimetypes handling is different, so use QDesktopServices
+        qtOpenUrl();
+        return;
+    }
+#endif
+
+    if (d->m_externalBrowserEnabled && checkNeedPortalSupport()) {
+        // Use the function from QDesktopServices as it handles portals correctly
+        // Note that it falls back to "normal way" if the portal service isn't running.
+        qtOpenUrl();
         return;
     }
 
@@ -168,16 +184,19 @@ void KIO::OpenUrlJob::start()
         return;
     }
 
-    if (d->m_externalBrowserEnabled && d->m_url.scheme().startsWith(QLatin1String("http"))) {
-        const QString externalBrowser = d->externalBrowser();
-        if (!externalBrowser.isEmpty() && d->runExternalBrowser(externalBrowser)) {
+    if (d->m_url.scheme().startsWith(QLatin1String("http"))) {
+        if (d->m_externalBrowserEnabled) {
+            const QString externalBrowser = d->externalBrowser();
+            if (!externalBrowser.isEmpty() && d->runExternalBrowser(externalBrowser)) {
+                return;
+            }
+        }
+    } else {
+        if (KIO::DesktopExecParser::hasSchemeHandler(d->m_url)) {
+            d->useSchemeHandler();
             return;
         }
     }
-    if (KIO::DesktopExecParser::hasSchemeHandler(d->m_url)) {
-        d->useSchemeHandler();
-        return;
-    }
 
     auto *job = new KIO::MimeTypeFinderJob(d->m_url, this);
     job->setFollowRedirections(d->m_followRedirections);
@@ -208,27 +227,25 @@ QString KIO::OpenUrlJobPrivate::externalBrowser() const
         return QString();
     }
 
+    if (!openurljob_force_use_browserapp_kdeglobals) {
+        KService::Ptr externalBrowser = KApplicationTrader::preferredService(QStringLiteral("x-scheme-handler/https"));
+        if (!externalBrowser) {
+            externalBrowser = KApplicationTrader::preferredService(QStringLiteral("x-scheme-handler/http"));
+        }
+        if (externalBrowser) {
+            return externalBrowser->storageId();
+        }
+    }
+
     const QString browserApp = KConfigGroup(KSharedConfig::openConfig(), "General").readEntry("BrowserApplication");
-    if (!browserApp.isEmpty()) {
-        return browserApp;
-    }
-
-    // If a default browser isn't set in kdeglobals, fall back to mimeapps.list
-    KSharedConfig::Ptr profile = KSharedConfig::openConfig(QStringLiteral("mimeapps.list"), KConfig::NoGlobals, QStandardPaths::GenericConfigLocation);
-    const KConfigGroup defaultApps(profile, "Default Applications");
-
-    QString externalBrowser = defaultApps.readEntry("x-scheme-handler/https");
-    if (externalBrowser.isEmpty()) {
-        externalBrowser = defaultApps.readEntry("x-scheme-handler/http");
-    }
-    return externalBrowser;
+    return browserApp;
 }
 
 bool KIO::OpenUrlJobPrivate::runExternalBrowser(const QString &exec)
 {
     if (exec.startsWith(QLatin1Char('!'))) {
         // Literal command
-        const QString command = exec.midRef(1) + QLatin1String(" %u");
+        const QString command = QStringView(exec).mid(1) + QLatin1String(" %u");
         KService::Ptr service(new KService(QString(), command, QString()));
         startService(service);
         return true;
@@ -259,8 +276,8 @@ void KIO::OpenUrlJobPrivate::useSchemeHandler()
         m_mimeTypeName = KProtocolManager::defaultMimetype(m_url);
         runUrlWithMimeType();
     } else {
-        KService::Ptr service(new KService(QString(), exec, QString()));
-        startService(service);
+        KService::Ptr servicePtr(new KService(QString(), exec, QString()));
+        startService(servicePtr);
     }
 }
 
@@ -337,7 +354,7 @@ static bool hasExecuteBit(const QString &fileName)
 // Handle native binaries (.e.g. /usr/bin/*); and .exe files
 void KIO::OpenUrlJobPrivate::handleBinaries(const QMimeType &mimeType)
 {
-    if (!KAuthorized::authorize(QStringLiteral("shell_access"))) {
+    if (!KAuthorized::authorize(KAuthorized::SHELL_ACCESS)) {
         emitAccessDenied();
         return;
     }
@@ -552,7 +569,7 @@ void KIO::OpenUrlJobPrivate::handleDesktopFiles()
 void KIO::OpenUrlJobPrivate::handleScripts()
 {
     // Executable scripts of any type can run arbitrary shell commands
-    if (!KAuthorized::authorize(QStringLiteral("shell_access"))) {
+    if (!KAuthorized::authorize(KAuthorized::SHELL_ACCESS)) {
         emitAccessDenied();
         return;
     }
@@ -591,6 +608,17 @@ void KIO::OpenUrlJobPrivate::openInPreferredApp()
     if (service) {
         startService(service);
     } else {
+        // Avoid directly opening partial downloads and incomplete files
+        // This is done here in the off chance the user actually has a default handler for it
+        if (m_mimeTypeName == QLatin1String("application/x-partial-download")) {
+            q->setError(KJob::UserDefinedError);
+            q->setErrorText(
+                i18n("This file is incomplete and should not be opened.\n"
+                     "Check your open applications and the notification area for any pending tasks or downloads."));
+            q->emitResult();
+            return;
+        }
+
         showOpenWithDialog();
     }
 }
