@@ -11,7 +11,11 @@
 
 #include "file.h"
 
-#include <config-kioslave-file.h>
+#include "config-kioslave-file.h"
+
+#if HAVE_POSIX_ACL
+#include <../../aclhelpers_p.h>
+#endif
 
 #include <QDir>
 #include <QFile>
@@ -21,40 +25,49 @@
 #include <qplatformdefs.h>
 
 #include <KConfigGroup>
+#include <KFileSystemType>
 #include <KLocalizedString>
 #include <QDebug>
 #include <kmountpoint.h>
 
 #include <cerrno>
+#include <array>
 #include <stdint.h>
 #include <utime.h>
 
-#include <KAuth>
+#include <KAuth/Action>
+#include <KAuth/ExecuteJob>
 #include <KRandom>
 
 #include "fdreceiver.h"
 #include "statjob.h"
 
+#ifdef Q_OS_LINUX
+
+#include <linux/fs.h>
+#include <sys/ioctl.h>
+#include <unistd.h>
+
+#endif // Q_OS_LINUX
+
 #if HAVE_STATX
 #include <sys/stat.h>
 #include <sys/sysmacros.h> // for makedev()
 #endif
 
-#ifdef Q_OS_LINUX
-#include <linux/fs.h>
-#include <sys/ioctl.h>
-#endif
-
-// sendfile has different semantics in different platforms
-#if HAVE_SENDFILE && defined Q_OS_LINUX
-#define USE_SENDFILE 1
-#include <sys/sendfile.h>
+#if HAVE_COPY_FILE_RANGE
+// sys/types.h must be included before unistd.h,
+// and it needs to be included explicitly for FreeBSD
+#include <sys/types.h>
+#include <unistd.h>
 #endif
 
 #if HAVE_SYS_XATTR_H
 #include <sys/xattr.h>
 // BSD uses a different include
 #elif HAVE_SYS_EXTATTR_H
+#include <sys/types.h> // For FreeBSD, this must be before sys/extattr.h
+
 #include <sys/extattr.h>
 #endif
 
@@ -80,7 +93,8 @@ static const QString socketPath()
 
 static QString actionDetails(ActionType actionType, const QVariantList &args)
 {
-    QString action, detail;
+    QString action;
+    QString detail;
     switch (actionType) {
     case CHMOD:
         action = i18n("Change File Permissions");
@@ -117,6 +131,10 @@ static QString actionDetails(ActionType actionType, const QVariantList &args)
     case UTIME:
         action = i18n("Change Timestamp");
         break;
+    case COPY:
+        action = i18n("Copy");
+        detail = i18n("From: %1, To: %2", args[0].toString(), args[1].toString());
+        break;
     default:
         action = i18n("Unknown Action");
         break;
@@ -138,68 +156,10 @@ bool FileProtocol::privilegeOperationUnitTestMode()
         && (requestPrivilegeOperation(QStringLiteral("Test Call")) == KIO::OperationAllowed);
 }
 
-/*************************************
- *
- * ACL handling helpers
- *
- *************************************/
 #if HAVE_POSIX_ACL
-
-static QString aclToText(acl_t acl)
-{
-    ssize_t size = 0;
-    char *txt = acl_to_text(acl, &size);
-    const QString ret = QString::fromLatin1(txt, size);
-    acl_free(txt);
-    return ret;
-}
-
 bool FileProtocol::isExtendedACL(acl_t acl)
 {
-    return (acl_equiv_mode(acl, nullptr) != 0);
-}
-
-static void appendACLAtoms(const QByteArray &path, UDSEntry &entry, mode_t type)
-{
-    // first check for a noop
-    if (acl_extended_file(path.data()) == 0) {
-        return;
-    }
-
-    acl_t acl = nullptr;
-    acl_t defaultAcl = nullptr;
-    bool isDir = (type & QT_STAT_MASK) == QT_STAT_DIR;
-    // do we have an acl for the file, and/or a default acl for the dir, if it is one?
-    acl = acl_get_file(path.data(), ACL_TYPE_ACCESS);
-    /* Sadly libacl does not provided a means of checking for extended ACL and default
-     * ACL separately. Since a directory can have both, we need to check again. */
-    if (isDir) {
-        if (acl) {
-            if (!FileProtocol::isExtendedACL(acl)) {
-                acl_free(acl);
-                acl = nullptr;
-            }
-        }
-        defaultAcl = acl_get_file(path.data(), ACL_TYPE_DEFAULT);
-    }
-    if (acl || defaultAcl) {
-        // qDebug() << path.constData() << "has extended ACL entries";
-        entry.fastInsert(KIO::UDSEntry::UDS_EXTENDED_ACL, 1);
-
-        if (acl) {
-            const QString str = aclToText(acl);
-            entry.fastInsert(KIO::UDSEntry::UDS_ACL_STRING, str);
-            // qDebug() << path.constData() << "ACL:" << str;
-            acl_free(acl);
-        }
-
-        if (defaultAcl) {
-            const QString str = aclToText(defaultAcl);
-            entry.fastInsert(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING, str);
-            // qDebug() << path.constData() << "DEFAULT ACL:" << str;
-            acl_free(defaultAcl);
-        }
-    }
+    return (ACLPortability::acl_equiv_mode(acl, nullptr) != 0);
 }
 #endif
 
@@ -263,7 +223,7 @@ inline int LSTAT(const char *path, struct statx *buff, KIO::StatDetails details)
     }
     return statx(AT_FDCWD, path, AT_SYMLINK_NOFOLLOW, mask, buff);
 }
-inline int STAT(const char *path, struct statx *buff, KIO::StatDetails details)
+inline int STAT(const char *path, struct statx *buff, const KIO::StatDetails &details)
 {
     uint32_t mask = 0;
     // KIO::StatAcl needs type
@@ -286,35 +246,35 @@ inline int STAT(const char *path, struct statx *buff, KIO::StatDetails details)
     // KIO::Inode is ignored as when STAT is called, the entry inode field has already been filled
     return statx(AT_FDCWD, path, AT_STATX_SYNC_AS_STAT, mask, buff);
 }
-inline static uint16_t stat_mode(struct statx &buf)
+inline static uint16_t stat_mode(const struct statx &buf)
 {
     return buf.stx_mode;
 }
-inline static dev_t stat_dev(struct statx &buf)
+inline static dev_t stat_dev(const struct statx &buf)
 {
     return makedev(buf.stx_dev_major, buf.stx_dev_minor);
 }
-inline static uint64_t stat_ino(struct statx &buf)
+inline static uint64_t stat_ino(const struct statx &buf)
 {
     return buf.stx_ino;
 }
-inline static uint64_t stat_size(struct statx &buf)
+inline static uint64_t stat_size(const struct statx &buf)
 {
     return buf.stx_size;
 }
-inline static uint32_t stat_uid(struct statx &buf)
+inline static uint32_t stat_uid(const struct statx &buf)
 {
     return buf.stx_uid;
 }
-inline static uint32_t stat_gid(struct statx &buf)
+inline static uint32_t stat_gid(const struct statx &buf)
 {
     return buf.stx_gid;
 }
-inline static int64_t stat_atime(struct statx &buf)
+inline static int64_t stat_atime(const struct statx &buf)
 {
     return buf.stx_atime.tv_sec;
 }
-inline static int64_t stat_mtime(struct statx &buf)
+inline static int64_t stat_mtime(const struct statx &buf)
 {
     return buf.stx_mtime.tv_sec;
 }
@@ -330,35 +290,35 @@ inline int STAT(const char *path, QT_STATBUF *buff, KIO::StatDetails details)
     Q_UNUSED(details)
     return QT_STAT(path, buff);
 }
-inline static mode_t stat_mode(QT_STATBUF &buf)
+inline static mode_t stat_mode(const QT_STATBUF &buf)
 {
     return buf.st_mode;
 }
-inline static dev_t stat_dev(QT_STATBUF &buf)
+inline static dev_t stat_dev(const QT_STATBUF &buf)
 {
     return buf.st_dev;
 }
-inline static ino_t stat_ino(QT_STATBUF &buf)
+inline static ino_t stat_ino(const QT_STATBUF &buf)
 {
     return buf.st_ino;
 }
-inline static off_t stat_size(QT_STATBUF &buf)
+inline static off_t stat_size(const QT_STATBUF &buf)
 {
     return buf.st_size;
 }
-inline static uid_t stat_uid(QT_STATBUF &buf)
+inline static uid_t stat_uid(const QT_STATBUF &buf)
 {
     return buf.st_uid;
 }
-inline static gid_t stat_gid(QT_STATBUF &buf)
+inline static gid_t stat_gid(const QT_STATBUF &buf)
 {
     return buf.st_gid;
 }
-inline static time_t stat_atime(QT_STATBUF &buf)
+inline static time_t stat_atime(const QT_STATBUF &buf)
 {
     return buf.st_atime;
 }
-inline static time_t stat_mtime(QT_STATBUF &buf)
+inline static time_t stat_mtime(const QT_STATBUF &buf)
 {
     return buf.st_mtime;
 }
@@ -632,7 +592,7 @@ bool FileProtocol::copyXattrs(const int src_fd, const int dest_fd)
     // Linux and MacOS return a list of null terminated strings, each string = [data,'\0']
     // BSDs return a list of items, each item consisting of the size byte
     // prepended to the key = [size, data]
-    QByteArray::const_iterator keyPtr = keylist.cbegin();
+    auto keyPtr = keylist.cbegin();
     size_t keyLen;
     QByteArray value;
 
@@ -641,9 +601,11 @@ bool FileProtocol::copyXattrs(const int src_fd, const int dest_fd)
         // Get size of the key
 #if HAVE_SYS_XATTR_H
         keyLen = strlen(keyPtr);
+        auto next_key = [&]() { keyPtr += keyLen + 1; };
 #elif HAVE_SYS_EXTATTR_H
         keyLen = static_cast<unsigned char>(*keyPtr);
         keyPtr++;
+        auto next_key = [&]() { keyPtr += keyLen; };
 #endif
         QByteArray key(keyPtr, keyLen);
 
@@ -679,6 +641,8 @@ bool FileProtocol::copyXattrs(const int src_fd, const int dest_fd)
         } while (true);
 
         if (valuelen < 0) {
+            // Skip to next attribute.
+            next_key();
             continue;
         }
 
@@ -698,11 +662,7 @@ bool FileProtocol::copyXattrs(const int src_fd, const int dest_fd)
             return false;
         }
 
-#if HAVE_SYS_XATTR_H
-        keyPtr += keyLen + 1;
-#elif HAVE_SYS_EXTATTR_H
-        keyPtr += keyLen;
-#endif
+        next_key();
     }
     return true;
 }
@@ -721,13 +681,10 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mode, JobF
     QString dest = destUrl.toLocalFile();
     QByteArray _src(QFile::encodeName(src));
     QByteArray _dest(QFile::encodeName(dest));
-    QByteArray _dest_backup;
+    QByteArray _destBackup;
 
-    QT_STATBUF buff_src;
-#if HAVE_POSIX_ACL
-    acl_t acl;
-#endif
-    if (QT_STAT(_src.data(), &buff_src) == -1) {
+    QT_STATBUF buffSrc;
+    if (QT_STAT(_src.data(), &buffSrc) == -1) {
         if (errno == EACCES) {
             error(KIO::ERR_ACCESS_DENIED, src);
         } else {
@@ -736,24 +693,24 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mode, JobF
         return;
     }
 
-    if ((buff_src.st_mode & QT_STAT_MASK) == QT_STAT_DIR) {
+    if (S_ISDIR(buffSrc.st_mode)) {
         error(KIO::ERR_IS_DIRECTORY, src);
         return;
     }
-    if (S_ISFIFO(buff_src.st_mode) || S_ISSOCK(buff_src.st_mode)) {
+    if (S_ISFIFO(buffSrc.st_mode) || S_ISSOCK(buffSrc.st_mode)) {
         error(KIO::ERR_CANNOT_OPEN_FOR_READING, src);
         return;
     }
 
-    QT_STATBUF buff_dest;
-    bool dest_exists = (QT_LSTAT(_dest.data(), &buff_dest) != -1);
+    QT_STATBUF buffDest;
+    bool dest_exists = (QT_LSTAT(_dest.data(), &buffDest) != -1);
     if (dest_exists) {
-        if (same_inode(buff_dest, buff_src)) {
+        if (same_inode(buffDest, buffSrc)) {
             error(KIO::ERR_IDENTICAL_FILES, dest);
             return;
         }
 
-        if ((buff_dest.st_mode & QT_STAT_MASK) == QT_STAT_DIR) {
+        if (S_ISDIR(buffDest.st_mode)) {
             error(KIO::ERR_DIR_ALREADY_EXIST, dest);
             return;
         }
@@ -762,7 +719,7 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mode, JobF
             // If the destination is a symlink and overwrite is TRUE,
             // remove the symlink first to prevent the scenario where
             // the symlink actually points to current source!
-            if ((buff_dest.st_mode & QT_STAT_MASK) == QT_STAT_LNK) {
+            if (S_ISLNK(buffDest.st_mode)) {
                 // qDebug() << "copy(): LINK DESTINATION";
                 if (!QFile::remove(dest)) {
                     if (auto err = execWithElevatedPrivilege(DEL, {_dest}, errno)) {
@@ -772,8 +729,8 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mode, JobF
                         return;
                     }
                 }
-            } else if ((buff_dest.st_mode & QT_STAT_MASK) == QT_STAT_REG) {
-                _dest_backup = _dest;
+            } else if (S_ISREG(buffDest.st_mode)) {
+                _destBackup = _dest;
                 dest.append(QStringLiteral(".part"));
                 _dest = QFile::encodeName(dest);
             }
@@ -783,9 +740,9 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mode, JobF
         }
     }
 
-    QFile src_file(src);
-    if (!src_file.open(QIODevice::ReadOnly)) {
-        if (auto err = tryOpen(src_file, _src, O_RDONLY, S_IRUSR, errno)) {
+    QFile srcFile(src);
+    if (!srcFile.open(QIODevice::ReadOnly)) {
+        if (auto err = tryOpen(srcFile, _src, O_RDONLY, S_IRUSR, errno)) {
             if (!err.wasCanceled()) {
                 error(KIO::ERR_CANNOT_OPEN_FOR_READING, src);
             }
@@ -794,12 +751,12 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mode, JobF
     }
 
 #if HAVE_FADVISE
-    posix_fadvise(src_file.handle(), 0, 0, POSIX_FADV_SEQUENTIAL);
+    posix_fadvise(srcFile.handle(), 0, 0, POSIX_FADV_SEQUENTIAL);
 #endif
 
-    QFile dest_file(dest);
-    if (!dest_file.open(QIODevice::Truncate | QIODevice::WriteOnly)) {
-        if (auto err = tryOpen(dest_file, _dest, O_WRONLY | O_TRUNC | O_CREAT, S_IRUSR | S_IWUSR, errno)) {
+    QFile destFile(dest);
+    if (!destFile.open(QIODevice::Truncate | QIODevice::WriteOnly)) {
+        if (auto err = tryOpen(destFile, _dest, O_WRONLY | O_TRUNC | O_CREAT, S_IRUSR | S_IWUSR, errno)) {
             if (!err.wasCanceled()) {
                 // qDebug() << "###### COULD NOT WRITE " << dest;
                 if (err == EACCES) {
@@ -808,168 +765,173 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mode, JobF
                     error(KIO::ERR_CANNOT_OPEN_FOR_WRITING, dest);
                 }
             }
-            src_file.close();
             return;
         }
     }
 
-    // nobody shall be allowed to peek into the file during creation
-    // Note that error handling is omitted for this call, we don't want to error on e.g. VFAT
-    dest_file.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner);
+    // _mode == -1 means don't touch dest permissions, leave it with the system default ones
+    if (_mode != -1) {
+        if (::chmod(_dest.constData(), _mode) == -1) {
+            const int errCode = errno;
+            KMountPoint::Ptr mp = KMountPoint::currentMountPoints().findByPath(dest);
+            // Eat the error if the filesystem apparently doesn't support chmod.
+            // This test isn't fullproof though, vboxsf (VirtualBox shared folder) supports
+            // chmod if the host is Linux, and doesn't if the host is Windows. Hard to detect.
+            if (mp && mp->testFileSystemFlag(KMountPoint::SupportsChmod)) {
+                if (tryChangeFileAttr(CHMOD, {_dest, _mode}, errCode)) {
+                    qCWarning(KIO_FILE) << "Could not change permissions for" << dest;
+                }
+            }
+        }
+    }
 
 #if HAVE_FADVISE
-    posix_fadvise(dest_file.handle(), 0, 0, POSIX_FADV_SEQUENTIAL);
+    posix_fadvise(destFile.handle(), 0, 0, POSIX_FADV_SEQUENTIAL);
 #endif
 
-#if HAVE_POSIX_ACL
-    acl = acl_get_fd(src_file.handle());
-    if (acl && !isExtendedACL(acl)) {
-        // qDebug() << _dest.data() << " doesn't have extended ACL";
-        acl_free(acl);
-        acl = nullptr;
-    }
-#endif
-    totalSize(buff_src.st_size);
+    totalSize(buffSrc.st_size);
+
+    off_t sizeProcessed = 0;
 
 #ifdef FICLONE
     // Share data blocks ("reflink") on supporting filesystems, like brfs and XFS
-    int ret = ::ioctl(dest_file.handle(), FICLONE, src_file.handle());
+    int ret = ::ioctl(destFile.handle(), FICLONE, srcFile.handle());
     if (ret != -1) {
-        processedSize(src_file.size());
-    } else {
-        // if fs does not support reflinking, files are on different devices...
+        sizeProcessed = srcFile.size();
+        processedSize(srcFile.size());
+    }
+    // if fs does not support reflinking, files are on different devices...
 #endif
-        KIO::filesize_t processed_size = 0;
-        char buffer[s_maxIPCSize];
-        ssize_t n = 0;
-#ifdef USE_SENDFILE
-        bool use_sendfile = true;
+
+    bool existingDestDeleteAttempted = false;
+
+    processedSize(sizeProcessed);
+
+#if HAVE_COPY_FILE_RANGE
+    while (!wasKilled() && sizeProcessed < srcFile.size()) {
+        if (testMode && destFile.fileName().contains(QLatin1String("slow"))) {
+            QThread::msleep(50);
+        }
+
+        const ssize_t copiedBytes = ::copy_file_range(srcFile.handle(), nullptr, destFile.handle(), nullptr, s_maxIPCSize, 0);
+
+        if (copiedBytes == -1) {
+            if (errno == EINVAL || errno == EXDEV) {
+                break; // will continue with next copy mechanism
+            }
+
+            if (errno == EINTR) { // Interrupted
+                continue;
+            }
+
+            if (errno == ENOSPC) { // disk full
+                // attempt to free disk space occupied by file being overwritten
+                if (!_destBackup.isEmpty() && !existingDestDeleteAttempted) {
+                    ::unlink(_destBackup.constData());
+                    existingDestDeleteAttempted = true;
+                    continue;
+                }
+                error(KIO::ERR_DISK_FULL, dest);
+            } else {
+                error(KIO::ERR_SLAVE_DEFINED, i18n("Cannot copy file from %1 to %2. (Errno: %3)", src, dest, errno));
+            }
+
+            if (!QFile::remove(dest)) { // don't keep partly copied file
+                execWithElevatedPrivilege(DEL, {_dest}, errno);
+            }
+            return;
+        }
+
+        sizeProcessed += copiedBytes;
+        processedSize(sizeProcessed);
+    }
 #endif
-        bool existing_dest_delete_attempted = false;
-        while (!wasKilled()) {
-            if (testMode && dest_file.fileName().contains(QLatin1String("slow"))) {
+
+    /* standard read/write fallback */
+    if (sizeProcessed < srcFile.size()) {
+        std::array<char, s_maxIPCSize> buffer;
+        while (!wasKilled() && sizeProcessed < srcFile.size()) {
+            if (testMode && destFile.fileName().contains(QLatin1String("slow"))) {
                 QThread::msleep(50);
             }
 
-#ifdef USE_SENDFILE
-            if (use_sendfile) {
-                off_t sf = processed_size;
-                n = ::sendfile(dest_file.handle(), src_file.handle(), &sf, s_maxIPCSize);
-                processed_size = sf;
-                if (n == -1 && (errno == EINVAL || errno == ENOSYS)) { // not all filesystems support sendfile()
-                    // qDebug() << "sendfile() not supported, falling back ";
-                    use_sendfile = false;
-                }
-            }
-            if (!use_sendfile)
-#endif
-                n = ::read(src_file.handle(), buffer, s_maxIPCSize);
+            const ssize_t readBytes = ::read(srcFile.handle(), &buffer, s_maxIPCSize);
 
-            if (n == -1) {
-                if (errno == EINTR) {
+            if (readBytes == -1) {
+                if (errno == EINTR) { // Interrupted
                     continue;
-                }
-#ifdef USE_SENDFILE
-                if (use_sendfile) {
-                    // qDebug() << "sendfile() error:" << strerror(errno);
-                    if (errno == ENOSPC) { // disk full
-                        if (!_dest_backup.isEmpty() && !existing_dest_delete_attempted) {
-                            ::unlink(_dest_backup.constData());
-                            existing_dest_delete_attempted = true;
-                            continue;
-                        }
-                        error(KIO::ERR_DISK_FULL, dest);
-                    } else {
-                        error(KIO::ERR_SLAVE_DEFINED, i18n("Cannot copy file from %1 to %2. (Errno: %3)", src, dest, errno));
-                    }
-                } else
-#endif
+                } else {
+                    qCWarning(KIO_FILE) << "Couldn't read[2]. Error:" << srcFile.errorString();
                     error(KIO::ERR_CANNOT_READ, src);
-                src_file.close();
-                dest_file.close();
-#if HAVE_POSIX_ACL
-                if (acl) {
-                    acl_free(acl);
                 }
-#endif
+
                 if (!QFile::remove(dest)) { // don't keep partly copied file
                     execWithElevatedPrivilege(DEL, {_dest}, errno);
                 }
                 return;
             }
-            if (n == 0) {
-                break; // Finished
-            }
-#ifdef USE_SENDFILE
-            if (!use_sendfile) {
-#endif
-                if (dest_file.write(buffer, n) != n) {
-                    if (dest_file.error() == QFileDevice::ResourceError) { // disk full
-                        if (!_dest_backup.isEmpty() && !existing_dest_delete_attempted) {
-                            ::unlink(_dest_backup.constData());
-                            existing_dest_delete_attempted = true;
+
+            if (destFile.write(buffer.data(), readBytes) != readBytes) {
+                if (destFile.error() == QFileDevice::ResourceError) { // disk full
+                    // attempt to free disk space occupied by file being overwritten
+                    if (!_destBackup.isEmpty() && !existingDestDeleteAttempted) {
+                        ::unlink(_destBackup.constData());
+                        existingDestDeleteAttempted = true;
+                        if (destFile.write(buffer.data(), readBytes) == readBytes) { // retry
                             continue;
                         }
-                        error(KIO::ERR_DISK_FULL, dest);
-                    } else {
-                        qCWarning(KIO_FILE) << "Couldn't write[2]. Error:" << dest_file.errorString();
-                        error(KIO::ERR_CANNOT_WRITE, dest);
                     }
-#if HAVE_POSIX_ACL
-                    if (acl) {
-                        acl_free(acl);
-                    }
-#endif
-                    if (!QFile::remove(dest)) { // don't keep partly copied file
-                        execWithElevatedPrivilege(DEL, {_dest}, errno);
-                    }
-                    return;
+                    error(KIO::ERR_DISK_FULL, dest);
+                } else {
+                    qCWarning(KIO_FILE) << "Couldn't write[2]. Error:" << destFile.errorString();
+                    error(KIO::ERR_CANNOT_WRITE, dest);
                 }
-                processed_size += n;
-#ifdef USE_SENDFILE
+
+                if (!QFile::remove(dest)) { // don't keep partly copied file
+                    execWithElevatedPrivilege(DEL, {_dest}, errno);
+                }
+                return;
             }
-#endif
-            processedSize(processed_size);
+            sizeProcessed += readBytes;
+            processedSize(sizeProcessed);
         }
-#ifdef FICLONE
     }
-#endif
 
     // Copy Extended attributes
 #if HAVE_SYS_XATTR_H || HAVE_SYS_EXTATTR_H
-    if (!copyXattrs(src_file.handle(), dest_file.handle())) {
-        qCDebug(KIO_FILE) << "cant copy Extended attributes";
+    if (!copyXattrs(srcFile.handle(), destFile.handle())) {
+        qCDebug(KIO_FILE) << "can't copy Extended attributes";
     }
 #endif
 
-    src_file.close();
+    srcFile.close();
 
-    dest_file.flush(); // so the write() happens before futimes()
+    destFile.flush(); // so the write() happens before futimes()
 
     // copy access and modification time
     if (!wasKilled()) {
 #if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
         // with nano secs precision
         struct timespec ut[2];
-        ut[0] = buff_src.st_atim;
-        ut[1] = buff_src.st_mtim;
+        ut[0] = buffSrc.st_atim;
+        ut[1] = buffSrc.st_mtim;
         // need to do this with the dest file still opened, or this fails
-        if (::futimens(dest_file.handle(), ut) != 0) {
+        if (::futimens(destFile.handle(), ut) != 0) {
 #else
         struct timeval ut[2];
-        ut[0].tv_sec = buff_src.st_atime;
+        ut[0].tv_sec = buffSrc.st_atime;
         ut[0].tv_usec = 0;
-        ut[1].tv_sec = buff_src.st_mtime;
+        ut[1].tv_sec = buffSrc.st_mtime;
         ut[1].tv_usec = 0;
-        if (::futimes(dest_file.handle(), ut) != 0) {
+        if (::futimes(destFile.handle(), ut) != 0) {
 #endif
-            if (tryChangeFileAttr(UTIME, {_dest, qint64(buff_src.st_atime), qint64(buff_src.st_mtime)}, errno)) {
+            if (tryChangeFileAttr(UTIME, {_dest, qint64(buffSrc.st_atime), qint64(buffSrc.st_mtime)}, errno)) {
                 qCWarning(KIO_FILE) << "Couldn't preserve access and modification time for" << dest;
             }
         }
     }
 
-    dest_file.close();
+    destFile.close();
 
     if (wasKilled()) {
         qCDebug(KIO_FILE) << "Clean dest file after ioslave was killed:" << dest;
@@ -980,70 +942,50 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mode, JobF
         return;
     }
 
-    if (dest_file.error() != QFile::NoError) {
-        qCWarning(KIO_FILE) << "Error when closing file descriptor[2]:" << dest_file.errorString();
+    if (destFile.error() != QFile::NoError) {
+        qCWarning(KIO_FILE) << "Error when closing file descriptor[2]:" << destFile.errorString();
         error(KIO::ERR_CANNOT_WRITE, dest);
-#if HAVE_POSIX_ACL
-        if (acl) {
-            acl_free(acl);
-        }
-#endif
+
         if (!QFile::remove(dest)) { // don't keep partly copied file
             execWithElevatedPrivilege(DEL, {_dest}, errno);
         }
         return;
     }
 
-    // set final permissions
-    // if no special mode given, preserve the mode from the sourcefile
+#if HAVE_POSIX_ACL
+    // If no special mode is given, preserve the ACL attributes from the source file
     if (_mode == -1) {
-        _mode = buff_src.st_mode;
-    }
-
-    if ((::chmod(_dest.data(), _mode) != 0)
-#if HAVE_POSIX_ACL
-        || (acl && acl_set_file(_dest.data(), ACL_TYPE_ACCESS, acl) != 0)
-#endif
-    ) {
-        const int errCode = errno;
-        KMountPoint::Ptr mp = KMountPoint::currentMountPoints().findByPath(dest);
-        // Eat the error if the filesystem apparently doesn't support chmod.
-        // This test isn't fullproof though, vboxsf (VirtualBox shared folder) supports
-        // chmod if the host is Linux, and doesn't if the host is Windows. Hard to detect.
-        if (mp && mp->testFileSystemFlag(KMountPoint::SupportsChmod)) {
-            if (tryChangeFileAttr(CHMOD, {_dest, _mode}, errCode)) {
-                qCWarning(KIO_FILE) << "Could not change permissions for" << dest;
-            }
+        acl_t acl = acl_get_fd(srcFile.handle());
+        if (acl && acl_set_file(_dest.data(), ACL_TYPE_ACCESS, acl) != 0) {
+            qCWarning(KIO_FILE) << "Could not set ACL permissions for" << dest;
         }
     }
-#if HAVE_POSIX_ACL
-    if (acl) {
-        acl_free(acl);
-    }
 #endif
 
     // preserve ownership
-    if (::chown(_dest.data(), -1 /*keep user*/, buff_src.st_gid) == 0) {
-        // as we are the owner of the new file, we can always change the group, but
-        // we might not be allowed to change the owner
-        (void)::chown(_dest.data(), buff_src.st_uid, -1 /*keep group*/);
-    } else {
-        if (tryChangeFileAttr(CHOWN, {_dest, buff_src.st_uid, buff_src.st_gid}, errno)) {
-            qCWarning(KIO_FILE) << "Couldn't preserve group for" << dest;
+    if (_mode != -1) {
+        if (::chown(_dest.data(), -1 /*keep user*/, buffSrc.st_gid) == 0) {
+            // as we are the owner of the new file, we can always change the group, but
+            // we might not be allowed to change the owner
+            (void)::chown(_dest.data(), buffSrc.st_uid, -1 /*keep group*/);
+        } else {
+            if (tryChangeFileAttr(CHOWN, {_dest, buffSrc.st_uid, buffSrc.st_gid}, errno)) {
+                qCWarning(KIO_FILE) << "Couldn't preserve group for" << dest;
+            }
         }
     }
 
-    if (!_dest_backup.isEmpty()) {
-        if (::unlink(_dest_backup.constData()) == -1) {
-            qCWarning(KIO_FILE) << "Couldn't remove original dest" << _dest_backup << "(" << strerror(errno) << ")";
+    if (!_destBackup.isEmpty()) { // Overwrite final dest file with new file
+        if (::unlink(_destBackup.constData()) == -1) {
+            qCWarning(KIO_FILE) << "Couldn't remove original dest" << _destBackup << "(" << strerror(errno) << ")";
         }
 
-        if (::rename(_dest.constData(), _dest_backup.constData()) == -1) {
-            qCWarning(KIO_FILE) << "Couldn't rename" << _dest << "to" << _dest_backup << "(" << strerror(errno) << ")";
+        if (::rename(_dest.constData(), _destBackup.constData()) == -1) {
+            qCWarning(KIO_FILE) << "Couldn't rename" << _dest << "to" << _destBackup << "(" << strerror(errno) << ")";
         }
     }
 
-    processedSize(buff_src.st_size);
+    processedSize(buffSrc.st_size);
     finished();
 }
 
@@ -1175,8 +1117,8 @@ void FileProtocol::listDir(const QUrl &url)
             if (QT_LSTAT(ep->d_name, &st) == -1) {
                 continue; // how can stat fail?
             }
-            entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, ((st.st_mode & QT_STAT_MASK) == QT_STAT_DIR) ? S_IFDIR : S_IFREG);
-            const bool isSymLink = ((st.st_mode & QT_STAT_MASK) == QT_STAT_LNK);
+            entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_ISDIR(st.st_mode) ? S_IFDIR : S_IFREG);
+            const bool isSymLink = S_ISLNK(st.st_mode);
 #endif
             if (isSymLink) {
                 // for symlinks obey the UDSEntry contract and provide UDS_LINK_DEST
@@ -1264,7 +1206,7 @@ void FileProtocol::rename(const QUrl &srcUrl, const QUrl &destUrl, KIO::JobFlags
             return;
         }
 
-        if ((buff_dest.st_mode & QT_STAT_MASK) == QT_STAT_DIR) {
+        if (S_ISDIR(buff_dest.st_mode)) {
             error(KIO::ERR_DIR_ALREADY_EXIST, dest);
             return;
         }
@@ -1297,44 +1239,70 @@ void FileProtocol::rename(const QUrl &srcUrl, const QUrl &destUrl, KIO::JobFlags
 
 void FileProtocol::symlink(const QString &target, const QUrl &destUrl, KIO::JobFlags flags)
 {
-    const QString dest = destUrl.toLocalFile();
     // Assume dest is local too (wouldn't be here otherwise)
-    if (::symlink(QFile::encodeName(target).constData(), QFile::encodeName(dest).constData()) == -1) {
-        // Does the destination already exist ?
-        if (errno == EEXIST) {
-            if ((flags & KIO::Overwrite)) {
-                // Try to delete the destination
-                if (unlink(QFile::encodeName(dest).constData()) != 0) {
-                    if (auto err = execWithElevatedPrivilege(DEL, {dest}, errno)) {
-                        if (!err.wasCanceled()) {
-                            error(KIO::ERR_CANNOT_DELETE, dest);
-                        }
-                        return;
+    const QString dest = destUrl.toLocalFile();
+    const QByteArray dest_c = QFile::encodeName(dest);
+
+    if (::symlink(QFile::encodeName(target).constData(), dest_c.constData()) == 0) {
+        finished();
+        return;
+    }
+
+    // Does the destination already exist ?
+    if (errno == EEXIST) {
+        if (flags & KIO::Overwrite) {
+            // Try to delete the destination
+            if (unlink(dest_c.constData()) != 0) {
+                if (auto err = execWithElevatedPrivilege(DEL, {dest}, errno)) {
+                    if (!err.wasCanceled()) {
+                        error(KIO::ERR_CANNOT_DELETE, dest);
                     }
+
+                    return;
                 }
-                // Try again - this won't loop forever since unlink succeeded
-                symlink(target, destUrl, flags);
-                return;
-            } else {
-                QT_STATBUF buff_dest;
-                if (QT_LSTAT(QFile::encodeName(dest).constData(), &buff_dest) == 0 && ((buff_dest.st_mode & QT_STAT_MASK) == QT_STAT_DIR)) {
-                    error(KIO::ERR_DIR_ALREADY_EXIST, dest);
-                } else {
-                    error(KIO::ERR_FILE_ALREADY_EXIST, dest);
-                }
-                return;
             }
+
+            // Try again - this won't loop forever since unlink succeeded
+            symlink(target, destUrl, flags);
+            return;
         } else {
-            if (auto err = execWithElevatedPrivilege(SYMLINK, {dest, target}, errno)) {
-                if (!err.wasCanceled()) {
-                    // Some error occurred while we tried to symlink
-                    error(KIO::ERR_CANNOT_SYMLINK, dest);
-                }
-                return;
+            if (QT_STATBUF buff_dest; QT_LSTAT(dest_c.constData(), &buff_dest) == 0) {
+                error(S_ISDIR(buff_dest.st_mode) ? KIO::ERR_DIR_ALREADY_EXIST : KIO::ERR_FILE_ALREADY_EXIST, dest);
+            } else { // Can't happen, we already know "dest" exists
+                error(KIO::ERR_CANNOT_SYMLINK, dest);
             }
+
+            return;
         }
     }
-    finished();
+
+    // Permission error, could be that the filesystem doesn't support symlinks
+    if (errno == EPERM) {
+        // "dest" doesn't exist, get the filesystem type of the parent dir
+        const QString parentDir = destUrl.adjusted(QUrl::StripTrailingSlash | QUrl::RemoveFilename).toLocalFile();
+        const KFileSystemType::Type fsType = KFileSystemType::fileSystemType(parentDir);
+
+        if (fsType == KFileSystemType::Fat || fsType == KFileSystemType::Exfat) {
+            const QString msg = i18nc(
+                "The first arg is the path to the symlink that couldn't be created, the second"
+                "arg is the filesystem type (e.g. vfat, exfat)",
+                "Could not create symlink \"%1\".\n"
+                "The destination filesystem (%2) doesn't support symlinks.",
+                dest,
+                KFileSystemType::fileSystemName(fsType));
+
+            error(KIO::ERR_SLAVE_DEFINED, msg);
+            return;
+        }
+    }
+
+    auto res = execWithElevatedPrivilege(SYMLINK, {dest, target}, errno);
+    if (res == PrivilegeOperationReturnValue::success()) {
+        finished();
+    } else if (!res.wasCanceled()) {
+        // Some error occurred while we tried to symlink
+        error(KIO::ERR_CANNOT_SYMLINK, dest);
+    }
 }
 
 void FileProtocol::del(const QUrl &url, bool isfile)
@@ -1566,7 +1534,7 @@ int FileProtocol::setACL(const char *path, mode_t perm, bool directoryDefault)
         if (ACLString == QLatin1String("ACL_DELETE")) {
             // user told us to delete the extended ACL, so let's write only
             // the minimal (UNIX permission bits) part
-            acl = acl_from_mode(perm);
+            acl = ACLPortability::acl_from_mode(perm);
         }
         acl = acl_from_text(ACLString.toLatin1().constData());
         if (acl_valid(acl) == 0) { // let's be safe
