@@ -269,8 +269,9 @@ const char *FtpInternal::ftpResponse(int iOffset)
 
 void FtpInternal::closeConnection()
 {
-    if (m_control || m_data)
+    if (m_control || m_data) {
         qCDebug(KIO_FTP) << "m_bLoggedOn=" << m_bLoggedOn << " m_bBusy=" << m_bBusy;
+    }
 
     if (m_bBusy) { // ftpCloseCommand not called
         qCWarning(KIO_FTP) << "Abandoned data stream";
@@ -403,7 +404,7 @@ Result FtpInternal::ftpOpenControlConnection()
 
     Result result = Result::fail();
 
-    for (const QString &proxyUrl : qAsConst(m_proxyUrls)) {
+    for (const QString &proxyUrl : std::as_const(m_proxyUrls)) {
         const QUrl url(proxyUrl);
         const QString scheme(url.scheme());
 
@@ -700,23 +701,19 @@ void FtpInternal::ftpAutoLoginMacro()
         return;
     }
 
-    const QStringList list = macro.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+    QStringList list = macro.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+    auto initIt = std::find_if(list.cbegin(), list.cend(), [](const QString &s) {
+        return s.startsWith(QLatin1String("init"));
+    });
 
-    for (QStringList::const_iterator it = list.begin(); it != list.end(); ++it) {
-        if ((*it).startsWith(QLatin1String("init"))) {
-            const QStringList list2 = macro.split(QLatin1Char('\\'), Qt::SkipEmptyParts);
-            it = list2.begin();
-            ++it; // ignore the macro name
-
-            for (; it != list2.end(); ++it) {
-                // TODO: Add support for arbitrary commands
-                // besides simply changing directory!!
-                if ((*it).startsWith(QLatin1String("cwd"))) {
-                    (void)ftpFolder((*it).mid(4));
-                }
+    if (initIt != list.cend()) {
+        list = macro.split(QLatin1Char('\\'), Qt::SkipEmptyParts);
+        // Ignore the macro name, so start from list.cbegin() + 1
+        for (auto it = list.cbegin() + 1; it != list.cend(); ++it) {
+            // TODO: Add support for arbitrary commands besides simply changing directory!!
+            if ((*it).startsWith(QLatin1String("cwd"))) {
+                (void)ftpFolder((*it).mid(4));
             }
-
-            break;
         }
     }
 }
@@ -1610,7 +1607,11 @@ bool FtpInternal::ftpReadDir(FtpEntry &de)
         // d [RWCEAFMS] Admin                     512 Oct 13  2004 PSI
 
         // we should always get the following 5 fields ...
-        const char *p_access, *p_junk, *p_owner, *p_group, *p_size;
+        const char *p_access;
+        const char *p_junk;
+        const char *p_owner;
+        const char *p_group;
+        const char *p_size;
         if ((p_access = strtok((char *)buffer, " ")) == nullptr) {
             continue;
         }
@@ -1634,7 +1635,10 @@ bool FtpInternal::ftpReadDir(FtpEntry &de)
             de.access = S_IRWXU | S_IRWXG | S_IRWXO; // unknown -> give all permissions
         }
 
-        const char *p_date_1, *p_date_2, *p_date_3, *p_name;
+        const char *p_date_1;
+        const char *p_date_2;
+        const char *p_date_3;
+        const char *p_name;
 
         // A special hack for "/dev". A listing may look like this:
         // crw-rw-rw-   1 root     root       1,   5 Jun 29  1997 zero
@@ -1780,12 +1784,13 @@ bool FtpInternal::ftpReadDir(FtpEntry &de)
             // It seems all FTP servers use the English way
             qCDebug(KIO_FTP) << "Looking for month " << p_date_1;
             static const char s_months[][4] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
-            for (int c = 0; c < 12; c++)
+            for (int c = 0; c < 12; c++) {
                 if (!qstrcmp(p_date_1, s_months[c])) {
                     qCDebug(KIO_FTP) << "Found month " << c << " for " << p_date_1;
                     month = c + 1;
                     break;
                 }
+            }
 
             // Parse third field
             if (p_date_3 && !strchr(p_date_3, ':')) { // No colon, looks like a year
@@ -2116,8 +2121,9 @@ Result FtpInternal::ftpPut(int iCopyFile, const QUrl &dest_url, int permissions,
 
     // set final permissions
     if (permissions != -1) {
-        if (m_user == QLatin1String(s_ftpLogin))
+        if (m_user == QLatin1String(s_ftpLogin)) {
             qCDebug(KIO_FTP) << "Trying to chmod over anonymous FTP ???";
+        }
         // chmod the file we just put
         if (!ftpChmod(dest_orig, permissions)) {
             // To be tested
