@@ -10,24 +10,25 @@ extern "C" int xmlLoadExtDtdDefaultValue;
 
 #include <QDebug>
 
-#include <QtCore/QString>
+#include <QCoreApplication>
+#include <QString>
 
+#include <qplatformdefs.h>
 #include <stdlib.h>
 #include <string.h>
-#include <qplatformdefs.h>
 
-#include <libxml/xmlversion.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/debugXML.h>
 #include <libxml/HTMLtree.h>
-#include <libxml/xmlIO.h>
+#include <libxml/debugXML.h>
 #include <libxml/parserInternals.h>
+#include <libxml/xmlIO.h>
+#include <libxml/xmlmemory.h>
+#include <libxml/xmlversion.h>
 
-#include <libxslt/xsltconfig.h>
-#include <libxslt/xsltInternals.h>
-#include <libxslt/transform.h>
-#include <libxslt/xsltutils.h>
 #include <libexslt/exslt.h>
+#include <libxslt/transform.h>
+#include <libxslt/xsltInternals.h>
+#include <libxslt/xsltconfig.h>
+#include <libxslt/xsltutils.h>
 
 // Pseudo plugin class to embed meta data
 class KIOPluginForMetaData : public QObject
@@ -36,30 +37,32 @@ class KIOPluginForMetaData : public QObject
     Q_PLUGIN_METADATA(IID "org.kde.kio.slave.help" FILE "help.json")
 };
 
-extern "C"
+extern "C" {
+Q_DECL_EXPORT int kdemain(int argc, char **argv)
 {
-    Q_DECL_EXPORT int kdemain(int argc, char **argv)
-    {
-        KDocTools::setupStandardDirs();
+    QCoreApplication app(argc, argv); // needed for KCrash
+    app.setApplicationName(QStringLiteral("kio_help"));
 
-        //qDebug() << "Starting " << getpid();
+    KDocTools::setupStandardDirs();
 
-        if (argc != 4) {
-            fprintf(stderr, "Usage: kio_help protocol domain-socket1 domain-socket2\n");
-            exit(-1);
-        }
+    // qDebug() << "Starting " << getpid();
 
-        LIBXML_TEST_VERSION
-        xmlSubstituteEntitiesDefault(1);
-        xmlLoadExtDtdDefaultValue = 1;
-        exsltRegisterAll();
-
-        HelpProtocol slave(false, argv[2], argv[3]);
-        slave.dispatchLoop();
-
-        //qDebug() << "Done";
-        return 0;
+    if (argc != 4) {
+        fprintf(stderr, "Usage: kio_help protocol domain-socket1 domain-socket2\n");
+        exit(-1);
     }
+
+    LIBXML_TEST_VERSION
+    xmlSubstituteEntitiesDefault(1);
+    xmlLoadExtDtdDefaultValue = 1;
+    exsltRegisterAll();
+
+    HelpProtocol slave(false, argv[2], argv[3]);
+    slave.dispatchLoop();
+
+    // qDebug() << "Done";
+    return 0;
+}
 }
 
 // needed for JSON file embedding
