@@ -150,7 +150,8 @@ TrashSizeCache::SizeAndModTime TrashSizeCache::calculateSizeAndLatestModDate()
         checkMaxTime(trashFileInfo.lastModified().toMSecsSinceEpoch());
     };
     while (it.hasNext()) {
-        const QFileInfo fileInfo = it.next();
+        it.next();
+        const QFileInfo fileInfo = it.fileInfo();
         const QString fileName = fileInfo.fileName();
         if (fileName == QLatin1Char('.') || fileName == QLatin1String("..")) {
             continue;
@@ -168,9 +169,9 @@ TrashSizeCache::SizeAndModTime TrashSizeCache::calculateSizeAndLatestModDate()
         } else {
             // directories
             bool usableCache = false;
-            DirCacheHash::const_iterator it = dirCache.constFind(QFile::encodeName(fileName));
-            if (it != dirCache.constEnd()) {
-                const SizeAndModTime &data = *it;
+            auto dirIt = dirCache.constFind(QFile::encodeName(fileName));
+            if (dirIt != dirCache.constEnd()) {
+                const SizeAndModTime &data = *dirIt;
                 const auto trashFileInfo = getTrashFileInfo(fileName);
                 if (trashFileInfo.exists() && trashFileInfo.lastModified().toMSecsSinceEpoch() == data.mtime) {
                     sum += data.size;
