@@ -13,19 +13,23 @@
 #include "kuriikwsfiltereng.h"
 #include "searchprovider.h"
 
-#include <KConfigGroup>
 #include <KConfig>
+#include <KConfigGroup>
 #include <kprotocolinfo.h>
 
+#include <QLoggingCategory>
 #include <QRegularExpression>
 #include <QTextCodec>
-#include <QLoggingCategory>
 
-namespace {
-QLoggingCategory category("kf.kio.urifilters.ikws", QtWarningMsg);
+namespace
+{
+Q_LOGGING_CATEGORY(category, "kf.kio.urifilters.ikws", QtWarningMsg)
 }
 
-#define PDVAR(n, v) qCDebug(category) << n << " = '" << v << "'"
+static void kuriikws_debug(const QString &n, const QString &v)
+{
+    qCDebug(category) << n << " = '" << v << "'";
+}
 
 /**
  * IMPORTANT: If you change anything here, make sure kiowidgets-kurifiltertest-{colon,space}-separator
@@ -41,33 +45,21 @@ KURISearchFilterEngine::~KURISearchFilterEngine()
 {
 }
 
+// static
+QStringList KURISearchFilterEngine::defaultSearchProviders()
+{
+    static const QStringList defaultProviders{QStringLiteral("google"),
+                                              QStringLiteral("youtube"),
+                                              QStringLiteral("yahoo"),
+                                              QStringLiteral("wikipedia"),
+                                              QStringLiteral("wikit")};
+    return defaultProviders;
+}
+
 SearchProvider *KURISearchFilterEngine::webShortcutQuery(const QString &typedString, QString &searchTerm) const
 {
-    SearchProvider *provider = nullptr;
-
-    if (m_bWebShortcutsEnabled) {
-        QString key;
-         if (typedString.contains(QLatin1Char('!'))) {
-            const static QRegularExpression bangRegex(QStringLiteral("!([^ ]+)"));
-            const auto match = bangRegex.match(typedString);
-            if (match.hasMatch() && match.lastCapturedIndex() == 1) {
-                key = match.captured(1);
-                searchTerm = QString(typedString).remove(bangRegex);
-            }
-        }
-        if (key.isEmpty()) {
-            const int pos = typedString.indexOf(QLatin1Char(m_cKeywordDelimiter));
-            if (pos > -1) {
-                key = typedString.left(pos).toLower(); // #169801
-                searchTerm = typedString.mid(pos+1);
-            } else if (!typedString.isEmpty() && m_cKeywordDelimiter == ' ') {
-                key = typedString;
-                searchTerm = typedString.mid(pos+1);
-            }
-        }
-
-        qCDebug(category) << "m_cKeywordDelimiter=" << QLatin1Char(m_cKeywordDelimiter) << "key=" << key << "typedString=" << typedString;
-
+    const auto getProviderForKey = [this, &searchTerm](const QString &key) {
+        SearchProvider *provider = nullptr;
         // If the key contains a : an assertion in the isKnownProtocol method would fail. This can be
         // the case if the delimiter is switched to space, see kiowidgets_space_separator_test
         if (!key.isEmpty() && (key.contains(QLatin1Char(':')) || !KProtocolInfo::isKnownProtocol(key))) {
@@ -80,6 +72,43 @@ SearchProvider *KURISearchFilterEngine::webShortcutQuery(const QString &typedStr
                 }
             }
         }
+        return provider;
+    };
+
+    SearchProvider *provider = nullptr;
+    if (m_bWebShortcutsEnabled) {
+        QString key;
+        if (typedString.contains(QLatin1Char('!'))) {
+            const static QRegularExpression bangRegex(QStringLiteral("!([^ ]+)"));
+            const auto match = bangRegex.match(typedString);
+            if (match.hasMatch() && match.lastCapturedIndex() == 1) {
+                key = match.captured(1);
+                searchTerm = QString(typedString).remove(bangRegex);
+            }
+        }
+
+        // If we have found a bang-match it might be unintentionally triggered, because the ! character is contained
+        // in the query. To avoid not returning any results we check if we can find a provider for the key, if not
+        // we clear it and try the traditional query syntax, see https://bugs.kde.org/show_bug.cgi?id=437660
+        if (!key.isEmpty()) {
+            provider = getProviderForKey(key);
+            if (!provider) {
+                key.clear();
+            }
+        }
+        if (key.isEmpty()) {
+            const int pos = typedString.indexOf(QLatin1Char(m_cKeywordDelimiter));
+            if (pos > -1) {
+                key = typedString.left(pos).toLower(); // #169801
+                searchTerm = typedString.mid(pos + 1);
+            } else if (!typedString.isEmpty() && m_cKeywordDelimiter == ' ') {
+                key = typedString;
+                searchTerm = typedString.mid(pos + 1);
+            }
+            provider = getProviderForKey(key);
+        }
+
+        qCDebug(category) << "m_cKeywordDelimiter=" << QLatin1Char(m_cKeywordDelimiter) << "key=" << key << "typedString=" << typedString;
     }
 
     return provider;
@@ -150,11 +179,7 @@ QStringList KURISearchFilterEngine::modifySubstitutionMap(SubstMap &map, const Q
     }
 
     // Split user query between spaces:
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QStringList l = userquery.simplified().split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
     QStringList l = userquery.simplified().split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 
     // Back-substitute quoted strings (%20 -> " "):
     userquery.replace(QLatin1String("%20"), QLatin1String(" "));
@@ -173,12 +198,12 @@ QStringList KURISearchFilterEngine::modifySubstitutionMap(SubstMap &map, const Q
         }
         // Add partial user query items to substitution map:
         else {
-            v = l[i-1];
+            v = l[i - 1];
         }
 
         // Insert partial queries (referenced by \1 ... \n) to map:
         map.insert(QString::number(i), v);
-        PDVAR(QLatin1String("  map['") + nr + QLatin1String("']"), map[nr]);
+        kuriikws_debug(QLatin1String("  map['") + nr + QLatin1String("']"), map[nr]);
 
         // Insert named references (referenced by \name) to map:
         if ((i > 0) && (pos = v.indexOf(QLatin1Char('='))) > 0) {
@@ -188,7 +213,7 @@ QStringList KURISearchFilterEngine::modifySubstitutionMap(SubstMap &map, const Q
             // Back-substitute references contained in references (e.g. '\refname' substitutes to 'thisquery=\0')
             s.replace(QLatin1String("%5C"), QLatin1String("\\"));
             map.insert(k, s);
-            PDVAR(QLatin1String("  map['") + k + QLatin1String("']"), map[k]);
+            kuriikws_debug(QLatin1String("  map['") + k + QLatin1String("']"), map[k]);
         }
     }
 
@@ -214,7 +239,7 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
         if ((pos = newurl.indexOf(QLatin1String("\\1"))) >= 0) {
             qCWarning(category) << "WARNING: Using compatibility mode for newurl='" << newurl
                                 << "'. Please replace old style '\\1' with new style '\\{0}' "
-                "in the query definition.\n";
+                                   "in the query definition.\n";
             newurl.replace(pos, 2, QStringLiteral("\\{@}"));
         }
     }
@@ -229,10 +254,10 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
         while ((match = reflistRe.match(newurl, start)).hasMatch()) {
             bool found = false;
 
-            //bool rest = false;
+            // bool rest = false;
             QString v;
             const QString rlstring = match.captured(1);
-            PDVAR("  reference list", rlstring);
+            kuriikws_debug(QStringLiteral("  reference list"), rlstring);
 
             // \{@} gets a special treatment later
             if (rlstring == QLatin1String("@")) {
@@ -241,15 +266,13 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
             }
 
             // TODO: strip whitespaces around commas
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            QStringList rl = rlstring.split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
-            QStringList rl = rlstring.split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
-            int i = 0;
+            const QStringList refList = rlstring.split(QLatin1Char(','), Qt::SkipEmptyParts);
+
+            for (const QString &rlitem : refList) {
+                if (found) {
+                    break;
+                }
 
-            while ((i < rl.count()) && !found) {
-                const QString rlitem = rl.at(i);
                 const QRegularExpression rangeRe(QStringLiteral("([0-9]*)\\-([0-9]*)"));
                 const QRegularExpressionMatch rangeMatch = rangeRe.match(rlitem);
                 // Substitute a range of keywords
@@ -268,7 +291,7 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
                     for (int i = first; i <= last; i++) {
                         v += map[QString::number(i)] + QLatin1Char(' ');
                         // Remove used value from ql (needed for \{@}):
-                        ql[i-1].clear();
+                        ql[i - 1].clear();
                     }
 
                     v = v.trimmed();
@@ -276,22 +299,23 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
                         found = true;
                     }
 
-                    PDVAR(QLatin1String("    range"), QString::number(first) + QLatin1Char('-') + QString::number(last) + QLatin1String(" => '") + v + QLatin1Char('\''));
+                    kuriikws_debug(QStringLiteral("    range"),
+                                   QString::number(first) + QLatin1Char('-') + QString::number(last) + QLatin1String(" => '") + v + QLatin1Char('\''));
                     v = encodeString(v, codec);
                 } else if (rlitem.startsWith(QLatin1Char('\"')) && rlitem.endsWith(QLatin1Char('\"'))) {
                     // Use default string from query definition:
                     found = true;
                     QString s = rlitem.mid(1, rlitem.length() - 2);
                     v = encodeString(s, codec);
-                    PDVAR("    default", s);
+                    kuriikws_debug(QStringLiteral("    default"), s);
                 } else if (map.contains(rlitem)) {
                     // Use value from substitution map:
                     found = true;
-                    PDVAR(QLatin1String("    map['") + rlitem + QLatin1String("']"), map[rlitem]);
+                    kuriikws_debug(QLatin1String("    map['") + rlitem + QLatin1String("']"), map[rlitem]);
                     v = encodeString(map[rlitem], codec);
 
                     // Remove used value from ql (needed for \{@}):
-                    QString c = rlitem.left(1);
+                    const QChar c = rlitem.at(0); // rlitem can't be empty at this point
                     if (c == QLatin1Char('0')) {
                         // It's a numeric reference to '0'
                         for (QStringList::Iterator it = ql.begin(); it != ql.end(); ++it) {
@@ -300,7 +324,7 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
                     } else if ((c >= QLatin1String("0")) && (c <= QLatin1String("9"))) { // krazy:excludeall=doublequote_chars
                         // It's a numeric reference > '0'
                         int n = rlitem.toInt();
-                        ql[n-1].clear();
+                        ql[n - 1].clear();
                     } else {
                         // It's a alphanumeric reference
                         QStringList::Iterator it = ql.begin();
@@ -316,10 +340,8 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
                     v.replace(QLatin1Char('+'), QLatin1String("%2B"));
                 } else if (rlitem == QLatin1String("@")) {
                     v = QStringLiteral("\\@");
-                    PDVAR("    v", v);
+                    kuriikws_debug(QStringLiteral("    v"), v);
                 }
-
-                i++;
             }
 
             newurl.replace(match.capturedStart(0), match.capturedLength(0), v);
@@ -328,11 +350,11 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
 
         // Special handling for \{@};
         {
-            PDVAR("  newurl", newurl);
+            kuriikws_debug(QStringLiteral("  newurl"), newurl);
             // Generate list of unmatched strings:
             QString v = ql.join(QLatin1Char(' ')).simplified();
 
-            PDVAR("    rest", v);
+            kuriikws_debug(QStringLiteral("    rest"), v);
             v = encodeString(v, codec);
 
             // Substitute \{@} with list of unmatched query strings
@@ -349,7 +371,12 @@ QUrl KURISearchFilterEngine::formatResult(const QString &url, const QString &cse
     return formatResult(url, cset1, cset2, query, isMalformed, map);
 }
 
-QUrl KURISearchFilterEngine::formatResult(const QString &url, const QString &cset1, const QString &cset2, const QString &userquery, bool /* isMalformed */, SubstMap &map) const
+QUrl KURISearchFilterEngine::formatResult(const QString &url,
+                                          const QString &cset1,
+                                          const QString &cset2,
+                                          const QString &userquery,
+                                          bool /* isMalformed */,
+                                          SubstMap &map) const
 {
     // Return nothing if userquery is empty and it contains
     // substitution strings...
@@ -361,7 +388,7 @@ QUrl KURISearchFilterEngine::formatResult(const QString &url, const QString &cse
     if (!map.isEmpty()) {
         qCDebug(category) << "Got non-empty substitution map:\n";
         for (SubstMap::Iterator it = map.begin(); it != map.end(); ++it) {
-            PDVAR(QLatin1String("    map['") + it.key() + QLatin1String("']"), it.value());
+            kuriikws_debug(QLatin1String("    map['") + it.key() + QLatin1String("']"), it.value());
         }
     }
 
@@ -377,8 +404,8 @@ QUrl KURISearchFilterEngine::formatResult(const QString &url, const QString &cse
         csetacodec = QTextCodec::codecForName(cseta.toLatin1());
     }
 
-    PDVAR("user query", userquery);
-    PDVAR("query definition", url);
+    kuriikws_debug(QStringLiteral("user query"), userquery);
+    kuriikws_debug(QStringLiteral("query definition"), url);
 
     // Add charset indicator for the query to substitution map:
     map.insert(QStringLiteral("ikw_charset"), cseta);
@@ -392,7 +419,7 @@ QUrl KURISearchFilterEngine::formatResult(const QString &url, const QString &cse
 
     QString newurl = substituteQuery(url, map, userquery, csetacodec);
 
-    PDVAR("substituted query", newurl);
+    kuriikws_debug(QStringLiteral("substituted query"), newurl);
 
     return QUrl(newurl, QUrl::StrictMode);
 }
@@ -412,7 +439,7 @@ void KURISearchFilterEngine::loadConfig()
 
     QStringList defaultPreferredShortcuts;
     if (!group.hasKey("PreferredWebShortcuts")) {
-        defaultPreferredShortcuts = DEFAULT_PREFERRED_SEARCH_PROVIDERS;
+        defaultPreferredShortcuts = KURISearchFilterEngine::defaultSearchProviders();
     }
     m_preferredWebShortcuts = group.readEntry("PreferredWebShortcuts", defaultPreferredShortcuts);
 
