@@ -24,7 +24,7 @@ class QUrl;
 namespace KDEPrivate
 {
 /**
- * Used for KIO::AccessManager; KDE implementation of QNetworkReply.
+ * Used for KIO::Integration::AccessManager; KDE implementation of QNetworkReply.
  *
  * @since 4.3
  * @author Urs Wolfer \<uwolfer @ kde.org\>
@@ -53,7 +53,7 @@ public:
                                 const QString &errorMessage,
                                 QObject *parent = nullptr);
 
-    virtual ~AccessManagerReply();
+    ~AccessManagerReply() override;
     qint64 bytesAvailable() const override;
     void abort() override;
 
