@@ -29,7 +29,7 @@ class KFileItemActionsPrivate : public QObject
 
 public:
     explicit KFileItemActionsPrivate(KFileItemActions *qq);
-    ~KFileItemActionsPrivate();
+    ~KFileItemActionsPrivate() override;
 
     int insertServicesSubmenus(const QMap<QString, ServiceList> &list, QMenu *menu, bool isBuiltin);
     int insertServices(const ServiceList &list, QMenu *menu, bool isBuiltin);
@@ -55,6 +55,10 @@ public:
     QPair<int, QMenu *> addServiceActionsTo(QMenu *mainMenu, const QList<QAction *> &additionalActions, const QStringList &excludeList);
     int addPluginActionsTo(QMenu *mainMenu, QMenu *actionsMenu, const QStringList &excludeList);
     void insertOpenWithActionsTo(QAction *before, QMenu *topMenu, const QStringList &excludedDesktopEntryNames, const QString &traderConstraint);
+    static KService::List
+    associatedApplications(const QStringList &mimeTypeList, const QString &traderConstraint, const QStringList &excludedDesktopEntryNames);
+
+    QStringList serviceMenuFilePaths();
 
 public Q_SLOTS:
     void slotRunPreferredApplications();
