@@ -26,6 +26,7 @@
 #include <QStyleOptionButton>
 #include <QtAlgorithms>
 
+#include <KAuthorized>
 #include <KCollapsibleGroupBox>
 #include <KDesktopFile>
 #include <KHistoryComboBox>
@@ -44,7 +45,9 @@
 
 #include <KConfigGroup>
 #include <assert.h>
+#ifndef KIO_ANDROID_STUB
 #include <kbuildsycocaprogressdialog.h>
+#endif
 #include <stdlib.h>
 
 inline void
@@ -195,10 +198,7 @@ KApplicationModel::KApplicationModel(QObject *parent)
     }
 }
 
-KApplicationModel::~KApplicationModel()
-{
-    delete d;
-}
+KApplicationModel::~KApplicationModel() = default;
 
 bool KApplicationModel::canFetchMore(const QModelIndex &parent) const
 {
@@ -391,7 +391,12 @@ bool QTreeViewProxyFilter::filterAcceptsRow(int sourceRow, const QModelIndex &pa
     }
 
     // Match the regexp only on leaf nodes
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    if (!sourceModel()->hasChildren(index) && index.data().toString().contains(filterRegularExpression())) {
+#else
+    // Do not port this to filterRegularExpression in Qt5. setFilterFixedString doesn't set filterRegularExpression() in Qt5
     if (!sourceModel()->hasChildren(index) && index.data().toString().contains(filterRegExp())) {
+#endif
         return true;
     }
 
@@ -418,10 +423,7 @@ KApplicationView::KApplicationView(QWidget *parent)
     setHeaderHidden(true);
 }
 
-KApplicationView::~KApplicationView()
-{
-    delete d;
-}
+KApplicationView::~KApplicationView() = default;
 
 void KApplicationView::setModels(KApplicationModel *model, QSortFilterProxyModel *proxyModel)
 {
@@ -457,13 +459,17 @@ void KApplicationView::currentChanged(const QModelIndex &current, const QModelIn
 {
     QTreeView::currentChanged(current, previous);
 
-    if (d->appModel) {
-        QModelIndex sourceCurrent = d->m_proxyModel->mapToSource(current);
-        if (!d->appModel->isDirectory(sourceCurrent)) {
-            QString exec = d->appModel->execFor(sourceCurrent);
-            if (!exec.isEmpty()) {
-                Q_EMIT highlighted(d->appModel->entryPathFor(sourceCurrent), exec);
-            }
+    if (!d->appModel) {
+        return;
+    }
+
+    QModelIndex sourceCurrent = d->m_proxyModel->mapToSource(current);
+    if (d->appModel->isDirectory(sourceCurrent)) {
+        expand(current);
+    } else {
+        const QString exec = d->appModel->execFor(sourceCurrent);
+        if (!exec.isEmpty()) {
+            Q_EMIT highlighted(d->appModel->entryPathFor(sourceCurrent), exec);
         }
     }
 }
@@ -657,7 +663,7 @@ void KOpenWithDialogPrivate::setMimeType(const QString &mimeType)
 
 void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
 {
-    bool bReadOnly = !KAuthorized::authorize(QStringLiteral("shell_access"));
+    bool bReadOnly = !KAuthorized::authorize(KAuthorized::SHELL_ACCESS);
     m_terminaldirty = false;
     view = nullptr;
     m_pService = nullptr;
@@ -806,8 +812,8 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
 
 KOpenWithDialog::~KOpenWithDialog()
 {
-    delete d;
-}
+    d->edit->removeEventFilter(this);
+};
 
 // ----------------------------------------------------------------------
 
@@ -899,12 +905,12 @@ void KOpenWithDialog::setSaveNewApplications(bool b)
 static QString simplifiedExecLineFromService(const QString &fullExec)
 {
     QString exec = fullExec;
-    exec.remove(QStringLiteral("%u"), Qt::CaseInsensitive);
-    exec.remove(QStringLiteral("%f"), Qt::CaseInsensitive);
-    exec.remove(QStringLiteral("-caption %c"));
-    exec.remove(QStringLiteral("-caption \"%c\""));
-    exec.remove(QStringLiteral("%i"));
-    exec.remove(QStringLiteral("%m"));
+    exec.remove(QLatin1String("%u"), Qt::CaseInsensitive);
+    exec.remove(QLatin1String("%f"), Qt::CaseInsensitive);
+    exec.remove(QLatin1String("-caption %c"));
+    exec.remove(QLatin1String("-caption \"%c\""));
+    exec.remove(QLatin1String("%i"));
+    exec.remove(QLatin1String("%m"));
     return exec.simplified();
 }
 
@@ -932,7 +938,9 @@ void KOpenWithDialogPrivate::addToMimeAppsList(const QString &serviceId /*menu i
     // qDebug() << "rebuilding ksycoca...";
 
     // kbuildsycoca is the one reading mimeapps.list, so we need to run it now
+#ifndef KIO_ANDROID_STUB
     KBuildSycocaProgressDialog::rebuildKSycoca(q);
+#endif
 
     // could be nullptr if the user canceled the dialog...
     m_pService = KService::serviceByStorageId(serviceId);
@@ -1005,7 +1013,15 @@ bool KOpenWithDialogPrivate::checkAccept()
         // qDebug() << "binaryName=" << binaryName;
         // Ensure that the typed binary name actually exists (#81190)
         if (QStandardPaths::findExecutable(binaryName).isEmpty()) {
-            KMessageBox::error(q, i18n("'%1' not found, please type a valid program name.", binaryName));
+            // QStandardPaths::findExecutable does not find non-executable files.
+            // Give a better error message for the case of a existing but non-executable file.
+            // https://bugs.kde.org/show_bug.cgi?id=437880
+            if (QFileInfo::exists(binaryName)) {
+                KMessageBox::error(q, xi18nc("@info", "<filename>%1</filename> does not appear to be an executable program.", binaryName));
+            } else {
+                KMessageBox::error(q, xi18nc("@info", "<filename>%1</filename> was not found; please enter a valid path to an executable program.", binaryName));
+            }
+
             return false;
         }
     }
@@ -1046,7 +1062,7 @@ bool KOpenWithDialogPrivate::checkAccept()
                         index = serviceExec.indexOf(QLatin1String("%f"), 0, Qt::CaseInsensitive);
                     }
                     if (index > -1) {
-                        fullExec += QLatin1Char(' ') + serviceExec.midRef(index, 2);
+                        fullExec += QLatin1Char(' ') + QStringView(serviceExec).mid(index, 2);
                     }
                 }
                 // qDebug() << "Creating service with Exec=" << fullExec;
@@ -1075,6 +1091,14 @@ bool KOpenWithDialogPrivate::checkAccept()
             KConfigGroup cg = desktopFile.desktopGroup();
             cg.writeEntry("Type", "Application");
             cg.writeEntry("Name", initialServiceName);
+
+            // if we select a binary for a scheme handler, then it's safe to assume it can handle URLs
+            if (qMimeType.startsWith(QLatin1String("x-scheme-handler/"))) {
+                if (!typedExec.contains(QLatin1String("%u"), Qt::CaseInsensitive) && !typedExec.contains(QLatin1String("%f"), Qt::CaseInsensitive)) {
+                    fullExec += QStringLiteral(" %u");
+                }
+            }
+
             cg.writeEntry("Exec", fullExec);
             cg.writeEntry("NoDisplay", true); // don't make it appear in the K menu
             if (terminal->isChecked()) {
