@@ -99,10 +99,7 @@ KUriFilterSearchProvider::KUriFilterSearchProvider(const KUriFilterSearchProvide
 {
 }
 
-KUriFilterSearchProvider::~KUriFilterSearchProvider()
-{
-    delete d;
-}
+KUriFilterSearchProvider::~KUriFilterSearchProvider() = default;
 
 QString KUriFilterSearchProvider::desktopEntryName() const
 {
@@ -263,14 +260,11 @@ KUriFilterData::KUriFilterData(const QString &url)
 }
 
 KUriFilterData::KUriFilterData(const KUriFilterData &other)
-    : d(new KUriFilterDataPrivate(other.d))
+    : d(new KUriFilterDataPrivate(*other.d))
 {
 }
 
-KUriFilterData::~KUriFilterData()
-{
-    delete d;
-}
+KUriFilterData::~KUriFilterData() = default;
 
 QUrl KUriFilterData::uri() const
 {
@@ -571,16 +565,13 @@ KUriFilter::KUriFilter()
     loadPlugins();
 }
 
-KUriFilter::~KUriFilter()
-{
-    delete d;
-}
+KUriFilter::~KUriFilter() = default;
 
 bool KUriFilter::filterUri(KUriFilterData &data, const QStringList &filters)
 {
     bool filtered = false;
 
-    for (KUriFilterPlugin *plugin : qAsConst(d->pluginList)) {
+    for (KUriFilterPlugin *plugin : std::as_const(d->pluginList)) {
         // If no specific filters were requested, iterate through all the plugins.
         // Otherwise, only use available filters.
         if (filters.isEmpty() || filters.contains(plugin->objectName())) {
@@ -661,26 +652,22 @@ QStringList KUriFilter::pluginNames() const
 
 void KUriFilter::loadPlugins()
 {
-    QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("kf5/urifilters"));
+    QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/urifilters"));
     const QString prefKey = QStringLiteral("X-KDE-InitialPreference");
     // Sort the plugins by order of priority
     std::sort(plugins.begin(), plugins.end(), [prefKey](const KPluginMetaData &a, const KPluginMetaData &b) {
-        return a.rawData().value(prefKey).toInt() > b.rawData().value(prefKey).toInt();
+        return a.value(prefKey, 0) > b.value(prefKey, 0);
     });
 
     QStringList pluginNames;
     pluginNames.reserve(plugins.count());
 
-    for (const KPluginMetaData &pluginMetaData : qAsConst(plugins)) {
+    for (const KPluginMetaData &pluginMetaData : std::as_const(plugins)) {
         const QString fileName = pluginMetaData.fileName().section(QLatin1Char('/'), -1);
         if (!pluginNames.contains(fileName)) {
             pluginNames << fileName;
-            KPluginFactory *factory = qobject_cast<KPluginFactory *>(pluginMetaData.instantiate());
-            if (factory) {
-                KUriFilterPlugin *plugin = factory->create<KUriFilterPlugin>(nullptr);
-                if (plugin) {
-                    d->pluginList << plugin;
-                }
+            if (auto plugin = KPluginFactory::instantiatePlugin<KUriFilterPlugin>(pluginMetaData).plugin) {
+                d->pluginList << plugin;
             }
         }
     }
