@@ -8,29 +8,27 @@
 #include "openfilemanagerwindowjob.h"
 #include "openfilemanagerwindowjob_p.h"
 
-#include <QDBusMessage>
 #include <QDBusConnection>
+#include <QDBusMessage>
 #include <QDBusPendingCallWatcher>
 #include <QDBusPendingReply>
+#include <QGuiApplication>
 
-
-#include <KRun>
 #include <KJobWidgets>
+#include <KWindowSystem>
 
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenUrlJob>
 
 namespace KIO
 {
-
 class OpenFileManagerWindowJobPrivate
 {
 public:
     OpenFileManagerWindowJobPrivate(OpenFileManagerWindowJob *qq)
-        : q(qq),
-          strategy(nullptr)
+        : q(qq)
+        , strategy(nullptr)
     {
-
     }
 
     ~OpenFileManagerWindowJobPrivate()
@@ -38,14 +36,14 @@ public:
         delete strategy;
     }
 
-    AbstractOpenFileManagerWindowStrategy* createDBusStrategy()
+    AbstractOpenFileManagerWindowStrategy *createDBusStrategy()
     {
         delete strategy;
         strategy = new OpenFileManagerWindowDBusStrategy(q);
         return strategy;
     }
 
-    AbstractOpenFileManagerWindowStrategy* createKRunStrategy()
+    AbstractOpenFileManagerWindowStrategy *createKRunStrategy()
     {
         delete strategy;
         strategy = new OpenFileManagerWindowKRunStrategy(q);
@@ -70,10 +68,7 @@ OpenFileManagerWindowJob::OpenFileManagerWindowJob(QObject *parent)
 #endif
 }
 
-OpenFileManagerWindowJob::~OpenFileManagerWindowJob()
-{
-    delete d;
-}
+OpenFileManagerWindowJob::~OpenFileManagerWindowJob() = default;
 
 QList<QUrl> OpenFileManagerWindowJob::highlightUrls() const
 {
@@ -110,8 +105,25 @@ OpenFileManagerWindowJob *highlightInFileManager(const QList<QUrl> &urls, const
 {
     auto *job = new OpenFileManagerWindowJob();
     job->setHighlightUrls(urls);
-    job->setStartupId(asn);
-    job->start();
+
+    if (asn.isNull()){
+        auto window = qGuiApp->focusWindow();
+        if (!window && !qGuiApp->allWindows().isEmpty()) {
+            window = qGuiApp->allWindows().constFirst();
+        }
+        const int launchedSerial = KWindowSystem::lastInputSerial(window);
+        QObject::connect(KWindowSystem::self(), &KWindowSystem::xdgActivationTokenArrived, job, [launchedSerial, job](int serial, const QString &token) {
+            if (serial == launchedSerial) {
+                job->setStartupId(token.toLatin1());
+                job->start();
+            }
+        });
+        KWindowSystem::requestXdgActivationToken(window, launchedSerial, {});
+    } else {
+        job->setStartupId(asn);
+        job->start();
+    }
+
     return job;
 }
 
