@@ -7,7 +7,6 @@
 
 #include "widgetsaskuseractionhandler.h"
 
-#include <kio_widgets_debug.h>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KGuiItem>
@@ -19,6 +18,7 @@
 #include <KSharedConfig>
 #include <KSslInfoDialog>
 #include <KStandardGuiItem>
+#include <kio_widgets_debug.h>
 
 #include <QDialogButtonBox>
 #include <QRegularExpression>
@@ -27,7 +27,7 @@
 class KIO::WidgetsAskUserActionHandlerPrivate
 {
 public:
-    WidgetsAskUserActionHandlerPrivate(WidgetsAskUserActionHandler *qq)
+    explicit WidgetsAskUserActionHandlerPrivate(WidgetsAskUserActionHandler *qq)
         : q(qq)
     {
     }
@@ -39,7 +39,8 @@ public:
 };
 
 KIO::WidgetsAskUserActionHandler::WidgetsAskUserActionHandler(QObject *parent)
-    : KIO::AskUserActionInterface(parent), d(new WidgetsAskUserActionHandlerPrivate(this))
+    : KIO::AskUserActionInterface(parent)
+    , d(new WidgetsAskUserActionHandlerPrivate(this))
 {
 }
 
@@ -59,11 +60,7 @@ void KIO::WidgetsAskUserActionHandler::askUserRename(KJob *job,
                                                      const QDateTime &mtimeSrc,
                                                      const QDateTime &mtimeDest)
 {
-    auto *dlg = new KIO::RenameDialog(KJobWidgets::window(job), caption,
-                                      src, dest, options,
-                                      sizeSrc, sizeDest,
-                                      ctimeSrc, ctimeDest,
-                                      mtimeSrc, mtimeDest);
+    auto *dlg = new KIO::RenameDialog(KJobWidgets::window(job), caption, src, dest, options, sizeSrc, sizeDest, ctimeSrc, ctimeDest, mtimeSrc, mtimeDest);
 
     dlg->setAttribute(Qt::WA_DeleteOnClose);
     dlg->setWindowModality(Qt::WindowModal);
@@ -72,15 +69,13 @@ void KIO::WidgetsAskUserActionHandler::askUserRename(KJob *job,
     connect(dlg, &QDialog::finished, this, [this, job, dlg](const int exitCode) {
         KIO::RenameDialog_Result result = static_cast<RenameDialog_Result>(exitCode);
         const QUrl newUrl = result == Result_AutoRename ? dlg->autoDestUrl() : dlg->newDestUrl();
-        emit askUserRenameResult(result, newUrl, job);
+        Q_EMIT askUserRenameResult(result, newUrl, job);
     });
 
     dlg->show();
 }
 
-void KIO::WidgetsAskUserActionHandler::askUserSkip(KJob *job,
-                                                   KIO::SkipDialog_Options options,
-                                                   const QString &errorText)
+void KIO::WidgetsAskUserActionHandler::askUserSkip(KJob *job, KIO::SkipDialog_Options options, const QString &errorText)
 {
     auto *dlg = new KIO::SkipDialog(KJobWidgets::window(job), options, errorText);
     dlg->setAttribute(Qt::WA_DeleteOnClose);
@@ -88,16 +83,13 @@ void KIO::WidgetsAskUserActionHandler::askUserSkip(KJob *job,
 
     connect(job, &KJob::finished, dlg, &QDialog::reject);
     connect(dlg, &QDialog::finished, this, [this, job](const int exitCode) {
-        emit askUserSkipResult(static_cast<KIO::SkipDialog_Result>(exitCode), job);
+        Q_EMIT askUserSkipResult(static_cast<KIO::SkipDialog_Result>(exitCode), job);
     });
 
     dlg->show();
 }
 
-void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls,
-                                                     DeletionType deletionType,
-                                                     ConfirmationType confirmationType,
-                                                     QWidget *parent)
+void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls, DeletionType deletionType, ConfirmationType confirmationType, QWidget *parent)
 {
     KSharedConfigPtr kioConfig = KSharedConfig::openConfig(QStringLiteral("kiorc"), KConfig::NoGlobals);
 
@@ -126,7 +118,7 @@ void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls,
     }
 
     if (!ask) {
-        emit askUserDeleteResult(true, urls, deletionType, parent);
+        Q_EMIT askUserDeleteResult(true, urls, deletionType, parent);
         return;
     }
 
@@ -150,27 +142,33 @@ void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls,
     QString text;
     QString caption = i18n("Delete Permanently");
 
-    switch(deletionType) {
+    switch (deletionType) {
     case Delete: {
-        text = xi18ncp("@info", "Do you really want to permanently delete this %1 item?<nl/><nl/>"
+        text = xi18ncp("@info",
+                       "Do you really want to permanently delete this %1 item?<nl/><nl/>"
                        "<emphasis strong='true'>This action cannot be undone.</emphasis>",
                        "Do you really want to permanently delete these %1 items?<nl/><nl/>"
-                       "<emphasis strong='true'>This action cannot be undone.</emphasis>", urlCount);
+                       "<emphasis strong='true'>This action cannot be undone.</emphasis>",
+                       urlCount);
         acceptButton = KStandardGuiItem::del();
         break;
     }
     case EmptyTrash: {
-        text = xi18nc("@info", "Do you want to permanently delete all items from the Trash?<nl/><nl/>"
+        text = xi18nc("@info",
+                      "Do you want to permanently delete all items from the Trash?<nl/><nl/>"
                       "<emphasis strong='true'>This action cannot be undone.</emphasis>");
         acceptButton = KGuiItem(i18nc("@action:button", "Empty Trash"), QStringLiteral("user-trash"));
         break;
     }
     case Trash: {
         if (urlCount == 1) {
-            text = xi18nc("@info", "Do you really want to move this item to the Trash?<nl/>"
-                          "<filename>%1</filename>", prettyList.at(0));
+            text = xi18nc("@info",
+                          "Do you really want to move this item to the Trash?<nl/>"
+                          "<filename>%1</filename>",
+                          prettyList.at(0));
         } else {
-            text = xi18ncp("@info", "Do you really want to move this %1 item to the Trash?", "Do you really want to move these %1 items to the Trash?", urlCount);
+            text =
+                xi18ncp("@info", "Do you really want to move this %1 item to the Trash?", "Do you really want to move these %1 items to the Trash?", urlCount);
         }
         caption = i18n("Move to Trash");
         acceptButton = KGuiItem(i18n("Move to Trash"), QStringLiteral("user-trash"));
@@ -196,7 +194,7 @@ void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls,
     connect(dlg, &QDialog::finished, this, [=](const int buttonCode) {
         const bool isDelete = buttonCode == QDialogButtonBox::Yes;
 
-        emit askUserDeleteResult(isDelete, urls, deletionType, parent);
+        Q_EMIT askUserDeleteResult(isDelete, urls, deletionType, parent);
 
         if (isDelete) {
             KConfigGroup cg = kioConfig->group("Confirmations");
@@ -225,7 +223,7 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
     const bool ask = reqMsgConfig->group("Notification Messages").readEntry(dontAskAgainName, true);
 
     if (!ask) {
-        emit messageBoxResult(type == WarningContinueCancel ? KIO::SlaveBase::Continue : KIO::SlaveBase::Yes);
+        Q_EMIT messageBoxResult(type == WarningContinueCancel ? KIO::SlaveBase::Continue : KIO::SlaveBase::Yes);
         return;
     }
 
@@ -310,7 +308,7 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
             return;
         }
 
-        emit messageBoxResult(btnCode);
+        Q_EMIT messageBoxResult(btnCode);
 
         if (result != QDialogButtonBox::Cancel) {
             KConfigGroup cg = reqMsgConfig->group("Notification Messages");
@@ -322,16 +320,9 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
     dialog->show();
 }
 
-void KIO::WidgetsAskUserActionHandlerPrivate::sslMessageBox(const QString &text,
-                                                            const KIO::MetaData &metaData,
-                                                            QWidget *parent)
+void KIO::WidgetsAskUserActionHandlerPrivate::sslMessageBox(const QString &text, const KIO::MetaData &metaData, QWidget *parent)
 {
-    const QStringList sslList = metaData.value(QStringLiteral("ssl_peer_chain")).split(QLatin1Char('\x01'),
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                                          QString::SkipEmptyParts);
-#else
-                                          Qt::SkipEmptyParts);
-#endif
+    const QStringList sslList = metaData.value(QStringLiteral("ssl_peer_chain")).split(QLatin1Char('\x01'), Qt::SkipEmptyParts);
 
     QList<QSslCertificate> certChain;
     bool decodedOk = true;
@@ -345,21 +336,20 @@ void KIO::WidgetsAskUserActionHandlerPrivate::sslMessageBox(const QString &text,
 
     if (decodedOk) { // Use KSslInfoDialog
         KSslInfoDialog *ksslDlg = new KSslInfoDialog(parent);
-        ksslDlg->setSslInfo(
-            certChain,
-            metaData.value(QStringLiteral("ssl_peer_ip")),
-            text, // The URL
-            metaData.value(QStringLiteral("ssl_protocol_version")),
-            metaData.value(QStringLiteral("ssl_cipher")),
-            metaData.value(QStringLiteral("ssl_cipher_used_bits")).toInt(),
-            metaData.value(QStringLiteral("ssl_cipher_bits")).toInt(),
-            KSslInfoDialog::certificateErrorsFromString(metaData.value(QStringLiteral("ssl_cert_errors"))));
+        ksslDlg->setSslInfo(certChain,
+                            metaData.value(QStringLiteral("ssl_peer_ip")),
+                            text, // The URL
+                            metaData.value(QStringLiteral("ssl_protocol_version")),
+                            metaData.value(QStringLiteral("ssl_cipher")),
+                            metaData.value(QStringLiteral("ssl_cipher_used_bits")).toInt(),
+                            metaData.value(QStringLiteral("ssl_cipher_bits")).toInt(),
+                            KSslInfoDialog::certificateErrorsFromString(metaData.value(QStringLiteral("ssl_cert_errors"))));
 
         // KSslInfoDialog deletes itself by setting Qt::WA_DeleteOnClose
 
         QObject::connect(ksslDlg, &QDialog::finished, q, [this]() {
             // KSslInfoDialog only has one button, QDialogButtonBox::Close
-            emit q->messageBoxResult(KIO::SlaveBase::Cancel);
+            Q_EMIT q->messageBoxResult(KIO::SlaveBase::Cancel);
         });
 
         ksslDlg->show();
@@ -367,9 +357,7 @@ void KIO::WidgetsAskUserActionHandlerPrivate::sslMessageBox(const QString &text,
     }
 
     // Fallback to a generic message box
-    auto *dialog = new KMessageDialog(KMessageDialog::Information,
-                                      i18n("The peer SSL certificate chain appears to be corrupt."),
-                                      parent);
+    auto *dialog = new KMessageDialog(KMessageDialog::Information, i18n("The peer SSL certificate chain appears to be corrupt."), parent);
 
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->setCaption(i18n("SSL"));
@@ -378,7 +366,7 @@ void KIO::WidgetsAskUserActionHandlerPrivate::sslMessageBox(const QString &text,
     dialog->setButtons(KStandardGuiItem::ok());
 
     QObject::connect(dialog, &QDialog::finished, q, [this](const int result) {
-        emit q->messageBoxResult(result == QDialogButtonBox::Ok ? KIO::SlaveBase::Ok : KIO::SlaveBase::Cancel);
+        Q_EMIT q->messageBoxResult(result == QDialogButtonBox::Ok ? KIO::SlaveBase::Ok : KIO::SlaveBase::Cancel);
     });
 
     dialog->show();
